@charset "UTF-8";
/*------------------------------------*
    $CONTENTS
*------------------------------------*/
/**
 * BASE
 * - MAIN
 * - NORMALIZE
 * - LAYOUTS
 * - COMPONENTS
 * - TYPOGRAPHY
 * - FORMS
 *
 * COMPONENTS
 * - TOP BAR
 * - HEADER
 * - NAVIGATIONS
 * - LINKS EFFECT
 * - MEGA MENU
 * - SEARCH ICON
 * - DROP DOWN MOBILE
 * - FULL SCREEN MOBILE
 * - PAGE HEADER
 * - BLOG
 * - SIDEBAR
 * - CUSTOM SELECTS
 * - PAGINATION
 * - COMMENT
 * - SEARCH
 * - FOOTER
 * - 404 PAGE
 *
 * PLUGINS
 * - GENERAL
 * - MAGNIFIC POPUP
 * - SIDR
 * - SLICK
 *
 * RESPONSIVE
 */
/*------------------------------------*
	$MAIN
*------------------------------------*/
html,
body,
div,
span,
applet,
object,
iframe,
h1,
h2,
h3,
h4,
h5,
h6,
p,
blockquote,
pre,
a,
abbr,
acronym,
address,
big,
cite,
code,
del,
dfn,
em,
img,
ins,
kbd,
q,
s,
samp,
small,
strike,
strong,
sub,
sup,
tt,
var,
b,
u,
i,
center,
dl,
dt,
dd,
ol,
ul,
li,
fieldset,
form,
label,
legend,
table,
caption,
tbody,
tfoot,
thead,
tr,
th,
td,
article,
aside,
canvas,
details,
embed,
figure,
figcaption,
footer,
header,
hgroup,
menu,
nav,
output,
ruby,
section,
summary,
time,
mark,
audio,
video {
  margin: 0;
  padding: 0;
  border: 0;
  outline: 0;
  font-size: 100%;
  font: inherit;
  vertical-align: baseline;
  font-family: inherit;
  font-size: 100%;
  font-style: inherit;
  font-weight: inherit;
}

article,
aside,
details,
figcaption,
figure,
footer,
header,
hgroup,
menu,
nav,
section {
  display: block;
}

html {
  font-size: 62.5%;
  overflow-y: scroll;
  -webkit-text-size-adjust: 100%;
  -ms-text-size-adjust: 100%;
}

*,
*:before,
*:after {
  box-sizing: border-box;
}

article,
aside,
details,
figcaption,
figure,
footer,
header,
main,
nav,
section {
  display: block;
}

table {
  border-collapse: collapse;
  border-spacing: 0;
}

caption,
th,
td {
  font-weight: normal;
  text-align: left;
}

blockquote:before,
blockquote:after,
q:before,
q:after {
  content: "";
  content: none;
}

blockquote,
q {
  quotes: none;
}

a:focus {
  outline: solid 1px !important;
}

a:hover,
a:active {
  outline: 0;
}

a img {
  border: 0;
}

img {
  max-width: 100%;
  height: auto;
}

select {
  max-width: 100%;
}

em {
  font-style: italic;
}

* html {
  font-size: 87.5%;
}

html {
  -ms-overflow-x: hidden;
  overflow-x: hidden;
}

body {
  font-family: "Open Sans", sans-serif;
  font-size: 14px;
  line-height: 1.8;
  color: #4a4a4a;
  overflow-wrap: break-word;
  word-wrap: break-word;
}

body {
  background-color: #fff;
}

.mejs-container {
  margin-bottom: 20px;
}

dfn,
cite,
em,
i {
  font-style: italic;
}

/**
 * Grid > Main Classes.
 */
body .oceanwp-row {
  margin: 0 -0.625rem;
}
body .oceanwp-row .col {
  float: left;
  margin: 0 0 1.25rem;
  padding: 0 0.625rem;
}
body .oceanwp-row .span_1_of_1 {
  float: none;
  width: 100%;
}
body .oceanwp-row .span_1_of_2 {
  width: 50%;
}
body .oceanwp-row .span_1_of_3 {
  width: 33.33%;
}
body .oceanwp-row .span_1_of_4 {
  width: 25%;
}
body .oceanwp-row .span_1_of_5 {
  width: 20%;
}
body .oceanwp-row .span_1_of_6 {
  width: 16.66666667%;
}
body .oceanwp-row .span_1_of_7 {
  width: 14.28%;
}
body .oceanwp-row .span_1_of_8 {
  width: 12.5%;
}
body .oceanwp-row .span_1_of_9 {
  width: 11.11%;
}
body .oceanwp-row .span_1_of_10 {
  width: 10%;
}

/**
 * Grid > Clear Floats.
 */
.count-1,
.col-1,
.col.first {
  clear: both;
  margin-left: 0;
}

.isotope-entry {
  clear: none;
}

/**
 * No margin or padding class.
 */
.no-margin {
  margin: 0 !important;
}

.no-padding {
  padding: 0 !important;
}

/**
 * Responsive Videos.
 */
.responsive-video-wrap iframe,
.responsive-video-wrap object,
.responsive-video-wrap embed,
.responsive-audio-wrap iframe,
.responsive-audio-wrap object,
.responsive-audio-wrap embed {
  display: block;
}

.wp-video-shortcode {
  max-width: 100% !important;
}

.responsive-video-wrap p {
  margin: 0;
}

/**
 * Search form shortcode
 */
form.oceanwp-searchform {
  display: inline-block;
  position: relative;
  height: 35px;
}
form.oceanwp-searchform input {
  margin: 0;
  padding: 0 40px 0 15px;
  height: 100%;
  min-height: 100%;
}
form.oceanwp-searchform button {
  display: block;
  position: absolute;
  top: 50%;
  right: 0;
  min-width: 40px;
  height: 60%;
  height: 100%;
  font-size: 12px;
  font-weight: 600;
  background-color: transparent !important;
  margin: 0;
  padding: 0;
  border: 0;
  text-align: center;
  line-height: 1;
  transition: all 0.3s ease;
  -ms-transform: translateY(-50%);
  transform: translateY(-50%);
}

/**
 * Language Switches.
 */
.polylang-switcher-shortcode li {
  float: left;
  margin-right: 5px;
}
.polylang-switcher-shortcode.flags-and-names li {
  margin-right: 15px;
}
.polylang-switcher-shortcode li:last-child {
  margin-right: 0;
}

/**
 * Text meant only for screen readers.
 */
.screen-reader-text {
  border: 0;
  clip: rect(1px, 1px, 1px, 1px);
  -webkit-clip-path: inset(50%);
          clip-path: inset(50%);
  height: 1px;
  margin: -1px;
  font-size: 14px !important;
  font-weight: 400;
  overflow: hidden;
  padding: 0;
  position: absolute !important;
  width: 1px;
  word-wrap: normal !important; /* Many screen reader and browser combinations announce broken words as they would appear visually. */
}
.screen-reader-text:focus {
  background-color: #f1f1f1;
  border-radius: 3px;
  box-shadow: 0 0 2px 2px rgba(0, 0, 0, 0.6);
  clip: auto !important;
  -webkit-clip-path: none;
          clip-path: none;
  color: #21759b;
  display: block;
  font-size: 14px;
  font-size: 0.875rem;
  font-weight: bold;
  height: auto;
  left: 5px;
  line-height: normal;
  padding: 15px 23px 14px;
  text-decoration: none;
  top: 5px;
  width: auto;
  z-index: 100000; /* Above WP toolbar. */
}

.no-display {
  border: 0;
  clip: rect(1px, 1px, 1px, 1px);
  display: none;
  height: 1px;
  overflow: hidden;
  padding: 0;
  position: absolute;
  width: 1px;
  -webkit-clip-path: circle(1% at 1% 1%);
  clip-path: circle(1% at 1% 1%);
}

.owp-icon {
  width: 14px;
  height: 14px;
  vertical-align: text-bottom;
}

#owp-svg-icons path,
#owp-svg-icons rect,
#owp-svg-icons circle,
#owp-svg-icons line,
#owp-svg-icons polygon,
#owp-svg-icons polyline {
  stroke: inherit;
  fill: none;
}

.owp-icon use {
  stroke: #333;
}

/**
 * Selection Color.
 */
::selection {
  color: #fff;
  background: #333;
  text-shadow: none;
}

::-moz-selection {
  color: #fff;
  background: #333;
  text-shadow: none;
}

/*------------------------------------*
	Tablet Portrait
*------------------------------------*/
@media only screen and (min-width: 768px) and (max-width: 959px) {
  /* turn 4 column masonry grids into 2 columns */
  body .oceanwp-row .span_1_of_4.col-3.col {
    margin-left: 0;
    clear: both;
  }
  body .oceanwp-row .span_1_of_4.col:not(.product),
body .oceanwp-isotope-grid .span_1_of_4.col {
    width: 50%;
  }
}
/*------------------------------------*
	Phone Landscape
*------------------------------------*/
@media only screen and (max-width: 480px) {
  .col {
    width: 100%;
    margin-left: 0;
    margin-right: 0;
    margin-bottom: 30px;
  }
}
/*------------------------------------*
	$NORMALIZE
*------------------------------------*/
/*! normalize.css v3.0.3 | MIT License | github.com/necolas/normalize.css */
/**
 * 1. Set default font family to sans-serif.
 * 2. Prevent iOS and IE text size adjust after device orientation change,
 *    without disabling user zoom.
 */
html {
  font-family: sans-serif; /* 1 */
  -ms-text-size-adjust: 100%; /* 2 */
  -webkit-text-size-adjust: 100%; /* 2 */
}

/**
 * Remove default margin.
 */
body {
  margin: 0;
}

/* HTML5 display definitions
   ========================================================================== */
/**
 * Correct `block` display not defined for any HTML5 element in IE 8/9.
 * Correct `block` display not defined for `details` or `summary` in IE 10/11
 * and Firefox.
 * Correct `block` display not defined for `main` in IE 11.
 */
article,
aside,
details,
figcaption,
figure,
footer,
header,
hgroup,
main,
menu,
nav,
section,
summary {
  display: block;
}

/**
 * 1. Correct `inline-block` display not defined in IE 8/9.
 * 2. Normalize vertical alignment of `progress` in Chrome, Firefox, and Opera.
 */
audio,
canvas,
progress,
video {
  display: inline-block; /* 1 */
  vertical-align: baseline; /* 2 */
}

/**
 * Prevent modern browsers from displaying `audio` without controls.
 * Remove excess height in iOS 5 devices.
 */
audio:not([controls]) {
  display: none;
  height: 0;
}

/**
 * Address `[hidden]` styling not present in IE 8/9/10.
 * Hide the `template` element in IE 8/9/10/11, Safari, and Firefox < 22.
 */
[hidden],
template {
  display: none;
}

/* Links
   ========================================================================== */
/**
 * Remove the gray background color from active links in IE 10.
 */
a {
  background-color: transparent;
}

/**
 * Improve readability of focused elements when they are also in an
 * active/hover state.
 */
a:active,
a:hover {
  outline: 0;
}

/* Text-level semantics
   ========================================================================== */
/**
 * Address styling not present in IE 8/9/10/11, Safari, and Chrome.
 */
abbr[title] {
  border-bottom: 1px dotted;
}

/**
 * Address style set to `bolder` in Firefox 4+, Safari, and Chrome.
 */
b,
strong {
  font-weight: 600;
}

/**
 * Address styling not present in Safari and Chrome.
 */
dfn {
  font-style: italic;
}

/**
 * Address styling not present in IE 8/9.
 */
mark {
  background: #ff0;
  color: #000;
}

/**
 * Address inconsistent and variable font size in all browsers.
 */
small {
  font-size: 80%;
}

/**
 * Prevent `sub` and `sup` affecting `line-height` in all browsers.
 */
sub,
sup {
  font-size: 75%;
  line-height: 0;
  position: relative;
  vertical-align: baseline;
}

sup {
  top: -0.5em;
}

sub {
  bottom: -0.25em;
}

/* Embedded content
   ========================================================================== */
/**
 * Remove border when inside `a` element in IE 8/9/10.
 */
img {
  border: 0;
}

/**
 * Correct overflow not hidden in IE 9/10/11.
 */
svg:not(:root) {
  overflow: hidden;
}

/* Grouping content
   ========================================================================== */
/**
 * Address differences between Firefox and other browsers.
 */
hr {
  box-sizing: content-box;
  height: 0;
}

/**
 * Contain overflow in all browsers.
 */
pre {
  overflow: auto;
}

/**
 * Address odd `em`-unit font size rendering in all browsers.
 */
code,
kbd,
pre,
samp {
  font-family: monospace, monospace;
  font-size: 1em;
}

/* Forms
   ========================================================================== */
/**
 * Known limitation: by default, Chrome and Safari on OS X allow very limited
 * styling of `select`, unless a `border` property is set.
 */
/**
 * 1. Correct color not being inherited.
 *    Known issue: affects color of disabled elements.
 * 2. Correct font properties not being inherited.
 * 3. Address margins set differently in Firefox 4+, Safari, and Chrome.
 */
button,
input,
optgroup,
select,
textarea {
  color: inherit; /* 1 */
  font: inherit; /* 2 */
  margin: 0; /* 3 */
}

/**
 * Address `overflow` set to `hidden` in IE 8/9/10/11.
 */
button {
  overflow: visible;
}

/**
 * Address inconsistent `text-transform` inheritance for `button` and `select`.
 * All other form control elements do not inherit `text-transform` values.
 * Correct `button` style inheritance in Firefox, IE 8/9/10/11, and Opera.
 * Correct `select` style inheritance in Firefox.
 */
button,
select {
  text-transform: none;
}

/**
 * 1. Avoid the WebKit bug in Android 4.0.* where (2) destroys native `audio`
 *    and `video` controls.
 * 2. Correct inability to style clickable `input` types in iOS.
 * 3. Improve usability and consistency of cursor style between image-type
 *    `input` and others.
 */
button,
html input[type=button],
input[type=reset],
input[type=submit] {
  -webkit-appearance: button; /* 2 */
  cursor: pointer; /* 3 */
}

/**
 * Re-set default cursor for disabled elements.
 */
button[disabled],
html input[disabled] {
  cursor: default;
}

/**
 * Remove inner padding and border in Firefox 4+.
 */
button::-moz-focus-inner,
input::-moz-focus-inner {
  border: 0;
  padding: 0;
}

/**
 * Address Firefox 4+ setting `line-height` on `input` using `!important` in
 * the UA stylesheet.
 */
input {
  line-height: normal;
}

/**
 * It's recommended that you don't attempt to style these elements.
 * Firefox's implementation doesn't respect box-sizing, padding, or width.
 *
 * 1. Address box sizing set to `content-box` in IE 8/9/10.
 * 2. Remove excess padding in IE 8/9/10.
 */
input[type=checkbox],
input[type=radio] {
  box-sizing: border-box;
  /* 1 */
  padding: 0; /* 2 */
}

/**
 * Fix the cursor style for Chrome's increment/decrement buttons. For certain
 * `font-size` values of the `input`, it causes the cursor style of the
 * decrement button to change from `default` to `text`.
 */
input[type=number]::-webkit-inner-spin-button,
input[type=number]::-webkit-outer-spin-button {
  height: auto;
}

/**
 * Remove inner padding and search cancel button in Safari and Chrome on OS X.
 * Safari (but not Chrome) clips the cancel button when the search input has
 * padding (and `textfield` appearance).
 */
input[type=search]::-webkit-search-cancel-button,
input[type=search]::-webkit-search-decoration {
  -webkit-appearance: none;
}

/**
 * Define consistent border, margin, and padding.
 */
fieldset {
  border: 1px solid #c0c0c0;
  margin: 0 2px;
  padding: 0.35em 0.625em 0.75em;
}

/**
 * 1. Correct `color` not being inherited in IE 8/9/10/11.
 * 2. Remove padding so people aren't caught out if they zero out fieldsets.
 */
legend {
  border: 0; /* 1 */
  padding: 0; /* 2 */
}

/**
 * Remove default vertical scrollbar in IE 8/9/10/11.
 */
textarea {
  overflow: auto;
}

/**
 * Don't inherit the `font-weight` (applied by a rule above).
 * NOTE: the default cannot safely be changed in Chrome and Safari on OS X.
 */
optgroup {
  font-weight: bold;
}

/* Tables
   ========================================================================== */
/**
 * Remove most spacing between table cells.
 */
table {
  border-collapse: collapse;
  border-spacing: 0;
}

td,
th {
  padding: 0;
}

/*------------------------------------*
	$LAYOUTS
*------------------------------------*/
.container {
  width: 1200px;
  max-width: 90%;
  margin: 0 auto;
}

#wrap {
  position: relative;
}

#main {
  position: relative;
}
#main #content-wrap {
  padding-top: 50px;
  padding-bottom: 50px;
}

.no-margins #main #content-wrap,
.no-margins.separate-layout #main #content-wrap,
.landing-page #main #content-wrap {
  padding-top: 0;
  padding-bottom: 0;
}

.content-area {
  float: left;
  position: relative;
  width: 72%;
  padding-right: 30px;
  border-right-width: 1px;
  border-style: solid;
  border-color: #f1f1f1;
}

.widget-area {
  width: 28%;
}
.widget-area.sidebar-primary {
  float: right;
  padding-left: 30px;
}
.widget-area.sidebar-secondary {
  float: left;
}

.content-full-width .content-area,
body.content-full-screen #content-wrap {
  width: 100% !important;
  max-width: none !important;
  padding: 0 !important;
  border: 0 !important;
}

.content-full-screen .content-area {
  float: none;
  width: 100% !important;
  max-width: none !important;
  padding: 0 !important;
  margin: 0 !important;
  border: 0 !important;
}

.content-left-sidebar .content-area {
  float: right;
  padding-left: 30px;
  padding-right: 0;
  border-left-width: 1px;
  border-right-width: 0;
}
.content-left-sidebar .widget-area {
  float: left;
  padding-right: 30px;
  padding-left: 0;
}

.content-both-sidebars .content-area {
  width: 44%;
}
.content-both-sidebars.scs-style .content-area {
  left: 28%;
  padding-left: 30px;
  border-left-width: 1px;
}
.content-both-sidebars.scs-style .widget-area.sidebar-secondary {
  position: relative;
  left: -44%;
  padding-right: 30px;
}
.content-both-sidebars.ssc-style .content-area {
  left: 56%;
  padding-left: 30px;
  padding-right: 0;
  border-left-width: 1px;
  border-right-width: 0;
}
.content-both-sidebars.ssc-style .widget-area {
  position: relative;
  left: -44%;
  padding-right: 30px;
}
.content-both-sidebars.ssc-style .widget-area.sidebar-primary {
  padding-left: 0;
}
.content-both-sidebars.css-style .widget-area.sidebar-secondary {
  padding-left: 30px;
}

/* Boxed Layout */
.boxed-layout {
  background-color: #e9e9e9;
}
.boxed-layout #wrap {
  width: 1280px;
  max-width: 100%;
  margin: 0 auto;
  background-color: #fff;
}
.boxed-layout.wrap-boxshadow #wrap {
  box-shadow: 0 1px 4px rgba(0, 0, 0, 0.15);
}
.boxed-layout #wrap .container {
  width: auto;
  max-width: none;
  padding-left: 30px;
  padding-right: 30px;
}
.boxed-layout.content-full-screen #content-wrap {
  padding-left: 0 !important;
  padding-right: 0 !important;
}
.boxed-layout #footer-widgets {
  margin: 0;
}

/* Boxed Layout > Move absolute items */
.boxed-layout .site-breadcrumbs {
  right: 30px;
}

/* Separate Layout */
.separate-layout {
  background-color: #f1f1f1;
}
.separate-layout .content-area,
.separate-layout .widget-area .sidebar-box {
  background-color: #fff;
  padding: 30px;
}
.separate-layout.content-left-sidebar .content-area {
  padding: 30px;
}
.separate-layout.content-full-width .content-area {
  padding: 30px !important;
}
.separate-layout .content-area {
  border-right-width: 0;
}
.separate-layout.content-left-sidebar .content-area {
  border-left-width: 0;
}
.separate-layout .widget-area.sidebar-primary {
  padding-left: 20px;
}
.separate-layout .widget-area.sidebar-secondary {
  padding-right: 20px;
}
.separate-layout.content-left-sidebar .widget-area {
  padding-right: 20px;
  padding-left: 0;
}
.separate-layout #main #content-wrap {
  padding-top: 20px;
  padding-bottom: 20px;
}
.separate-layout .sidebar-box {
  margin-bottom: 20px;
}
.separate-layout .sidebar-box:last-child {
  margin-bottom: 0;
}
.separate-layout.content-both-sidebars.scs-style .content-area {
  border-left-width: 0;
}
.separate-layout.content-both-sidebars.scs-style .widget-area.sidebar-secondary {
  padding-right: 20px;
}
.separate-layout.content-both-sidebars.ssc-style .content-area {
  padding-right: 30px;
  border-left-width: 0;
}
.separate-layout.content-both-sidebars.ssc-style .widget-area {
  padding-right: 20px;
}
.separate-layout.content-both-sidebars.css-style .widget-area.sidebar-secondary {
  padding-left: 20px;
  padding-right: 0;
}

body.separate-blog.separate-layout .content-area {
  padding: 0 !important; /* using !important to override customizer setting */
  background-color: transparent;
}
body.separate-blog.separate-layout #blog-entries > * {
  background-color: #fff;
  padding: 30px;
  border: 0;
  margin-bottom: 20px;
}
body.separate-blog.separate-layout #blog-entries > :last-child {
  margin-bottom: 0;
}
body.separate-blog.separate-layout .oceanwp-pagination,
body.separate-blog.separate-layout .page-jump,
body.separate-blog.separate-layout .scroller-status {
  background-color: #fff;
  padding: 30px;
  margin-top: 20px;
}
body.separate-blog.separate-layout .oceanwp-pagination ul.page-numbers,
body.separate-blog.separate-layout .page-jump ul.page-numbers,
body.separate-blog.separate-layout .scroller-status ul.page-numbers {
  padding: 0;
}
body.separate-blog.separate-layout .oceanwp-row {
  margin: 0;
  margin-right: -1.25rem;
}
body.separate-blog.separate-layout #blog-entries.blog-grid > * {
  background-color: transparent;
  padding: 0 1.25rem 0 0;
}
body.separate-blog.separate-layout #blog-entries.blog-grid > :last-child {
  margin-bottom: 1.25rem;
}
body.separate-blog.separate-layout.has-blog-grid .oceanwp-pagination {
  margin-top: 0;
}
body.separate-blog.separate-layout .blog-entry.grid-entry .blog-entry-inner {
  background-color: #fff;
  padding: 1.875rem;
  border: 0;
}
body.separate-blog.separate-layout .blog-entry.grid-entry .thumbnail {
  margin: 0;
}

/*------------------------------------*
	All Devices under 1280px
*------------------------------------*/
@media only screen and (max-width: 1280px) {
  /* Both sidebars layout */
  .content-both-sidebars .content-area {
    float: none !important;
    width: 100% !important;
    left: auto !important;
    border-width: 0 !important;
  }
  .content-both-sidebars:not(.separate-layout) .content-area {
    padding: 0 !important;
    margin-bottom: 40px;
  }
  .content-both-sidebars .widget-area.sidebar-primary, .content-both-sidebars .widget-area.sidebar-secondary {
    float: left;
    width: 49% !important;
    left: auto !important;
    padding: 0 !important;
  }
  .content-both-sidebars .widget-area.sidebar-primary {
    float: right;
  }
  .content-both-sidebars:not(.separate-layout) .widget-area.sidebar-primary, .content-both-sidebars:not(.separate-layout) .widget-area.sidebar-secondary {
    width: 48% !important;
  }
  /* Separate layout */
  .separate-layout.content-both-sidebars .content-area {
    margin-bottom: 20px;
  }
  .separate-layout.content-both-sidebars .widget-area.sidebar-primary, .separate-layout.content-both-sidebars .widget-area.sidebar-secondary {
    width: 49% !important;
  }
  .separate-layout.content-both-sidebars .widget-area.sidebar-secondary {
    margin-bottom: 20px;
  }
  .separate-layout.content-both-sidebars .widget-area.sidebar-primary {
    padding-left: 0;
  }
}
/*------------------------------------*
	All Devices under 1080px
*------------------------------------*/
@media only screen and (max-width: 1080px) {
  /* Both sidebars layout */
  .content-both-sidebars .content-area {
    float: none !important;
    width: 100% !important;
    left: auto !important;
    border-width: 0 !important;
  }
  .content-both-sidebars:not(.separate-layout) .content-area {
    padding: 0 !important;
    margin-bottom: 40px;
  }
  .content-both-sidebars .widget-area.sidebar-primary, .content-both-sidebars .widget-area.sidebar-secondary {
    float: left;
    width: 49% !important;
    left: auto !important;
    padding: 0 !important;
  }
  .content-both-sidebars .widget-area.sidebar-primary {
    float: right;
  }
  .content-both-sidebars:not(.separate-layout) .widget-area.sidebar-primary, .content-both-sidebars:not(.separate-layout) .widget-area.sidebar-secondary {
    width: 48% !important;
  }
  /* Separate layout */
  .separate-layout.content-both-sidebars .content-area {
    margin-bottom: 20px;
  }
  .separate-layout.content-both-sidebars .widget-area.sidebar-primary, .separate-layout.content-both-sidebars .widget-area.sidebar-secondary {
    width: 49% !important;
  }
  .separate-layout.content-both-sidebars .widget-area.sidebar-secondary {
    margin-bottom: 20px;
  }
  .separate-layout.content-both-sidebars .widget-area.sidebar-primary {
    padding-left: 0;
  }
}
/*------------------------------------*
	All Devices under 960px
*------------------------------------*/
@media only screen and (max-width: 959px) {
  /* boxed */
  .boxed-layout #wrap {
    overflow: hidden;
  }
  .boxed-layout .site-breadcrumbs {
    right: auto;
  }
  /* container */
  .container,
body.content-full-screen .elementor-section-wrap > .elementor-section.elementor-section-boxed > .elementor-container {
    max-width: 90%;
  }
  /* full width content and sidebar */
  .content-area,
.content-left-sidebar .content-area {
    float: none !important;
    width: 100%;
    margin-bottom: 40px;
    border: 0;
  }
  body.sidebar-content .content-area {
    margin-bottom: 0;
  }
  body:not(.separate-layout) .content-area,
.content-left-sidebar:not(.separate-layout) .content-area {
    padding: 0 !important;
  }
  .no-margins .content-area,
.no-margins.content-left-sidebar .content-area {
    margin-bottom: 0;
  }
  .widget-area.sidebar-primary,
.widget-area.sidebar-secondary,
.content-left-sidebar .widget-area {
    float: none !important;
    width: 100%;
    padding: 0 !important;
    border: 0;
  }
  body.has-composer.has-sidebar #primary {
    margin-bottom: 40px;
  }
  #main #content-wrap.container {
    width: auto !important;
  }
  /* Both sidebars layout */
  .content-both-sidebars .widget-area.sidebar-primary, .content-both-sidebars .widget-area.sidebar-secondary {
    float: none !important;
    width: 100% !important;
  }
  .content-both-sidebars:not(.separate-layout) .widget-area.sidebar-primary, .content-both-sidebars:not(.separate-layout) .widget-area.sidebar-secondary {
    width: 100% !important;
  }
  .separate-layout.content-both-sidebars .widget-area.sidebar-primary, .separate-layout.content-both-sidebars .widget-area.sidebar-secondary {
    width: 100% !important;
  }
  /* Separate layout */
  .separate-layout .container, .separate-layout.content-full-screen .elementor-section-wrap > .elementor-section.elementor-section-boxed > .elementor-container {
    max-width: 95%;
  }
  .separate-layout .content-area, .separate-layout.content-left-sidebar .content-area {
    margin-bottom: 20px;
  }
  .separate-layout .widget-area {
    padding-left: 0 !important;
    padding-right: 0 !important;
  }
  body.separate-blog.separate-layout .oceanwp-row {
    margin: 0 !important;
  }
  body.separate-blog.separate-layout #blog-entries.blog-grid > * {
    padding: 0 !important;
  }
}
/*------------------------------------*
	Tablet Portrait
*------------------------------------*/
@media only screen and (min-width: 768px) and (max-width: 959px) {
  /* main  */
  body.boxed-layout #wrap,
body.boxed-layout .parallax-footer {
    width: auto !important;
  }
}
/*------------------------------------*
	Phone Portrait and Landscape
*------------------------------------*/
@media only screen and (max-width: 767px) {
  /* grid & main  */
  #wrap {
    width: 100% !important;
  }
  body.boxed-layout #wrap {
    width: auto !important;
  }
  .boxed-layout #top-bar-social.top-bar-right {
    right: auto;
  }
  .boxed-layout #top-bar-social.top-bar-left {
    left: auto;
  }
  .col:not(.swiper-slide), .blog-entry {
    width: 100% !important;
    margin-bottom: 25px;
  }
}
/*------------------------------------*
	Phone Landscape
*------------------------------------*/
@media only screen and (max-width: 480px) {
  /* boxed */
  .boxed-layout #wrap .container {
    padding-left: 20px;
    padding-right: 20px;
  }
}
/*------------------------------------*
	$COMPONENTS
*------------------------------------*/
figure > img {
  display: block;
  margin: 0 auto;
}

img {
  max-width: 100%;
  height: auto;
  vertical-align: middle;
}

img[class*=align],
img[class*=attachment-] {
  height: auto;
}

.wp-caption {
  max-width: 100%;
  margin-bottom: 24px;
}
.wp-caption img[class*=wp-image-] {
  display: block;
  margin-bottom: 5px;
}

.wp-caption-text {
  font-size: 14px;
  font-style: italic;
  color: #999;
}

.wp-smiley {
  margin-top: 0;
  margin-bottom: 0;
  padding: 0;
  border: 0;
}

embed,
iframe,
object {
  width: 100%;
  max-width: 100%;
}

.entry-content .alignwide {
  margin-left: -3%;
  width: 106%;
  max-width: 106%;
}

.entry-content .alignfull {
  margin-left: -32px;
  width: calc(100% + 64px) !important;
  max-width: calc(100% + 64px);
}

.page .entry .alignfull {
  margin-left: -32px;
  width: calc(100% + 64px) !important;
  max-width: calc(100% + 64px);
}
.page .entry .alignwide {
  margin-left: -3%;
  width: 106%;
  max-width: 106%;
}

body.content-full-screen .entry-content .alignwide,
body.content-full-screen .entry-content .alignfull,
body.content-full-screen .entry .alignwide,
body.content-full-screen .entry .alignfull {
  margin-left: 0;
  width: 100% !important;
  max-width: 100%;
}

body.single-post.content-max-width .entry-content .wp-block-embed .responsive-video-wrap,
body.page.content-max-width .entry .wp-block-embed .responsive-video-wrap {
  max-width: 100%;
  padding-left: 0;
  padding-right: 0;
}
body.single-post.content-max-width .entry-content .alignwide,
body.page.content-max-width .entry .alignwide {
  margin: 0 auto;
  width: calc(90% + 32px);
  max-width: calc(90% + 32px);
}
body.single-post.content-max-width .entry-content .alignfull,
body.page.content-max-width .entry .alignfull {
  width: 100vw !important;
  max-width: 100vw !important;
  margin-left: calc(50% - 50vw) !important;
}

@media screen and (max-width: 959px) {
  .entry-content .alignfull {
    margin-left: -5.5% !important;
    width: 111% !important;
    max-width: 111% !important;
  }
  .page .entry .alignfull {
    margin-left: -5.5% !important;
    width: 111% !important;
    max-width: 111% !important;
  }
  body.content-full-screen .entry-content .alignfull {
    margin-left: -5.5% !important;
    width: 111% !important;
    max-width: 111% !important;
  }
  body.content-full-screen.page .entry .alignfull {
    margin-left: -5.5% !important;
    width: 111% !important;
    max-width: 111% !important;
  }
}
.alignleft {
  float: left;
  margin-right: 1.5em;
}

.alignright {
  float: right;
  margin-left: 1.5em;
}

.aligncenter {
  text-align: center;
  margin: 0 auto;
  clear: both;
}

img.aligncenter,
.wp-caption.aligncenter {
  display: block;
  margin: 0 auto;
}

.alignnone {
  display: block;
}

table {
  width: 100%;
  margin-bottom: 2.618em;
}

table th,
table td {
  padding: 10px;
  text-align: left;
  vertical-align: top;
  border-bottom: 1px solid #e9e9e9;
}

table th {
  text-transform: uppercase;
}

.sticky,
.bypostauthor {
  font-size: inherit;
}

.col:after,
.clr:after,
.group:after,
dl:after,
.left_float:after,
.right_float:after {
  content: "";
  display: block;
  visibility: hidden;
  clear: both;
  zoom: 1;
  height: 0;
}

.left_float {
  float: left;
  width: 48%;
}

.right_float {
  float: right;
  width: 48%;
}

.no_float {
  clear: both;
}

.left_float label,
.right_float label,
.no_float label {
  font-size: 13px;
  font-weight: 600;
  color: #333;
}

.full {
  display: block;
  width: 100%;
}

/**
 * Gallery
 * Taken from Twenty Seventeen theme.
 */
.gallery-item {
  display: inline-block;
  text-align: left;
  vertical-align: top;
  margin: 0 0 1.5em;
  width: 50%;
}

.gallery-columns-1 .gallery-item {
  width: 100%;
}

.gallery-columns-2 .gallery-item {
  max-width: 50%;
}

.gallery-item a,
.gallery-item a:hover,
.gallery-item a:focus {
  box-shadow: none;
  background: none;
  display: inline-block;
  max-width: 100%;
  vertical-align: top;
}

.gallery-item a img {
  display: block;
}

.gallery-caption {
  background-color: #f5f5f5;
  color: #333;
  font-size: 14px;
  font-weight: 400;
  line-height: 1.3;
  padding: 8px 10px;
}

.gallery-columns-7 .gallery-caption,
.gallery-columns-8 .gallery-caption,
.gallery-columns-9 .gallery-caption {
  display: none;
}

@media screen and (min-width: 30em) {
  .gallery-item {
    max-width: 25%;
  }
  .gallery-columns-1 .gallery-item {
    max-width: 100%;
  }
  .gallery-columns-2 .gallery-item {
    max-width: 50%;
  }
  .gallery-columns-3 .gallery-item {
    max-width: 33.33%;
  }
  .gallery-columns-4 .gallery-item {
    max-width: 25%;
  }
}
@media screen and (min-width: 48em) {
  .gallery-columns-5 .gallery-item {
    max-width: 20%;
  }
  .gallery-columns-6 .gallery-item {
    max-width: 16.66%;
  }
  .gallery-columns-7 .gallery-item {
    max-width: 14.28%;
  }
  .gallery-columns-8 .gallery-item {
    max-width: 12.5%;
  }
  .gallery-columns-9 .gallery-item {
    max-width: 11.11%;
  }
}
/* Responsive Classic Editor Video */
.responsive-video-wrap {
  position: relative;
}

.responsive-video-wrap:before {
  content: "";
  display: block;
  padding-top: 56.25%;
}

.responsive-video-wrap iframe {
  position: absolute;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  height: 100%;
  width: 100%;
  display: block;
}

.wp-block-embed .responsive-video-wrap {
  position: static;
}

.wp-block-embed .responsive-video-wrap:before {
  display: none;
}

/*------------------------------------*
	$TYPOGRAPHY
*------------------------------------*/
/**
 * Set link colors.
 */
a {
  color: #333;
}
a:hover {
  color: #13aff0;
}

a.light {
  color: #fff;
}
a.light:hover {
  color: #13aff0;
}

a, a:hover, a:focus {
  text-decoration: none;
  transition: all 0.3s ease;
}

.single-post:not(.elementor-page) .entry-content a:not(.wp-block-button__link):not(.wp-block-file__button),
.page:not(.elementor-page):not(.woocommerce-page) .entry a:not(.wp-block-button__link):not(.wp-block-file__button) {
  cursor: pointer;
  text-underline-offset: 3px;
  text-decoration: underline;
  text-decoration-skip-ink: all;
  transition: all 0.3s ease;
}
.single-post:not(.elementor-page) .entry-content a:not(.wp-block-button__link):not(.wp-block-file__button):hover,
.page:not(.elementor-page):not(.woocommerce-page) .entry a:not(.wp-block-button__link):not(.wp-block-file__button):hover {
  text-decoration: underline;
  -webkit-text-decoration-style: dotted;
          text-decoration-style: dotted;
  text-decoration-skip-ink: none;
  transition: all 0.3s ease;
}
.single-post:not(.elementor-page) .entry-content a:not(.wp-block-button__link):not(.wp-block-file__button):focus:not(.wp-block-button__link):not(.wp-block-file__button),
.page:not(.elementor-page):not(.woocommerce-page) .entry a:not(.wp-block-button__link):not(.wp-block-file__button):focus:not(.wp-block-button__link):not(.wp-block-file__button) {
  /* Only visible in Windows High Contrast mode */
  outline: 2px solid transparent;
  text-decoration: underline 1px dotted #13aff0;
  text-decoration-skip-ink: none;
  transition: all 0.3s ease;
}

/**
 * Headings.
 */
h1,
h2,
h3,
h4,
h5,
h6 {
  font-weight: 600;
  margin: 0 0 20px;
  color: #333;
  line-height: 1.4;
}

h1 {
  font-size: 23px;
}

h2 {
  font-size: 20px;
}

h3 {
  font-size: 18px;
}

h4 {
  font-size: 17px;
}

h5 {
  font-size: 15px;
}

h6 {
  font-size: 14px;
}

.theme-heading {
  font-size: 14px;
  letter-spacing: 1.3px;
  margin: 0 0 20px;
  text-transform: uppercase;
}
.theme-heading .text::before {
  content: "\f105";
  font-family: "Font Awesome 5 Free";
  font-size: 18px;
  font-weight: 600;
  color: #13aff0;
  padding-right: 6px;
}

/**
 * Text elements.
 */
p {
  margin: 0 0 20px;
}

abbr[title],
dfn[title] {
  cursor: help;
}

del {
  vertical-align: baseline;
  text-decoration: line-through;
  color: #aaa;
}

code,
kbd,
pre,
samp {
  font-size: 16px;
}

pre {
  margin: 20px 0;
  padding: 20px;
  color: #2080ad;
  background-color: #fafafa;
}

code {
  color: #2080ad;
}

.wp-block-quote {
  margin: 1.5em auto;
  padding-left: 20px;
  border-left-width: 3px;
  border-style: solid;
  border-left-color: #13aff0;
}

blockquote {
  font-style: italic;
  margin: 20px 40px;
  padding-left: 20px;
  border-left-width: 3px;
  border-style: solid;
  border-left-color: #13aff0;
}
blockquote cite {
  position: relative;
  display: block;
  padding: 10px 0 0 20px;
  color: #555;
}
blockquote cite:before {
  position: absolute;
  left: 0;
  content: "—";
}

q:before,
q:after,
blockquote:before,
blockquote:after {
  content: "";
}

address {
  display: block;
  margin: 0 0 20px;
}

ul,
ol {
  margin: 15px 0 15px 20px;
}

ol {
  list-style-type: decimal;
}

ol ol {
  list-style: upper-alpha;
}

ol ol ol {
  list-style: lower-roman;
}

ol ol ol ol {
  list-style: lower-alpha;
}

li ul,
li ol {
  margin: 0 0 0 25px;
}

dl {
  margin: 20px;
}

dt {
  font-weight: 700;
}

dd {
  margin-bottom: 20px;
}

hr {
  clear: both;
  height: 1px;
  min-height: 0;
  margin: 20px 0;
  border-top: 1px solid #e9e9e9;
  border-right: 0;
  border-bottom: 0;
  border-left: 0;
}
hr.dotted {
  border-style: dotted;
}
hr.dashed {
  border-style: dashed;
}
hr.blackborder {
  border-color: #000;
}
hr.whiteborder {
  border-color: #fff;
}

/**
 * Print styles.
 */
@media print {
  * {
    background: transparent !important;
    box-shadow: none !important;
    text-shadow: none !important;
  }
  a,
a:visited {
    text-decoration: underline;
  }
  a[href]:after {
    content: " (" attr(href) ")";
  }
  abbr[title]:after {
    content: " (" attr(title) ")";
  }
  .ir a:after,
a[href^="javascript:"]:after,
a[href^="#"]:after {
    content: "";
  }
  pre,
blockquote {
    border: 1px solid #999;
    page-break-inside: avoid;
  }
  thead {
    display: table-header-group;
  }
  tr,
img {
    page-break-inside: avoid;
  }
  img {
    max-width: 100% !important;
  }
  @page {
    margin: 0.5cm;
  }
  p,
h2,
h3 {
    orphans: 3;
    widows: 3;
  }
  h2,
h3 {
    page-break-after: avoid;
  }
}
/*------------------------------------*
	Phone Landscape
*------------------------------------*/
@media only screen and (max-width: 480px) {
  blockquote {
    margin: 20px 0;
  }
}
/*------------------------------------*
	$FORMS
*------------------------------------*/
form input[type=text],
form input[type=password],
form input[type=email],
form input[type=url],
form input[type=date],
form input[type=month],
form input[type=time],
form input[type=datetime],
form input[type=datetime-local],
form input[type=week],
form input[type=number],
form input[type=search],
form input[type=tel],
form input[type=color],
form select,
form textarea {
  display: inline-block;
  min-height: 40px;
  width: 100%;
  font-size: 14px;
  line-height: 1.8;
  padding: 6px 12px;
  vertical-align: middle;
  background-color: transparent;
  color: #333;
  border: 1px solid #ddd;
  border-radius: 3px;
  transition: all 0.3s ease;
}

form select {
  padding-top: 0 !important;
  padding-bottom: 0 !important;
}

form input[type=number] {
  max-width: 50px;
  padding: 0 0 0 8px;
}

input[type=text],
input[type=password],
input[type=email],
input[type=url],
input[type=search],
textarea {
  -webkit-appearance: none;
}

input[type=search]::-webkit-search-decoration,
input[type=search]::-webkit-search-cancel-button,
input[type=search]::-webkit-search-results-button,
input[type=search]::-webkit-search-results-decoration {
  display: none;
}

form textarea {
  min-height: 150px;
  line-height: 1.5;
  resize: vertical;
}

input[type=checkbox] {
  display: inline-block;
  background-color: #fff;
  border: 1px solid #bbb;
  line-height: 0;
  width: 16px;
  min-width: 16px;
  height: 16px;
  margin: -3px 10px 0 0;
  outline: 0;
  text-align: center;
  vertical-align: middle;
  clear: none;
  cursor: pointer;
  -webkit-appearance: none;
  box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1);
  transition: 0.05s border-color ease-in-out;
}

input[type=radio]:checked:before,
input[type=checkbox]:checked:before {
  float: left;
  display: inline-block;
  vertical-align: middle;
  width: 16px;
  line-height: 14px;
  font-family: "Font Awesome 5 Free";
  text-rendering: auto;
}

input[type=checkbox]:checked:before {
  content: "\f00c";
  margin-bottom: -1px;
  color: #13aff0;
  font-weight: 600;
}

/*
Need to separate out the :not() selector from the rest of the CSS 2.1 selectors
since IE8 won't execute CSS that contains a CSS3 selector.
*/
form input:not([type]) {
  display: inline-block;
  padding: 5px 10px;
  border: 1px solid #ccc;
  border-radius: 4px;
  box-shadow: inset 0 1px 3px #ddd;
}

/* Chrome (as of v.32/34 on OS X) needs additional room for color to display. */
/* May be able to remove this tweak as color inputs become more standardized across browsers. */
form input[type=color] {
  padding: 5px 10px;
}

form input[type=text]:focus,
form input[type=password]:focus,
form input[type=email]:focus,
form input[type=url]:focus,
form input[type=date]:focus,
form input[type=month]:focus,
form input[type=time]:focus,
form input[type=datetime]:focus,
form input[type=datetime-local]:focus,
form input[type=week]:focus,
form input[type=number]:focus,
form input[type=search]:focus,
form input[type=tel]:focus,
form input[type=color]:focus,
form select:focus,
form textarea:focus {
  border-color: #bbb;
  outline: 0;
}

/*
Need to separate out the :not() selector from the rest of the CSS 2.1 selectors
since IE8 won't execute CSS that contains a CSS3 selector.
*/
form input:not([type]):focus {
  border-color: #bbb;
  outline: 0;
}

form input[type=file]:focus,
form input[type=radio]:focus,
form input[type=checkbox]:focus {
  outline: 0;
}

form input[type=checkbox],
form input[type=radio] {
  display: inline-block;
}

form input[type=text][disabled],
form input[type=password][disabled],
form input[type=email][disabled],
form input[type=url][disabled],
form input[type=date][disabled],
form input[type=month][disabled],
form input[type=time][disabled],
form input[type=datetime][disabled],
form input[type=datetime-local][disabled],
form input[type=week][disabled],
form input[type=number][disabled],
form input[type=search][disabled],
form input[type=tel][disabled],
form input[type=color][disabled],
form select[disabled],
form textarea[disabled] {
  cursor: not-allowed;
  color: #cad2d3;
  background-color: #eaeded;
}

/*
Need to separate out the :not() selector from the rest of the CSS 2.1 selectors
since IE8 won't execute CSS that contains a CSS3 selector.
*/
form input:not([type])[disabled] {
  cursor: not-allowed;
  color: #cad2d3;
  background-color: #eaeded;
}

form input[readonly],
form select[readonly],
form textarea[readonly] {
  color: #777; /* menu text color */
  border-color: #ccc;
  background-color: #eee; /* menu hover bg color */
}

form input:focus:invalid,
form textarea:focus:invalid,
form select:focus:invalid {
  color: #b94a48;
  border-color: #e9322d;
}

form input[type=file]:focus:invalid:focus,
form input[type=radio]:focus:invalid:focus,
form input[type=checkbox]:focus:invalid:focus {
  outline-color: #e9322d;
}

select {
  width: 100%;
  /* Normalizes the height; padding is not sufficient. */
  height: 2.25em;
  min-height: auto;
  border: 1px solid #ddd;
  background-color: white;
  cursor: pointer;
  padding: 0 15px;
  margin: 0;
}

form select[multiple] {
  height: auto;
}

form label {
  margin-bottom: 3px;
}

form fieldset {
  margin: 0;
  padding: 0.35em 0 0.75em;
  border: 0;
}

form legend {
  display: block;
  width: 100%;
  margin-bottom: 0.3em;
  padding: 0.3em 0;
  color: #333;
  border-bottom: 1px solid #e5e5e5;
}

/*csslint outline-none:false*/
input[type=button],
input[type=reset],
input[type=submit],
button[type=submit],
.button,
body div.wpforms-container-full .wpforms-form input[type=submit],
body div.wpforms-container-full .wpforms-form button[type=submit],
body div.wpforms-container-full .wpforms-form .wpforms-page-button {
  display: inline-block;
  font-family: inherit;
  background-color: #13aff0;
  color: #fff;
  font-size: 12px;
  font-weight: 600;
  text-transform: uppercase;
  margin: 0;
  padding: 14px 20px;
  border: 0;
  cursor: pointer;
  text-align: center;
  letter-spacing: 0.1em;
  line-height: 1;
  transition: all 0.3s ease;
}

input[type=button]:hover,
input[type=reset]:hover,
input[type=submit]:hover,
button[type=submit]:hover,
input[type=button]:focus,
input[type=reset]:focus,
input[type=submit]:focus,
button[type=submit]:focus,
.button:hover,
.button:focus,
body div.wpforms-container-full .wpforms-form input[type=submit]:hover,
body div.wpforms-container-full .wpforms-form button[type=submit]:hover,
body div.wpforms-container-full .wpforms-form .wpforms-page-button:hover {
  background-color: #0b7cac;
  color: #fff;
}

.elementor-form input[type=checkbox],
.elementor-form input[type=radio] {
  display: inline-block !important;
}

input[type=button]:focus,
input[type=reset]:focus,
input[type=submit]:focus,
button[type=submit]:focus,
button:focus {
  outline: 0;
}

.pure-button[disabled],
.pure-button-disabled,
.pure-button-disabled:hover,
.pure-button-disabled:focus,
.pure-button-disabled:active {
  cursor: not-allowed;
  -moz-opacity: 0.4;
  -webkit-opacity: 0.4;
  opacity: 0.4;
  border: none;
  background-image: none;
  box-shadow: none;
}

/* Firefox: Get rid of the inner focus border */
button::-moz-focus-inner,
input[type=button]::-moz-focus-inner,
input[type=reset]::-moz-focus-inner,
input[type=submit]::-moz-focus-inner {
  padding: 0;
  border: 0;
}

.pure-button-primary,
.pure-button-selected,
a.pure-button-primary,
a.pure-button-selected {
  color: #fff;
  background-color: rgb(0, 120, 231);
}

/* Comment checkbox */
.comment-form-cookies-consent {
  display: inline-block;
  width: 100%;
}
.comment-form-cookies-consent label {
  display: inline-block;
}

/*------------------------------------*
	$TOP BAR
*------------------------------------*/
#top-bar-wrap {
  position: relative;
  background-color: #fff;
  font-size: 12px;
  border-bottom: 1px solid #f1f1f1;
  z-index: 101;
}

#top-bar {
  padding: 8px 0;
}

#top-bar-inner {
  position: relative;
}

.top-bar-left {
  float: left;
}

.top-bar-right {
  float: right;
}

.top-bar-centered {
  float: none;
  text-align: center;
}

/*------------------------------------*
	Phone Portrait and Landscape
*------------------------------------*/
@media only screen and (max-width: 767px) {
  #top-bar {
    padding: 20px 0;
  }
  #top-bar > div:nth-child(2) {
    padding-top: 20px;
  }
  .top-bar-right {
    float: none;
    text-align: center;
  }
}
@media screen and (max-width: 782px) {
  #top-bar-wrap {
    z-index: 100;
  }
}
/**
 * Top Bar Content
 */
#top-bar-content strong {
  color: #333;
}
#top-bar-content > a {
  color: #555;
}
#top-bar-content > a:hover {
  color: #13aff0;
}
#top-bar-content select {
  background-color: transparent;
  padding: 5px;
  color: rgba(0, 0, 0, 0.4);
  border-color: rgba(0, 0, 0, 0.2);
  min-width: 100px;
}
#top-bar-content #lang_sel {
  position: relative;
  display: inline-block;
  top: 3px;
  margin-right: 10px;
  z-index: 99;
}

#topbar-template {
  display: inline-block;
}

#top-bar-wrap #lang_sel ul ul {
  z-index: 99999;
}

.top-bar-right .polylang-switcher-shortcode {
  float: right;
  margin: 0;
  margin-left: 20px;
}

.top-bar-left .polylang-switcher-shortcode {
  float: left;
  margin: 0;
  margin-right: 20px;
}

/*------------------------------------*
  Phone Portrait and Landscape
*------------------------------------*/
@media only screen and (max-width: 767px) {
  #top-bar-content, #top-bar-social-alt {
    float: none;
    text-align: center;
  }
  #top-bar #lang_sel {
    text-align: left;
  }
  body.rtl #top-bar #lang_sel {
    text-align: right;
  }
}
/**
 * Top Bar Menu
 */
.top-bar-left.has-content #top-bar-nav,
.top-bar-right.has-content #top-bar-nav {
  margin: 0;
  margin-right: 20px;
  padding: 0;
}

#top-bar-nav,
#top-bar-nav > li {
  display: inline-block;
}

#top-bar-content.top-bar-centered #top-bar-nav,
#top-bar-content.top-bar-centered #top-bar-nav > li {
  display: inline-block;
  float: none;
}

#top-bar-nav > ul > li {
  display: inline-block;
  float: none;
  margin-right: 15px;
}
#top-bar-nav > ul > li:last-child {
  margin-right: 0;
}
#top-bar-nav > ul > li a .nav-arrow {
  margin-left: 4px;
  margin-right: 0;
}

/*------------------------------------*
  Phone Portrait and Landscape
*------------------------------------*/
@media only screen and (max-width: 767px) {
  #top-bar #top-bar-nav > li {
    float: none;
    display: inline-block;
  }
  #top-bar-nav {
    float: none;
    text-align: center;
  }
}
/**
 * Top Bar Social
 */
#top-bar-social ul {
  margin: 0;
  padding: 0;
  list-style: none;
}
#top-bar-social li {
  float: left;
}
#top-bar-social li a {
  display: block;
  float: left;
  font-size: 14px;
  color: #bbb;
  padding: 0 6px;
}
#top-bar-social.top-bar-left li:first-child a {
  padding-left: 0;
}
#top-bar-social.top-bar-right li:last-child a {
  padding-right: 0;
}
#top-bar-social li a.oceanwp-twitter a:hover {
  color: #46d4fe;
}
#top-bar-social li a.oceanwp-facebook a:hover {
  color: #37589b;
}
#top-bar-social li a.oceanwp-googleplus a:hover {
  color: #de5a49;
}
#top-bar-social li a.oceanwp-pinterest a:hover {
  color: #cb2027;
}
#top-bar-social li a.oceanwp-dribbble a:hover {
  color: #ea4c89;
}
#top-bar-social li a.oceanwp-vk a:hover {
  color: #597BA5;
}
#top-bar-social li a.oceanwp-instagram a:hover {
  color: #3F729B;
}
#top-bar-social li a.oceanwp-linkedin a:hover {
  color: #3399CC;
}
#top-bar-social li a.oceanwp-tumblr a:hover {
  color: #2C4762;
}
#top-bar-social li a.oceanwp-github a:hover {
  color: #60b044;
}
#top-bar-social li a.oceanwp-flickr a:hover {
  color: #fa4086;
}
#top-bar-social li a.oceanwp-skype a:hover {
  color: #00AFF0;
}
#top-bar-social li a.oceanwp-youtube a:hover {
  color: #C4302B;
}
#top-bar-social li a.oceanwp-vimeo a:hover {
  color: #1ab7ea;
}
#top-bar-social li a.oceanwp-vine a:hover {
  color: #00bf8f;
}
#top-bar-social li a.oceanwp-xing a:hover {
  color: #006464;
}
#top-bar-social li a.oceanwp-yelp a:hover {
  color: #C41200;
}
#top-bar-social li a.oceanwp-tripadvisor a:hover {
  color: #589442;
}
#top-bar-social li a.oceanwp-rss a:hover {
  color: #ff7900;
}
#top-bar-social li a.oceanwp-email a:hover {
  color: #13aff0;
}

/**
 * Top Bar Social Right
 */
#top-bar-social.top-bar-right {
  position: absolute;
  right: 0;
  top: 50%;
  height: 20px;
  line-height: 20px;
  margin-top: -10px;
}

/**
 * Top Bar Social Left
 */
#top-bar-social.top-bar-left {
  position: absolute;
  left: 0;
  top: 50%;
  height: 20px;
  line-height: 20px;
  margin-top: -10px;
}

/**
 * Top Bar Social Centered
 */
#top-bar-social.top-bar-centered {
  padding-top: 15px;
}
#top-bar-social.top-bar-centered li {
  display: inline-block;
  float: none;
}

/*------------------------------------*
  Phone Portrait and Landscape
*------------------------------------*/
@media only screen and (max-width: 767px) {
  #top-bar-social {
    text-align: center;
  }
  #top-bar-social.top-bar-left, #top-bar-social.top-bar-right {
    position: inherit;
    left: auto;
    right: auto;
    float: none;
    height: auto;
    line-height: 1.5em;
    margin-top: 0;
  }
  #top-bar-social li {
    float: none;
    display: inline-block;
  }
}
/*------------------------------------*
	$HEADER
*------------------------------------*/
#site-header {
  position: relative;
  width: 100%;
  background-color: #fff;
  border-bottom: 1px solid #f1f1f1;
  z-index: 100;
}
#site-header.is-transparent {
  position: absolute;
  top: 0;
  background-color: transparent;
  height: auto;
  z-index: 9999;
}

#transparent-header-wrap {
  position: relative;
}

.has-transparent-header .oceanwp-sticky-header-holder {
  height: auto !important;
}
.has-transparent-header .is-sticky #site-header {
  background-color: #fff;
}

.no-header-border #site-header {
  border-bottom: none;
}

#site-header-inner {
  position: relative;
  height: 100%;
}

#site-logo {
  float: left;
  height: 100%;
  display: table;
}

#site-logo #site-logo-inner {
  display: table-cell;
  vertical-align: middle;
  height: 74px;
}
#site-logo #site-logo-inner a {
  background-color: transparent !important;
}
#site-logo #site-logo-inner a img {
  width: auto;
  vertical-align: middle;
  transition: all 0.3s ease-in-out;
}
#site-logo #site-logo-inner a:hover img {
  -moz-opacity: 0.6;
  -webkit-opacity: 0.6;
  opacity: 0.6;
}
#site-logo #site-logo-inner picture {
  display: inline-block;
}

#site-logo a.site-logo-text {
  font-size: 24px;
  margin: 0;
}

/* Responsive logo */
#site-logo.has-responsive-logo .responsive-logo-link {
  display: none;
}

/**
 * Header media
 */
#site-header.has-header-media > *:not(.overlay-header-media) {
  position: relative;
  z-index: 2;
}
#site-header.has-header-media .overlay-header-media {
  display: block;
  position: absolute;
  top: 0;
  left: 0;
  height: 100%;
  width: 100%;
  background-color: rgba(0, 0, 0, 0.3);
  z-index: 1;
}

/**
 * Video header
 */
#site-header .custom-header-media {
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  right: 0;
  overflow: hidden;
  width: 100%;
}
#site-header .custom-header-media:before {
  content: "";
  position: absolute;
  bottom: 0;
  left: 0;
  right: 0;
  display: block;
  height: 100%;
  z-index: 2;
  background: linear-gradient(to bottom, rgba(0, 0, 0, 0) 0%, rgba(0, 0, 0, 0.3) 75%, rgba(0, 0, 0, 0.3) 100%);
}
#site-header .custom-header-media video,
#site-header .custom-header-media iframe {
  position: absolute;
  height: auto;
  left: 50%;
  max-width: 1000%;
  min-height: 100%;
  min-width: 100%;
  min-width: 100vw;
  width: auto;
  top: 50%;
  -ms-transform: translateX(-50%) translateY(-50%);
  transform: translateX(-50%) translateY(-50%);
}
#site-header .custom-header-media .wp-custom-header-video-button {
  display: none;
}

.has-header-video #site-header-inner {
  z-index: 10;
}

/*------------------------------------*
	Fixed old Font Awesomes
*------------------------------------*/
#sidr .sidr-class-social-menu-inner .fa {
  font-family: "Font Awesome 5 Brands";
  font-weight: 400;
}

/*------------------------------------*
	All Devices under 960px
*------------------------------------*/
@media only screen and (max-width: 959px) {
  .has-left-menu #site-logo {
    padding: 0 !important;
  }
}
/*------------------------------------*
	Phone Portrait and Landscape
*------------------------------------*/
@media only screen and (max-width: 767px) {
  /* logo */
  #site-logo {
    margin-top: 0px !important;
    margin-bottom: 0px !important;
  }
}
#site-header.transparent-header {
  position: absolute;
  top: 0;
  background-color: transparent;
  height: auto;
  z-index: 9999;
}
#site-header.transparent-header #site-logo.has-transparent-logo .custom-logo-link {
  display: none;
}
#site-header.transparent-header #site-logo.has-transparent-logo .transparent-logo-link {
  display: block;
}

.is-sticky #site-header.transparent-header #site-logo.has-transparent-logo .custom-logo-link {
  display: block;
}
.is-sticky #site-header.transparent-header #site-logo.has-transparent-logo .transparent-logo-link {
  display: none;
}

#site-header.top-header {
  border-bottom: 0 !important;
}
#site-header.top-header .header-top {
  position: relative;
  background-color: #fff;
  box-shadow: 0 1px 5px 0 rgba(0, 0, 0, 0.1);
  z-index: 100;
}
#site-header.top-header .header-top .left {
  float: left;
}
#site-header.top-header .header-top .right {
  float: right;
}
#site-header.top-header .header-top .right .inner {
  display: table;
  position: relative;
}
#site-header.top-header #searchform-header-replace {
  background-color: #fff;
}
#site-header.top-header.header-replace .left, #site-header.top-header.header-replace .right {
  transition: opacity 0.25s ease-in-out;
}
#site-header.top-header.header-replace .left.hide, #site-header.top-header.header-replace .right.hide {
  visibility: hidden;
  -moz-opacity: 0;
  -webkit-opacity: 0;
  opacity: 0;
}
#site-header.top-header #site-navigation-wrap {
  float: none;
  right: auto !important;
  left: -15px;
}
#site-header.top-header #site-navigation-wrap .dropdown-menu > li > a {
  font-size: 10px;
  line-height: 40px;
  font-weight: 600;
  letter-spacing: 2px;
  text-transform: uppercase;
}
#site-header.top-header .oceanwp-social-menu,
#site-header.top-header #search-toggle {
  float: none;
  display: table-cell;
  vertical-align: middle;
  height: 40px;
}
#site-header.top-header .oceanwp-social-menu .social-menu-inner {
  display: block;
  height: auto;
}
#site-header.top-header .oceanwp-social-menu {
  right: 0;
  padding: 0 10px;
}
#site-header.top-header .oceanwp-social-menu .colored ul li a,
#site-header.top-header .oceanwp-social-menu .minimal ul li a,
#site-header.top-header .oceanwp-social-menu .dark ul li a {
  padding: 0 3px;
}
#site-header.top-header .oceanwp-social-menu .colored ul li a span,
#site-header.top-header .oceanwp-social-menu .minimal ul li a span,
#site-header.top-header .oceanwp-social-menu .dark ul li a span {
  width: 26px;
  height: 26px;
  line-height: 26px;
}
#site-header.top-header #search-toggle {
  border-right: 1px solid #f1f1f1;
  border-left: 1px solid #f1f1f1;
  padding: 0 6px;
}
#site-header.top-header #search-toggle a {
  display: inline-block;
  font-size: 12px;
  width: 28px;
  text-align: center;
}
#site-header.top-header.search-overlay #search-toggle .search-overlay-toggle {
  position: relative;
  z-index: 101;
}
#site-header.top-header.search-overlay #search-toggle .search-overlay-toggle.exit > span:before {
  content: "✕";
  color: #fff;
}
#site-header.top-header #searchform-header-replace input {
  color: #222;
  font-size: 10px;
  font-weight: 600;
  text-transform: uppercase;
  letter-spacing: 2px;
}
#site-header.top-header #searchform-header-replace-close {
  font-size: 16px;
  padding: 0 6px;
}
#site-header.top-header .header-bottom {
  text-align: center;
}
#site-header.top-header #site-logo {
  float: none;
  display: inline-block;
  padding: 50px 0;
}
#site-header.top-header #site-logo #site-logo-inner {
  display: block;
  height: auto;
}
#site-header.top-header #site-logo #site-description {
  padding-top: 20px;
}
#site-header.top-header #site-logo #site-description h2 {
  color: #929292;
  font-size: 12px;
  line-height: 20px;
  letter-spacing: 2px;
  text-transform: uppercase;
  margin: 0;
}

#site-header.top-header .oceanwp-mobile-menu-icon {
  float: none;
  left: -15px;
  right: auto;
}
#site-header.top-header .oceanwp-mobile-menu-icon a {
  font-size: 10px;
  line-height: 40px;
  font-weight: 600;
  letter-spacing: 2px;
  text-transform: uppercase;
}

#site-header.top-header.has-header-media #site-header-sticky-wrapper,
#site-header.top-header.has-header-media .header-top {
  z-index: 101;
}

/*------------------------------------*
	All Devices under 960px
*------------------------------------*/
@media only screen and (max-width: 959px) {
  /* Hide social and search form in sidr for the top menu header style */
  .top-header-style .sidr-class-social-menu-inner,
.top-header-style .sidr-class-mobile-searchform {
    display: none;
  }
}
/*------------------------------------*
	Phone Landscape
*------------------------------------*/
@media only screen and (max-width: 480px) {
  /* Hide social and search in menu and show them in sidr for the top menu header style */
  #site-header.top-header .right {
    display: none;
  }
  #site-header.top-header.header-replace .left.hide,
#site-header.top-header.header-replace .right.hide {
    visibility: visible;
    -moz-opacity: 1;
    -webkit-opacity: 1;
    opacity: 1;
  }
  #site-header.top-header .header-top .left,
#site-header.top-header .header-top .right {
    float: none !important;
    text-align: center;
  }
  #site-header.top-header .oceanwp-mobile-menu-icon {
    float: none;
    left: auto !important;
    right: auto !important;
  }
  #site-header.top-header .oceanwp-mobile-menu-icon a {
    float: none;
  }
  #site-header.top-header .header-top .right .inner {
    display: block;
    padding-bottom: 10px;
  }
  #site-header.top-header .oceanwp-social-menu,
#site-header.top-header #search-toggle {
    float: none;
    display: inline-block;
    height: auto;
  }
  .top-header-style .sidr-class-social-menu-inner,
.top-header-style .sidr-class-mobile-searchform {
    display: block;
  }
}
#site-header.full_screen-header {
  z-index: 9999;
}
#site-header.full_screen-header #site-header-inner {
  overflow: visible !important;
}
#site-header.full_screen-header #site-navigation-wrap {
  right: 0;
}
#site-header.full_screen-header #site-logo.has-full-screen-logo {
  position: relative;
  z-index: 101;
}
#site-header.full_screen-header #site-logo.has-full-screen-logo .full-screen-logo-link {
  display: none;
}
#site-header.full_screen-header #site-logo.has-full-screen-logo.opened .custom-logo-link, #site-header.full_screen-header #site-logo.has-full-screen-logo.opened .retina-logo-link {
  display: none;
}
#site-header.full_screen-header #site-logo.has-full-screen-logo.opened .full-screen-logo-link {
  display: block;
}
#site-header.full_screen-header .menu-bar-wrap {
  float: right;
  height: 100%;
  display: table;
}
#site-header.full_screen-header .menu-bar-inner {
  display: table-cell;
  vertical-align: middle;
  position: relative;
  height: 74px;
}
#site-header.full_screen-header .menu-bar {
  display: inline-block;
  position: relative;
  margin-left: 10px;
  min-width: 38px;
  height: 33px;
  text-align: center;
  z-index: 101;
}
#site-header.full_screen-header .menu-bar .ham {
  display: inline-block;
  width: 23px;
  height: 2px;
  position: relative;
  top: 2px;
  background-color: #333;
  vertical-align: middle;
  white-space: nowrap;
  transition: all ease 0.3s;
}
#site-header.full_screen-header .menu-bar .ham:before, #site-header.full_screen-header .menu-bar .ham:after {
  position: absolute;
  content: "";
  display: inline-block;
  width: 23px;
  height: 2px;
  left: 0;
  background-color: #333;
  outline: 1px solid transparent;
  transition: all ease 0.3s;
}
#site-header.full_screen-header .menu-bar .ham:before {
  top: -8px;
}
#site-header.full_screen-header .menu-bar .ham:after {
  top: 8px;
}
#site-header.full_screen-header .menu-bar.exit .ham {
  background-color: transparent !important;
}
#site-header.full_screen-header .menu-bar.exit .ham:before, #site-header.full_screen-header .menu-bar.exit .ham:after {
  background-color: #fff;
}
#site-header.full_screen-header .menu-bar.exit .ham:before {
  -ms-transform: translateY(8px) rotateZ(-45deg);
  transform: translateY(8px) rotateZ(-45deg);
}
#site-header.full_screen-header .menu-bar.exit .ham:after {
  -ms-transform: translateY(-8px) rotateZ(45deg);
  transform: translateY(-8px) rotateZ(45deg);
}
#site-header.full_screen-header.nav-open {
  -ms-transform: none !important;
  transform: none !important;
}
#site-header.full_screen-header #full-screen-menu {
  display: none;
  position: fixed;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  background-color: rgba(0, 0, 0, 0.9);
  overflow-y: scroll;
  z-index: 100;
}
#site-header.full_screen-header #full-screen-menu #full-screen-menu-inner {
  display: table;
  width: 100%;
  height: 100%;
  padding: 0 40px;
}
#site-header.full_screen-header #full-screen-menu #site-navigation {
  display: table-cell;
  vertical-align: middle;
  padding: 100px 0;
  text-align: center;
}
#site-header.full_screen-header .fs-dropdown-menu {
  list-style: none;
  margin: 0;
}
#site-header.full_screen-header .fs-dropdown-menu li a {
  display: block;
  color: #fff;
  letter-spacing: 2px;
  text-transform: uppercase;
}
#site-header.full_screen-header .fs-dropdown-menu li a:hover {
  color: #929292;
}
#site-header.full_screen-header .fs-dropdown-menu li a:focus {
  outline: 1px dashed rgba(255, 255, 255, 0.3);
}
#site-header.full_screen-header .fs-dropdown-menu li > a .nav-arrow {
  display: inline-block;
  width: 26px;
  padding-left: 5px;
  text-align: center;
}
#site-header.full_screen-header .fs-dropdown-menu li > a .nav-arrow:before {
  content: "+";
}
#site-header.full_screen-header .fs-dropdown-menu li > a .nav-arrow:focus {
  outline: 1px dashed rgba(255, 255, 255, 0.3);
}
#site-header.full_screen-header .fs-dropdown-menu li.open-sub > a .nav-arrow:before {
  content: "-";
}
#site-header.full_screen-header .fs-dropdown-menu li .sidebar-box {
  display: none;
}
#site-header.full_screen-header .fs-dropdown-menu ul.sub-menu {
  display: none;
  list-style: none;
  margin: 0;
  padding: 0;
}
#site-header.full_screen-header .fs-dropdown-menu ul.sub-menu li a {
  font-size: 16px;
  padding: 6px 0;
}
#site-header.full_screen-header .fs-dropdown-menu > li {
  display: block;
}
#site-header.full_screen-header .fs-dropdown-menu > li > a {
  font-size: 24px;
  line-height: 1.2;
  padding: 12px 0;
}
#site-header.full_screen-header .fs-dropdown-menu > li.search-toggle-li {
  max-width: 220px;
  margin: 10px auto 0;
}
#site-header.full_screen-header .fs-dropdown-menu > li.search-toggle-li form {
  position: relative;
}
#site-header.full_screen-header .fs-dropdown-menu > li.search-toggle-li input,
#site-header.full_screen-header .fs-dropdown-menu > li.search-toggle-li .search-text {
  font-size: 20px;
  padding: 4px 0;
  color: #fff;
  margin: 0;
  text-align: center;
  text-transform: uppercase;
}
#site-header.full_screen-header .fs-dropdown-menu > li.search-toggle-li input {
  position: relative;
  border: 0;
  background-color: transparent;
  border-bottom: 1px solid #666;
  border-radius: 0;
  z-index: 2;
}
#site-header.full_screen-header .fs-dropdown-menu > li.search-toggle-li input:hover, #site-header.full_screen-header .fs-dropdown-menu > li.search-toggle-li input:focus {
  border-color: #fff;
}
#site-header.full_screen-header .fs-dropdown-menu > li.search-toggle-li .search-text {
  display: block;
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  right: 0;
  cursor: text;
  -moz-opacity: 0.5;
  -webkit-opacity: 0.5;
  opacity: 0.5;
  z-index: 1;
}
#site-header.full_screen-header .fs-dropdown-menu > li.search-toggle-li .search-text i {
  display: inline-block;
  background-color: #fff;
  width: 3px;
  height: 3px;
  margin-left: 3px;
  animation: blink 1s linear infinite;
}
#site-header.full_screen-header .fs-dropdown-menu > li.search-toggle-li .search-text i + i {
  animation-delay: 0.2s;
}
#site-header.full_screen-header .fs-dropdown-menu > li.search-toggle-li .search-text i + i + i {
  animation-delay: 0.4s;
}
#site-header.full_screen-header .fs-dropdown-menu > li.search-toggle-li form.search-filled .search-text {
  -moz-opacity: 0;
  -webkit-opacity: 0;
  opacity: 0;
  transition-duration: 150ms;
}
#site-header.full_screen-header .oceanwp-social-menu {
  display: block;
  float: none;
  margin-top: 30px;
  text-align: center;
  right: auto;
}
#site-header.full_screen-header .oceanwp-social-menu .social-menu-inner {
  display: block;
  height: auto !important;
}
#site-header.full_screen-header .oceanwp-social-menu ul li {
  float: none;
  display: inline-block;
}
#site-header.full_screen-header .oceanwp-social-menu.simple-social ul li a {
  background-color: transparent !important;
  color: #fff;
  font-size: 24px;
  padding: 0 16px;
  margin: 0;
}
#site-header.full_screen-header .oceanwp-social-menu.simple-social ul li a:hover {
  color: #929292;
}
#site-header.full_screen-header .oceanwp-social-menu .colored ul li a,
#site-header.full_screen-header .oceanwp-social-menu .minimal ul li a,
#site-header.full_screen-header .oceanwp-social-menu .dark ul li a {
  padding: 0 4px;
}
#site-header.full_screen-header .oceanwp-social-menu .colored ul li a span,
#site-header.full_screen-header .oceanwp-social-menu .minimal ul li a span,
#site-header.full_screen-header .oceanwp-social-menu .dark ul li a span {
  font-size: 16px;
  width: 60px;
  height: 60px;
  line-height: 60px;
}
@keyframes blink {
  0% {
    opacity: 1;
  }
  50% {
    opacity: 0;
  }
  100% {
    opacity: 1;
  }
}
/*------------------------------------*
	All Devices under 960px
*------------------------------------*/
@media only screen and (max-width: 959px) {
  /* header > logo */
  #site-header.full_screen-header #site-logo.has-full-screen-logo.opened .custom-logo-link {
    display: block;
  }
  #site-header.full_screen-header #site-logo.has-full-screen-logo.opened .full-screen-logo-link {
    display: none;
  }
}
#site-header.center-header #site-logo {
  display: none;
}
#site-header.center-header #site-navigation-wrap {
  float: none;
  width: 100%;
  right: auto;
}
#site-header.center-header #site-navigation-wrap .navigation {
  display: -ms-flexbox;
  display: flex;
  -ms-flex-align: center;
      align-items: center;
}
#site-header.center-header #site-navigation-wrap .middle-site-logo {
  width: 24%;
  text-align: center;
}
#site-header.center-header #site-navigation-wrap .middle-site-logo a img {
  width: auto;
  vertical-align: middle;
  transition: all 0.3s ease-in-out;
}
#site-header.center-header #site-navigation-wrap .middle-site-logo:hover img {
  -moz-opacity: 0.6;
  -webkit-opacity: 0.6;
  opacity: 0.6;
}
#site-header.center-header #site-navigation-wrap .left-menu,
#site-header.center-header #site-navigation-wrap .right-menu {
  position: relative;
  width: 38%;
}
#site-header.center-header #site-navigation-wrap .left-menu {
  float: left;
}
#site-header.center-header #site-navigation-wrap .right-menu {
  float: right;
}
#site-header.center-header #site-navigation-wrap .dropdown-menu > li {
  float: none;
  display: inline-block;
}
#site-header.center-header .centered .left-menu,
#site-header.center-header .centered .right-menu {
  text-align: center;
}
#site-header.center-header .wider .left-menu {
  text-align: left;
}
#site-header.center-header .wider .right-menu {
  text-align: right;
}
#site-header.center-header .closer .left-menu {
  text-align: right;
}
#site-header.center-header .closer .right-menu {
  text-align: left;
}
#site-header.center-header #searchform-header-replace.show {
  max-width: 100% !important;
}
#site-header.center-header.header-replace #site-navigation .middle-site-logo {
  transition: opacity 0.3s;
}
#site-header.center-header.header-replace #site-navigation.hide .middle-site-logo {
  visibility: hidden;
  -moz-opacity: 0;
  -webkit-opacity: 0;
  opacity: 0;
}

#site-header.medium-header {
  background-color: transparent;
  text-align: center;
}
#site-header.medium-header .top-header-wrap {
  position: relative;
  background-color: #fff;
  padding: 30px 0;
  transition: padding 0.4s ease-in-out;
  z-index: 10;
}
#site-header.medium-header .top-header-inner {
  display: -ms-flexbox;
  display: flex;
  -ms-flex-direction: row;
      flex-direction: row;
  -ms-flex-align: center;
      align-items: center;
  -ms-flex-pack: center;
      justify-content: center;
  width: 100%;
  margin: 0;
}
#site-header.medium-header .top-col {
  -ms-flex: 1 0 0%;
      flex: 1 0 0%;
}
#site-header.medium-header .top-col.col-1 {
  text-align: left;
}
#site-header.medium-header .top-col.col-2, #site-header.medium-header .top-col.logo-col {
  text-align: center;
}
#site-header.medium-header .top-col.col-3 {
  text-align: right;
}
#site-header.medium-header #medium-searchform form {
  display: inline-block;
  position: relative;
}
#site-header.medium-header #medium-searchform form.search-filled label {
  -moz-opacity: 0;
  -webkit-opacity: 0;
  opacity: 0;
  transition-duration: 150ms;
}
#site-header.medium-header #medium-searchform input {
  position: relative;
  background-color: transparent !important;
  border: 0;
  margin: 0;
  padding: 6px 38px 6px 12px;
  max-width: 178px;
  z-index: 2;
}
#site-header.medium-header #medium-searchform input:focus {
  max-width: 220px;
}
#site-header.medium-header #medium-searchform label,
#site-header.medium-header #medium-searchform button {
  position: absolute;
  top: 0;
  line-height: 40px;
  margin: 0;
}
#site-header.medium-header #medium-searchform button:focus {
  outline: 1px solid;
}
#site-header.medium-header #medium-searchform label {
  left: 12px;
  color: #333;
  cursor: text;
  -moz-opacity: 0.5;
  -webkit-opacity: 0.5;
  opacity: 0.5;
  z-index: 1;
}
#site-header.medium-header #medium-searchform button {
  right: 0;
  width: 38px;
  background-color: transparent;
  color: #555;
  border: 0;
  padding: 0;
  z-index: 2;
  transition: all 0.3s ease;
}
#site-header.medium-header #medium-searchform button:hover {
  color: #13aff0;
}
#site-header.medium-header #medium-searchform .search-bg {
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  right: 0;
  background-color: #f5f5f5;
}
#site-header.medium-header #site-logo {
  float: none;
  display: block;
}
#site-header.medium-header #site-logo #site-logo-inner {
  display: block;
  height: auto !important;
}
#site-header.medium-header .oceanwp-social-menu {
  float: none;
  display: block;
  right: auto !important;
  left: auto !important;
}
#site-header.medium-header .oceanwp-social-menu .social-menu-inner {
  display: block;
  height: auto !important;
}
#site-header.medium-header .oceanwp-social-menu ul li {
  float: none;
  display: inline-block;
}
#site-header.medium-header #site-navigation-wrap {
  position: relative;
  background-color: #f9f9f9;
  float: none;
  position: relative;
  right: auto !important;
  left: auto !important;
  -ms-transform: none;
  transform: none;
  z-index: 9;
}
#site-header.medium-header #site-navigation-wrap.left-menu #site-navigation {
  float: left;
  left: -22px;
}
#site-header.medium-header #site-navigation-wrap.center-menu #site-navigation .dropdown-menu > li {
  float: none;
  display: inline-block;
}
#site-header.medium-header #site-navigation-wrap.right-menu #site-navigation {
  float: right;
  right: -22px;
}
#site-header.medium-header #site-navigation-wrap #site-navigation {
  display: inline-block;
  position: relative;
}
#site-header.medium-header #site-navigation-wrap .dropdown-menu > li > a {
  font-size: 12px;
  line-height: 60px;
  padding: 0 22px;
  text-transform: uppercase;
  letter-spacing: 1px;
}
#site-header.medium-header.hidden-menu #site-navigation-wrap,
#site-header.medium-header.hidden-menu #site-navigation,
#site-header.medium-header.hidden-menu .oceanwp-mobile-menu-icon {
  max-height: 150px;
  transition: all 0.4s ease-in-out;
}

.is-sticky #site-header.medium-header .top-header-wrap {
  padding: 20px 0;
}
.is-sticky #site-header.medium-header .top-header-wrap .oceanwp-social-menu .social-menu-inner {
  height: auto;
}
.is-sticky #site-header.medium-header.hidden-menu #site-navigation-wrap,
.is-sticky #site-header.medium-header.hidden-menu #site-navigation,
.is-sticky #site-header.medium-header.hidden-menu .oceanwp-mobile-menu-icon {
  max-height: 0;
  -moz-opacity: 0;
  -webkit-opacity: 0;
  opacity: 0;
  visibility: hidden;
}
.is-sticky #site-header.medium-header.hidden-menu:hover #site-navigation-wrap,
.is-sticky #site-header.medium-header.hidden-menu:hover #site-navigation,
.is-sticky #site-header.medium-header.hidden-menu:hover .oceanwp-mobile-menu-icon {
  max-height: 150px;
  -moz-opacity: 1;
  -webkit-opacity: 1;
  opacity: 1;
  visibility: visible;
}

#site-header.medium-header .oceanwp-mobile-menu-icon {
  float: none;
  background-color: #f9f9f9;
  right: auto !important;
  left: auto !important;
}
#site-header.medium-header .oceanwp-mobile-menu-icon a {
  float: none;
  display: inline-block;
  font-size: 12px;
  padding: 0 22px;
  line-height: 60px;
  letter-spacing: 1px;
  text-transform: uppercase;
}

#site-header.medium-header.is-transparent .top-header-wrap,
#site-header.medium-header.is-transparent #site-navigation-wrap,
#site-header.medium-header.is-transparent .oceanwp-mobile-menu-icon {
  background-color: transparent;
  transition: all 0.3s;
}

/*------------------------------------*
	All Devices under 960px
*------------------------------------*/
@media only screen and (max-width: 959px) {
  /* Hide social and search form in sidr for the medium header style */
  .medium-header-style .sidr-class-social-menu-inner,
.medium-header-style .sidr-class-mobile-searchform {
    display: none;
  }
}
/*------------------------------------*
	Phone Portrait and Landscape
*------------------------------------*/
@media only screen and (max-width: 767px) {
  #site-header.medium-header .top-header-inner {
    display: block;
  }
  #site-header.medium-header .top-col:not(.logo-col) {
    display: none;
  }
  #site-header.medium-header .top-col.logo-col {
    display: inline-block;
    text-align: center;
  }
  /* Show social and search form in sidr for the medium header style */
  .medium-header-style .sidr-class-social-menu-inner,
.medium-header-style .sidr-class-mobile-searchform {
    display: block;
  }
}
/*------------------------------------*
	Phone Landscape
*------------------------------------*/
@media only screen and (max-width: 480px) {
  /* medium header style */
  #site-header.medium-header .header-top-wrap {
    padding: 20px 0;
  }
  #site-header.medium-header .oceanwp-mobile-menu-icon a {
    line-height: 40px;
  }
}
#site-header.vertical-header {
  position: fixed;
  top: 0;
  width: 300px;
  max-width: 100%;
  height: 100%;
  border-bottom: none;
  z-index: 3000;
  transition: all 0.3s ease-in-out;
}
#site-header.vertical-header .ps__rail-y {
  padding: 0 !important;
  width: 0;
}
#site-header.vertical-header.has-scrolled {
  background-color: #fff;
}
#site-header.vertical-header.has-shadow {
  box-shadow: 0 0 20px 0 rgba(0, 0, 0, 0.1);
}
#site-header.vertical-header .ps__thumb-y {
  background-color: transparent;
}
#site-header.vertical-header .has-template > #site-logo {
  display: none;
}
#site-header.vertical-header #site-header-inner {
  max-width: 100%;
  padding: 30px 0;
  overflow: hidden;
}
#site-header.vertical-header #site-header-inner > *:not(#site-navigation-wrap) {
  padding: 0 30px;
}
#site-header.vertical-header #site-header-inner #sidr {
  display: block;
}
#site-header.vertical-header.vh-left-logo #site-logo {
  text-align: left;
}
#site-header.vertical-header.vh-center-logo #site-logo {
  text-align: center;
}
#site-header.vertical-header.vh-right-logo #site-logo {
  text-align: right;
}
#site-header.vertical-header #site-logo,
#site-header.vertical-header #site-logo #site-logo-inner {
  display: block;
  float: none;
  height: auto;
}
#site-header.vertical-header #site-logo {
  margin: 20px 0 45px;
}
#site-header.vertical-header #site-logo a:focus {
  outline: 1px dashed rgba(0, 0, 0, 0.3);
}
#site-header.vertical-header .has-social #site-navigation-wrap {
  right: auto;
}
#site-header.vertical-header #site-navigation-wrap {
  float: none;
  right: auto;
  transition: all 0.3s ease-in-out;
}
#site-header.vertical-header #site-navigation-wrap .dropdown-menu li {
  display: block;
  float: none;
  position: relative;
  border-bottom: 1px solid rgba(0, 0, 0, 0.05);
}
#site-header.vertical-header #site-navigation-wrap .dropdown-menu li:last-child {
  border-bottom: none;
}
#site-header.vertical-header #site-navigation-wrap .dropdown-menu li > a {
  position: relative;
  line-height: 1;
  padding: 17px 30px;
}
#site-header.vertical-header #site-navigation-wrap .dropdown-menu li > a:focus {
  outline: 1px dashed rgba(0, 0, 0, 0.3);
}
#site-header.vertical-header #site-navigation-wrap .dropdown-menu li > a .dropdown-toggle {
  position: absolute;
  right: 0;
  top: 0;
  width: 50px;
  height: 100%;
  line-height: 1;
  cursor: pointer;
  text-align: center;
}
#site-header.vertical-header #site-navigation-wrap .dropdown-menu li > a .dropdown-toggle:focus {
  outline: 1px dashed rgba(0, 0, 0, 0.3);
}
#site-header.vertical-header #site-navigation-wrap .dropdown-menu li > a .dropdown-toggle:before {
  content: "+";
  font-size: 20px;
  position: absolute;
  top: 50%;
  left: 50%;
  line-height: 1;
  margin-top: -10px;
  margin-left: -10px;
}
#site-header.vertical-header #site-navigation-wrap .dropdown-menu li.active > a > .dropdown-toggle:before {
  content: "-";
}
#site-header.vertical-header #site-navigation-wrap .dropdown-menu .sub-menu {
  display: none;
  position: relative;
  top: 100%;
  left: 0;
  background-color: rgba(0, 0, 0, 0.03);
  border: none;
  border-top: 1px solid rgba(0, 0, 0, 0.05);
  box-shadow: none;
}
#site-header.vertical-header #site-navigation-wrap .nav-arrow,
#site-header.vertical-header #site-navigation-wrap .sidebar-box {
  display: none;
}
#site-header.vertical-header #vertical-searchform {
  margin-top: 40px;
}
#site-header.vertical-header #vertical-searchform form {
  position: relative;
}
#site-header.vertical-header #vertical-searchform form.search-filled label {
  -moz-opacity: 0;
  -webkit-opacity: 0;
  opacity: 0;
  transition-duration: 150ms;
}
#site-header.vertical-header #vertical-searchform form input {
  position: relative;
  font-size: 14px;
  border-width: 0 0 2px;
  background-color: transparent !important;
  border-color: rgba(0, 0, 0, 0.04);
  padding: 10px 12px;
  z-index: 2;
}
#site-header.vertical-header #vertical-searchform form label,
#site-header.vertical-header #vertical-searchform form button {
  position: absolute;
  top: 50%;
  margin: 0;
  -ms-transform: translateY(-50%);
  transform: translateY(-50%);
}
#site-header.vertical-header #vertical-searchform form label:focus,
#site-header.vertical-header #vertical-searchform form button:focus {
  outline: 1px dashed rgba(0, 0, 0, 0.3);
}
#site-header.vertical-header #vertical-searchform form label {
  left: 12px;
  cursor: text;
  -moz-opacity: 0.5;
  -webkit-opacity: 0.5;
  opacity: 0.5;
  z-index: 1;
}
#site-header.vertical-header #vertical-searchform form button {
  right: 0;
  width: 50px;
  height: 100%;
  line-height: 1;
  padding: 0;
  background-color: transparent;
  color: #777;
  border: none;
  z-index: 2;
  transition: all 0.3s ease;
}
#site-header.vertical-header #vertical-searchform form button:hover {
  color: #333;
}
#site-header.vertical-header #vertical-searchform form .search-bg {
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  right: 0;
  background-color: rgba(0, 0, 0, 0.03);
}
#site-header.vertical-header .oceanwp-social-menu {
  float: none;
  display: block;
  margin-top: 40px;
}
#site-header.vertical-header .oceanwp-social-menu.simple-social {
  right: auto;
}
#site-header.vertical-header .oceanwp-social-menu .social-menu-inner {
  display: block;
  height: auto;
}
#site-header.vertical-header .custom-header-nav #site-navigation-wrap #site-navigation {
  display: block;
}
#site-header.vertical-header .custom-header-nav #site-navigation-wrap #site-navigation .dropdown-menu > li > a {
  padding-left: 0;
  padding-right: 0;
}
#site-header.vertical-header .vertical-toggle {
  display: none;
  position: absolute;
  top: 10px;
  width: 34px;
  height: 34px;
  font-size: 22px;
  line-height: 34px;
  padding: 0 !important;
  text-align: center;
}

.has-vh-transparent .is-sticky #site-header.vertical-header {
  background-color: #fff;
}

body.vertical-header-style.left-header #site-header.vertical-header {
  left: 0;
}
body.vertical-header-style.left-header #site-header.vertical-header .vertical-toggle {
  right: 0;
}
body.vertical-header-style.left-header #outer-wrap {
  margin-left: 300px;
}
body.vertical-header-style.right-header #site-header.vertical-header {
  right: 0;
}
body.vertical-header-style.right-header #site-header.vertical-header .vertical-toggle {
  left: 0;
}
body.vertical-header-style.right-header #outer-wrap {
  margin-right: 300px;
}
body.vertical-header-style.has-vh-transparent.left-header #outer-wrap {
  margin-left: 0;
}
body.vertical-header-style.has-vh-transparent.right-header #outer-wrap {
  margin-right: 0;
}
body.vertical-header-style.vh-closed.left-header #site-header.vertical-header {
  left: -266px;
}
body.vertical-header-style.vh-closed.left-header #outer-wrap {
  margin-left: 34px;
}
body.vertical-header-style.vh-closed.right-header #site-header.vertical-header {
  right: -266px;
}
body.vertical-header-style.vh-closed.right-header #outer-wrap {
  margin-right: 34px;
}
body.vertical-header-style.vh-closed.vh-opened.left-header #site-header.vertical-header {
  left: 0;
}
body.vertical-header-style.vh-closed.vh-opened.right-header #site-header.vertical-header {
  right: 0;
}
body.vertical-header-style.vh-closed.vh-opened #site-header.vertical-header #site-navigation-wrap {
  padding-right: 0;
}
body.vertical-header-style.vh-closed #site-header.vertical-header .vertical-toggle {
  display: block;
}
body.vertical-header-style.vh-closed #site-header.vertical-header #site-navigation-wrap {
  padding-right: 34px;
}

/*------------------------------------*
	All Devices under 1280px
*------------------------------------*/
@media only screen and (max-width: 1280px) {
  body.vertical-header-style.default-collapse.left-header #site-header.vertical-header {
    left: -266px;
  }
  body.vertical-header-style.default-collapse.left-header #outer-wrap {
    margin-left: 34px;
  }
  body.vertical-header-style.default-collapse.right-header #site-header.vertical-header {
    right: -266px;
  }
  body.vertical-header-style.default-collapse.right-header #outer-wrap {
    margin-right: 34px;
  }
  body.vertical-header-style.default-collapse.vh-opened.left-header #site-header.vertical-header {
    left: 0;
  }
  body.vertical-header-style.default-collapse.vh-opened.right-header #site-header.vertical-header {
    right: 0;
  }
  body.vertical-header-style.default-collapse.vh-opened #site-header.vertical-header #site-navigation-wrap {
    padding-right: 0;
  }
  body.default-collapse #site-header.vertical-header .vertical-toggle {
    display: block;
  }
  body.default-collapse #site-header.vertical-header #site-navigation-wrap {
    padding-right: 34px;
  }
}
#site-header.custom-header ul.oceanwp-custom-menu {
  list-style: none;
  margin: 0;
  padding: 0;
}
#site-header.custom-header ul.oceanwp-custom-menu li {
  display: inline-block;
}
#site-header.custom-header ul.oceanwp-custom-menu li a {
  display: block;
  font-size: 13px;
  line-height: 40px;
  padding: 0 15px;
  letter-spacing: 0.6px;
}

.custom-header-logo.left {
  text-align: left;
}
.custom-header-logo.right {
  text-align: right;
}
.custom-header-logo.center {
  text-align: center;
}
.custom-header-logo #site-logo {
  float: none;
  display: inline-block;
}
.custom-header-logo #site-logo #site-logo-inner {
  display: block;
  height: auto !important;
}

.custom-header-nav.left {
  text-align: left;
}
.custom-header-nav.right {
  text-align: right;
}
.custom-header-nav.center {
  text-align: center;
}
.custom-header-nav #site-navigation-wrap {
  float: none;
  right: auto;
}
.custom-header-nav #site-navigation-wrap #site-navigation {
  display: inline-block;
  position: relative;
}
.custom-header-nav #site-navigation-wrap .dropdown-menu > li {
  float: none;
  display: inline-block;
}
.custom-header-nav .oceanwp-mobile-menu-icon {
  float: none !important;
}
.custom-header-nav .oceanwp-mobile-menu-icon a {
  display: inline-block;
}

/*------------------------------------*
	$NAVIGATIONS
*------------------------------------*/
#site-navigation-wrap {
  float: right;
  position: relative;
  right: -15px;
}
#site-navigation-wrap .dropdown-menu {
  list-style: none;
  margin: 0;
  padding: 0;
}
#site-navigation-wrap .dropdown-menu > li {
  float: left;
  position: relative;
}
#site-navigation-wrap .dropdown-menu > li > a {
  display: block;
  font-size: 13px;
  line-height: 74px;
  color: #555;
  padding: 0 15px;
  letter-spacing: 0.6px;
}
#site-navigation-wrap .dropdown-menu > li > a.site-search-toggle {
  letter-spacing: 0;
}
#site-navigation-wrap .dropdown-menu > li > a:hover {
  color: #13aff0;
}
#site-navigation-wrap .dropdown-menu > li > a .nav-arrow {
  padding-left: 6px;
  line-height: 1;
}
#site-navigation-wrap .dropdown-menu > li.btn > a {
  background-color: transparent !important;
}
#site-navigation-wrap .dropdown-menu > li.btn > a > span {
  background-color: #13aff0;
  color: #fff;
  padding: 12px 22px;
  font-weight: 600;
  border-radius: 4px;
  cursor: pointer;
  text-align: center;
  transition: background-color 0.3s ease;
}
#site-navigation-wrap .dropdown-menu > li.btn > a > span:before, #site-navigation-wrap .dropdown-menu > li.btn > a > span:after {
  display: none !important;
}
#site-navigation-wrap .dropdown-menu > li.btn > a:hover > span {
  background-color: #0b7cac;
  color: #fff;
}
#site-navigation-wrap .dropdown-menu > li.btn.rounded > a > span {
  border-radius: 25px;
}

.has-social #site-navigation-wrap {
  right: 0;
}

.minimal-header.left-menu #site-navigation-wrap,
.transparent-header.left-menu #site-navigation-wrap {
  float: left;
  right: 0;
}

.minimal-header.left-menu #site-logo,
.transparent-header.left-menu #site-logo {
  padding-right: 20px;
}

.center-menu #site-navigation-wrap {
  position: absolute;
  float: none;
  left: 50%;
  right: auto;
  -ms-transform: translateX(-50%);
  transform: translateX(-50%);
}

/**
 * SuperFish
 */
.sf-menu,
.sf-menu * {
  margin: 0;
  padding: 0;
  list-style: none;
}

.sf-menu li.menu-item {
  position: relative;
  white-space: nowrap;
  white-space: normal;
}
.sf-menu li:hover,
.sf-menu li.sfHover {
  transition: none;
}
.sf-menu ul.sub-menu {
  position: absolute;
  visibility: hidden;
  top: 100%;
  left: 0;
  z-index: 9999;
}
.sf-menu > li {
  float: left;
}
.sf-menu li:hover > ul,
.sf-menu li.sfHover > ul {
  display: block;
}
.sf-menu a.menu-link {
  display: block;
  position: relative;
  zoom: 1;
}
.sf-menu ul.sub-menu ul {
  top: 0;
  left: 100%;
  visibility: visible;
}

/**
 * Dropdown
 */
.dropdown-menu,
.dropdown-menu * {
  margin: 0;
  padding: 0;
  list-style: none;
}

.dropdown-menu .sub-menu {
  display: none;
  position: absolute;
  top: 100%;
  left: 0;
  background-color: #fff;
  border-top: 3px solid #13aff0;
  min-width: 180px;
  line-height: 1;
  text-align: left;
  z-index: 999;
  box-shadow: 0 2px 6px rgba(0, 0, 0, 0.1);
}
.dropdown-menu li .sub-menu li.menu-item {
  display: block;
  float: none;
}
.dropdown-menu ul .sub-menu {
  top: 0;
  left: 100%;
  margin-top: -3px;
}

.no-top-border .sub-menu {
  border: none;
}

.dropdown-menu ul li.menu-item {
  display: block;
  border-bottom: 1px solid #f1f1f1;
}
.dropdown-menu ul li.menu-item:last-child {
  border-bottom: 0;
}
.dropdown-menu ul li a.menu-link {
  display: block;
  position: relative;
  float: none;
  font-size: 12px;
  font-weight: 400;
  line-height: 1.2em;
  letter-spacing: 0.6px;
  padding: 12px 15px;
  text-transform: capitalize;
}
.dropdown-menu ul li a.menu-link:hover {
  background-color: #f8f8f8;
  color: #555;
}
.dropdown-menu ul li a.menu-link:hover .owp-icon use {
  stroke: #555;
}
.dropdown-menu ul li a.menu-link .nav-arrow {
  position: absolute;
  top: 50%;
  right: 15px;
  margin-top: -6.5px;
  padding: 0;
}
.dropdown-menu ul li a.menu-link i {
  position: relative;
  width: 20px;
  text-align: center;
  margin-right: 3px;
}

/**
 * Icons
 */
.dropdown-menu li a.menu-link i {
  padding-right: 5px;
}

/**
 * Item description
 */
.nav-content {
  display: block;
  font-size: 11px;
  line-height: 1.8;
  padding: 5px 0;
  white-space: normal;
  -moz-opacity: 0.7;
  -webkit-opacity: 0.7;
  opacity: 0.7;
}

/**
 * Menu Icons
 */
.navigation li a i.icon,
.navigation li a span.icon-wrap,
.navigation li a img.icon {
  display: inline-block;
  vertical-align: middle;
}
.navigation li a i.icon {
  width: auto;
  height: auto;
  font-size: 1.2em;
  line-height: 1;
  padding: 0 !important;
}
.navigation li a i.before, .navigation li a i.after {
  margin-top: -0.265em;
}
.navigation li a i.before {
  margin-right: 6px;
}
.navigation li a i.after {
  margin-left: 6px;
}
.navigation li a i.elusive {
  margin-top: -0.3em;
}
.navigation li a span.icon-wrap {
  text-align: center;
}
.navigation li a span.icon-wrap i.below,
.navigation li a span.icon-wrap img {
  display: block;
  margin: 0 0 8px;
}
.navigation li a span.icon-wrap img {
  margin: 0 auto 8px auto;
}
.navigation li a span.icon-wrap span.menu-text {
  display: block;
  line-height: 1;
}
.navigation li a img.before {
  margin-right: 6px;
}
.navigation li a img.after {
  margin-left: 6px;
}
.navigation li a .svg {
  width: 1em;
}
.navigation li a .hidden {
  display: none !important;
}

/**
 * After header content
 */
.after-header-content {
  float: right;
  height: 100%;
  display: table;
}
.after-header-content .after-header-content-inner {
  display: table-cell;
  vertical-align: middle;
  height: 74px;
}
.after-header-content .after-header-content-inner > a,
.after-header-content .after-header-content-inner > div > a {
  display: inline-block;
  line-height: 74px;
}
.after-header-content .elementor {
  display: inline-block;
}

/*------------------------------------*
	Mobile Menu
*------------------------------------*/
.oceanwp-mobile-menu-icon {
  display: none;
  position: relative;
}
.oceanwp-mobile-menu-icon.mobile-right {
  float: right;
}
.oceanwp-mobile-menu-icon.mobile-left {
  float: left;
}
.oceanwp-mobile-menu-icon a {
  font-size: 13px;
  line-height: 74px;
  color: #555;
  padding-left: 15px;
  letter-spacing: 0.6px;
  cursor: pointer;
}
.oceanwp-mobile-menu-icon a:first-child {
  padding-left: 0;
}
.oceanwp-mobile-menu-icon a:hover {
  color: #13aff0;
}
.oceanwp-mobile-menu-icon a:focus {
  outline: 1px dashed #e3e3e3;
}
.oceanwp-mobile-menu-icon a.mobile-menu .oceanwp-text,
.oceanwp-mobile-menu-icon a.mobile-menu .oceanwp-close-text {
  padding-left: 6px;
}
.oceanwp-mobile-menu-icon a.mobile-menu .oceanwp-close-text, .oceanwp-mobile-menu-icon a.mobile-menu.opened .oceanwp-text {
  display: none;
}
.oceanwp-mobile-menu-icon a.mobile-menu.opened .oceanwp-close-text {
  display: inline-block;
}

.oceanwp-social-menu {
  float: right;
  position: relative;
  z-index: 10;
}
.oceanwp-social-menu.simple-social {
  right: -8px;
}
.oceanwp-social-menu.social-with-style {
  right: -2px;
}
.oceanwp-social-menu .social-menu-inner {
  display: -ms-flexbox;
  display: flex;
  -ms-flex-align: center;
      align-items: center;
  height: 74px;
}
.oceanwp-social-menu ul {
  margin: 0;
  padding: 0;
  list-style: none;
}
.oceanwp-social-menu ul li {
  float: left;
  position: relative;
}
.oceanwp-social-menu ul li a {
  display: inline-block;
  background-color: transparent;
  color: #929292;
  padding: 0 8px;
  line-height: 1;
  text-align: center;
  letter-spacing: 0;
}
.oceanwp-social-menu ul li a span {
  width: 1em;
  height: 1em;
  text-align: center;
}
.oceanwp-social-menu ul li a:hover {
  background-color: transparent;
}
.oceanwp-social-menu ul li:first-child a {
  margin-left: 0;
}
.oceanwp-social-menu ul li:last-child a {
  margin-right: 0;
}
.oceanwp-social-menu ul li.oceanwp-twitter a:hover {
  color: #46d4fe;
}
.oceanwp-social-menu ul li.oceanwp-facebook a:hover {
  color: #37589b;
}
.oceanwp-social-menu ul li.oceanwp-googleplus a:hover {
  color: #de5a49;
}
.oceanwp-social-menu ul li.oceanwp-pinterest a:hover {
  color: #cb2027;
}
.oceanwp-social-menu ul li.oceanwp-dribbble a:hover {
  color: #ea4c89;
}
.oceanwp-social-menu ul li.oceanwp-vk a:hover {
  color: #597BA5;
}
.oceanwp-social-menu ul li.oceanwp-instagram a:hover {
  color: #3F729B;
}
.oceanwp-social-menu ul li.oceanwp-linkedin a:hover {
  color: #3399CC;
}
.oceanwp-social-menu ul li.oceanwp-tumblr a:hover {
  color: #2C4762;
}
.oceanwp-social-menu ul li.oceanwp-github a:hover {
  color: #60b044;
}
.oceanwp-social-menu ul li.oceanwp-flickr a:hover {
  color: #fa4086;
}
.oceanwp-social-menu ul li.oceanwp-skype a:hover {
  color: #00AFF0;
}
.oceanwp-social-menu ul li.oceanwp-youtube a:hover {
  color: #C4302B;
}
.oceanwp-social-menu ul li.oceanwp-vimeo a:hover {
  color: #1ab7ea;
}
.oceanwp-social-menu ul li.oceanwp-vine a:hover {
  color: #00bf8f;
}
.oceanwp-social-menu ul li.oceanwp-xing a:hover {
  color: #006464;
}
.oceanwp-social-menu ul li.oceanwp-yelp a:hover {
  color: #C41200;
}
.oceanwp-social-menu ul li.oceanwp-tripadvisor a:hover {
  color: #589442;
}
.oceanwp-social-menu ul li.oceanwp-rss a:hover {
  color: #ff7900;
}
.oceanwp-social-menu ul li.oceanwp-email a:hover {
  color: #13aff0;
}
.oceanwp-social-menu ul li.oceanwp-tiktok a:hover {
  color: #000000;
}
.oceanwp-social-menu ul li.oceanwp-medium a:hover {
  color: #00ab6c;
}
.oceanwp-social-menu ul li.oceanwp-telegram a:hover {
  color: #0088cc;
}
.oceanwp-social-menu ul li.oceanwp-twitch a:hover {
  color: #6441a5;
}
.oceanwp-social-menu ul li.oceanwp-line a:hover {
  color: #00c300;
}
.oceanwp-social-menu ul li.oceanwp-qq a:hover {
  color: #febf1b;
}
.oceanwp-social-menu ul li.oceanwp-facebook_group a:hover {
  color: #37589b;
}
.oceanwp-social-menu ul li.oceanwp-slack a:hover {
  color: #4a154b;
}
.oceanwp-social-menu ul li.oceanwp-threads a:hover {
  color: #000000;
}
.oceanwp-social-menu ul li.oceanwp-mastodon a:hover {
  color: #563acc;
}
.oceanwp-social-menu ul li.oceanwp-discord a:hover {
  color: #5865f2;
}
.oceanwp-social-menu .colored ul li a {
  position: relative;
  display: inline-block;
  font-size: 12px;
  color: #fff;
  line-height: 1;
  padding: 1em;
  border-radius: 50%;
  vertical-align: middle;
  transition: all 0.3s ease-out;
}
.oceanwp-social-menu .colored ul li a:hover {
  color: #fff;
}
.oceanwp-social-menu .colored ul li a .owp-icon use {
  stroke: #fff;
}
.oceanwp-social-menu .colored ul li.oceanwp-twitter a {
  background-color: #46d4fe;
}
.oceanwp-social-menu .colored ul li.oceanwp-twitter a:hover {
  background-color: #39b4d8;
}
.oceanwp-social-menu .colored ul li.oceanwp-facebook a {
  background-color: #37589b;
}
.oceanwp-social-menu .colored ul li.oceanwp-facebook a:hover {
  background-color: #2d477c;
}
.oceanwp-social-menu .colored ul li.oceanwp-googleplus a {
  background-color: #de5a49;
}
.oceanwp-social-menu .colored ul li.oceanwp-googleplus a:hover {
  background-color: #bb4c3e;
}
.oceanwp-social-menu .colored ul li.oceanwp-pinterest a {
  background-color: #cb2027;
}
.oceanwp-social-menu .colored ul li.oceanwp-pinterest a:hover {
  background-color: #a91d23;
}
.oceanwp-social-menu .colored ul li.oceanwp-dribbble a {
  background-color: #ea4c89;
}
.oceanwp-social-menu .colored ul li.oceanwp-dribbble a:hover {
  background-color: #c64174;
}
.oceanwp-social-menu .colored ul li.oceanwp-vk a {
  background-color: #597BA5;
}
.oceanwp-social-menu .colored ul li.oceanwp-vk a:hover {
  background-color: #486384;
}
.oceanwp-social-menu .colored ul li.oceanwp-instagram a {
  background-color: #3F729B;
}
.oceanwp-social-menu .colored ul li.oceanwp-instagram a:hover {
  background-color: #315a7c;
}
.oceanwp-social-menu .colored ul li.oceanwp-linkedin a {
  background-color: #3399CC;
}
.oceanwp-social-menu .colored ul li.oceanwp-linkedin a:hover {
  background-color: #2678a1;
}
.oceanwp-social-menu .colored ul li.oceanwp-tumblr a {
  background-color: #2C4762;
}
.oceanwp-social-menu .colored ul li.oceanwp-tumblr a:hover {
  background-color: #1d3042;
}
.oceanwp-social-menu .colored ul li.oceanwp-github a {
  background-color: #60b044;
}
.oceanwp-social-menu .colored ul li.oceanwp-github a:hover {
  background-color: #4f9237;
}
.oceanwp-social-menu .colored ul li.oceanwp-flickr a {
  background-color: #fa4086;
}
.oceanwp-social-menu .colored ul li.oceanwp-flickr a:hover {
  background-color: #c63169;
}
.oceanwp-social-menu .colored ul li.oceanwp-skype a {
  background-color: #00AFF0;
}
.oceanwp-social-menu .colored ul li.oceanwp-skype a:hover {
  background-color: #0291c6;
}
.oceanwp-social-menu .colored ul li.oceanwp-youtube a {
  background-color: #C4302B;
}
.oceanwp-social-menu .colored ul li.oceanwp-youtube a:hover {
  background-color: #982420;
}
.oceanwp-social-menu .colored ul li.oceanwp-vimeo a {
  background-color: #1ab7ea;
}
.oceanwp-social-menu .colored ul li.oceanwp-vimeo a:hover {
  background-color: #1494bd;
}
.oceanwp-social-menu .colored ul li.oceanwp-vine a {
  background-color: #00bf8f;
}
.oceanwp-social-menu .colored ul li.oceanwp-vine a:hover {
  background-color: #01906c;
}
.oceanwp-social-menu .colored ul li.oceanwp-xing a {
  background-color: #006464;
}
.oceanwp-social-menu .colored ul li.oceanwp-xing a:hover {
  background-color: #014646;
}
.oceanwp-social-menu .colored ul li.oceanwp-yelp a {
  background-color: #C41200;
}
.oceanwp-social-menu .colored ul li.oceanwp-yelp a:hover {
  background-color: #940f01;
}
.oceanwp-social-menu .colored ul li.oceanwp-tripadvisor a {
  background-color: #589442;
}
.oceanwp-social-menu .colored ul li.oceanwp-tripadvisor a:hover {
  background-color: #426f32;
}
.oceanwp-social-menu .colored ul li.oceanwp-rss a {
  background-color: #ff7900;
}
.oceanwp-social-menu .colored ul li.oceanwp-rss a:hover {
  background-color: #d46603;
}
.oceanwp-social-menu .colored ul li.oceanwp-email a {
  background-color: #13aff0;
}
.oceanwp-social-menu .colored ul li.oceanwp-email a:hover {
  background-color: #0f8dc2;
}
.oceanwp-social-menu .colored ul li.oceanwp-tiktok a {
  background-color: #000000;
}
.oceanwp-social-menu .colored ul li.oceanwp-tiktok a:hover {
  background-color: #141414;
}
.oceanwp-social-menu .colored ul li.oceanwp-medium a {
  background-color: #00ab6c;
}
.oceanwp-social-menu .colored ul li.oceanwp-medium a:hover {
  background-color: #03945f;
}
.oceanwp-social-menu .colored ul li.oceanwp-telegram a {
  background-color: #0088cc;
}
.oceanwp-social-menu .colored ul li.oceanwp-telegram a:hover {
  background-color: #0da4f0;
}
.oceanwp-social-menu .colored ul li.oceanwp-twitch a {
  background-color: #6441a5;
}
.oceanwp-social-menu .colored ul li.oceanwp-twitch a:hover {
  background-color: #702cee;
}
.oceanwp-social-menu .colored ul li.oceanwp-line a {
  background-color: #00c300;
}
.oceanwp-social-menu .colored ul li.oceanwp-line a:hover {
  background-color: #09f309;
}
.oceanwp-social-menu .colored ul li.oceanwp-qq a {
  background-color: #febf1b;
}
.oceanwp-social-menu .colored ul li.oceanwp-qq a:hover {
  background-color: #db9f07;
}
.oceanwp-social-menu .colored ul li.oceanwp-facebook_group a {
  background-color: #37589b;
}
.oceanwp-social-menu .colored ul li.oceanwp-facebook_group a:hover {
  background-color: #2d477c;
}
.oceanwp-social-menu .colored ul li.oceanwp-slack a {
  background-color: #4a154b;
}
.oceanwp-social-menu .colored ul li.oceanwp-slack a:hover {
  background-color: #3d0a3e;
}
.oceanwp-social-menu .colored ul li.oceanwp-threads a {
  background-color: #000000;
}
.oceanwp-social-menu .colored ul li.oceanwp-threads a:hover {
  background-color: #191919;
}
.oceanwp-social-menu .colored ul li.oceanwp-mastodon a {
  background-color: #6364ff;
}
.oceanwp-social-menu .colored ul li.oceanwp-mastodon a:hover {
  background-color: #563acc;
}
.oceanwp-social-menu .colored ul li.oceanwp-discord a {
  background-color: #5865f2;
}
.oceanwp-social-menu .colored ul li.oceanwp-discord a:hover {
  background-color: #7289da;
}
.oceanwp-social-menu .minimal ul li a {
  position: relative;
  display: inline-block;
  font-size: 12px;
  background-color: transparent;
  color: #bbb;
  border: 1px solid #ccc;
  line-height: 1;
  padding: 1em;
  border-radius: 50%;
  vertical-align: middle;
  transition: all 0.3s ease-out;
}
.oceanwp-social-menu .minimal ul li a:hover {
  background-color: transparent;
}
.oceanwp-social-menu .minimal ul li.oceanwp-twitter a:hover {
  color: #46d4fe;
  border-color: #46d4fe;
}
.oceanwp-social-menu .minimal ul li.oceanwp-facebook a:hover {
  color: #37589b;
  border-color: #37589b;
}
.oceanwp-social-menu .minimal ul li.oceanwp-googleplus a:hover {
  color: #de5a49;
  border-color: #de5a49;
}
.oceanwp-social-menu .minimal ul li.oceanwp-pinterest a:hover {
  color: #cb2027;
  border-color: #cb2027;
}
.oceanwp-social-menu .minimal ul li.oceanwp-dribbble a:hover {
  color: #ea4c89;
  border-color: #ea4c89;
}
.oceanwp-social-menu .minimal ul li.oceanwp-vk a:hover {
  color: #597BA5;
  border-color: #597BA5;
}
.oceanwp-social-menu .minimal ul li.oceanwp-instagram a:hover {
  color: #3F729B;
  border-color: #3F729B;
}
.oceanwp-social-menu .minimal ul li.oceanwp-linkedin a:hover {
  color: #3399CC;
  border-color: #3399CC;
}
.oceanwp-social-menu .minimal ul li.oceanwp-tumblr a:hover {
  color: #2C4762;
  border-color: #2C4762;
}
.oceanwp-social-menu .minimal ul li.oceanwp-github a:hover {
  color: #60b044;
  border-color: #60b044;
}
.oceanwp-social-menu .minimal ul li.oceanwp-flickr a:hover {
  color: #fa4086;
  border-color: #fa4086;
}
.oceanwp-social-menu .minimal ul li.oceanwp-skype a:hover {
  color: #00AFF0;
  border-color: #00AFF0;
}
.oceanwp-social-menu .minimal ul li.oceanwp-youtube a:hover {
  color: #C4302B;
  border-color: #C4302B;
}
.oceanwp-social-menu .minimal ul li.oceanwp-vimeo a:hover {
  color: #1ab7ea;
  border-color: #1ab7ea;
}
.oceanwp-social-menu .minimal ul li.oceanwp-vine a:hover {
  color: #00bf8f;
  border-color: #00bf8f;
}
.oceanwp-social-menu .minimal ul li.oceanwp-xing a:hover {
  color: #006464;
  border-color: #006464;
}
.oceanwp-social-menu .minimal ul li.oceanwp-yelp a:hover {
  color: #C41200;
  border-color: #C41200;
}
.oceanwp-social-menu .minimal ul li.oceanwp-tripadvisor a:hover {
  color: #589442;
  border-color: #589442;
}
.oceanwp-social-menu .minimal ul li.oceanwp-rss a:hover {
  color: #ff7900;
  border-color: #ff7900;
}
.oceanwp-social-menu .minimal ul li.oceanwp-email a:hover {
  color: #13aff0;
  border-color: #13aff0;
}
.oceanwp-social-menu .minimal ul li.oceanwp-tiktok a:hover {
  color: #000000;
  border-color: #000000;
}
.oceanwp-social-menu .minimal ul li.oceanwp-medium a:hover {
  color: #00ab6c;
  border-color: #00ab6c;
}
.oceanwp-social-menu .minimal ul li.oceanwp-telegram a:hover {
  color: #0088cc;
  border-color: #0088cc;
}
.oceanwp-social-menu .minimal ul li.oceanwp-twitch a:hover {
  color: #702cee;
  border-color: #702cee;
}
.oceanwp-social-menu .minimal ul li.oceanwp-line a:hover {
  color: #00c300;
  border-color: #00c300;
}
.oceanwp-social-menu .minimal ul li.oceanwp-qq a:hover {
  color: #febf1b;
  border-color: #febf1b;
}
.oceanwp-social-menu .minimal ul li.oceanwp-facebook_group a:hover {
  color: #37589b;
  border-color: #37589b;
}
.oceanwp-social-menu .minimal ul li.oceanwp-slack a:hover {
  color: #4a154b;
  border-color: #4a154b;
}
.oceanwp-social-menu .minimal ul li.oceanwp-threads a:hover {
  color: #000000;
  border-color: #000000;
}
.oceanwp-social-menu .minimal ul li.oceanwp-mastodon a:hover {
  color: #563acc;
  border-color: #563acc;
}
.oceanwp-social-menu .minimal ul li.oceanwp-discord a:hover {
  color: #5865f2;
  border-color: #7289da;
}
.oceanwp-social-menu .dark ul li a {
  position: relative;
  display: inline-block;
  font-size: 12px;
  background-color: #333;
  color: #fff;
  line-height: 1;
  padding: 1em;
  border-radius: 50%;
  vertical-align: middle;
  transition: all 0.3s ease-out;
}
.oceanwp-social-menu .dark ul li a:hover {
  background-color: #000;
  color: #fff;
}
.oceanwp-social-menu .dark ul li a .owp-icon use {
  stroke: #fff;
}

/*------------------------------------*
	$LINKS EFFECT
*------------------------------------*/
.effect-one #site-navigation-wrap .dropdown-menu > li > a.menu-link > span {
  position: relative;
}
.effect-one #site-navigation-wrap .dropdown-menu > li > a.menu-link > span:after {
  display: block;
  background-color: #13aff0;
  position: absolute;
  bottom: -30%;
  left: 0;
  content: "";
  width: 100%;
  height: 2px;
  visibility: hidden;
  -ms-transform: scaleX(0);
      transform: scaleX(0);
  -ms-transform-origin: bottom left;
      transform-origin: bottom left;
  transition: all 0.25s ease-out;
}
.effect-one #site-navigation-wrap .dropdown-menu > li > a.menu-link:hover > span:after {
  visibility: visible;
  -ms-transform: scaleX(1);
      transform: scaleX(1);
}
.effect-one #site-navigation-wrap .dropdown-menu > li.sfHover > a.menu-link > span:after {
  visibility: visible;
  -ms-transform: scaleX(1);
      transform: scaleX(1);
}

.effect-two #site-navigation-wrap .dropdown-menu > li > a.menu-link > span {
  position: relative;
}
.effect-two #site-navigation-wrap .dropdown-menu > li > a.menu-link > span:after {
  position: absolute;
  bottom: -30%;
  left: 0;
  width: 100%;
  height: 3px;
  background-color: rgba(0, 0, 0, 0.1);
  content: "";
  opacity: 0;
  transition: all 0.25s ease-out;
  -ms-transform: translateY(10px);
  transform: translateY(10px);
}
.effect-two #site-navigation-wrap .dropdown-menu > li > a.menu-link:hover > span:after {
  opacity: 1;
  -ms-transform: translateY(0);
  transform: translateY(0);
}
.effect-two #site-navigation-wrap .dropdown-menu > li.sfHover > a.menu-link > span:after {
  opacity: 1;
  -ms-transform: translateY(0);
  transform: translateY(0);
}

.effect-three #site-navigation-wrap .dropdown-menu > li > a.menu-link > span {
  position: relative;
}
.effect-three #site-navigation-wrap .dropdown-menu > li > a.menu-link > span:after {
  position: absolute;
  bottom: -30%;
  left: 0;
  width: 100%;
  height: 1px;
  background-color: #13aff0;
  content: "";
  opacity: 0;
  transition: all 0.25s ease-out;
  -ms-transform: translateY(-10px);
  transform: translateY(-10px);
}
.effect-three #site-navigation-wrap .dropdown-menu > li > a.menu-link:hover > span:after {
  height: 2px;
  opacity: 1;
  -ms-transform: translateY(0);
  transform: translateY(0);
}
.effect-three #site-navigation-wrap .dropdown-menu > li.sfHover > a.menu-link > span:after {
  height: 2px;
  opacity: 1;
  -ms-transform: translateY(0);
  transform: translateY(0);
}

.effect-four #site-navigation-wrap .dropdown-menu > li > a.menu-link > span {
  position: relative;
}
.effect-four #site-navigation-wrap .dropdown-menu > li > a.menu-link > span:before, .effect-four #site-navigation-wrap .dropdown-menu > li > a.menu-link > span:after {
  display: inline-block;
  color: #13aff0;
  opacity: 0;
  transition: all 0.25s ease-out;
}
.effect-four #site-navigation-wrap .dropdown-menu > li > a.menu-link > span:before {
  margin-right: 6px;
  content: "[";
  -ms-transform: translateX(20px);
  transform: translateX(20px);
}
.effect-four #site-navigation-wrap .dropdown-menu > li > a.menu-link > span:after {
  margin-left: 6px;
  content: "]";
  -ms-transform: translateX(-20px);
  transform: translateX(-20px);
}
.effect-four #site-navigation-wrap .dropdown-menu > li > a.menu-link:hover > span:before, .effect-four #site-navigation-wrap .dropdown-menu > li > a.menu-link:hover > span:after {
  opacity: 1;
  -ms-transform: translateX(0);
  transform: translateX(0);
}
.effect-four #site-navigation-wrap .dropdown-menu > li.sfHover > a.menu-link > span:before, .effect-four #site-navigation-wrap .dropdown-menu > li.sfHover > a.menu-link > span:after {
  opacity: 1;
  -ms-transform: translateX(0);
  transform: translateX(0);
}

.effect-five #site-navigation-wrap .dropdown-menu > li > a.menu-link > span {
  position: relative;
}
.effect-five #site-navigation-wrap .dropdown-menu > li > a.menu-link > span:before, .effect-five #site-navigation-wrap .dropdown-menu > li > a.menu-link > span:after {
  position: absolute;
  top: 130%;
  left: 0;
  width: 100%;
  height: 2px;
  background-color: #13aff0;
  content: "";
  transition: all 0.25s ease-out;
  -ms-transform: scale(0.85);
  transform: scale(0.85);
}
.effect-five #site-navigation-wrap .dropdown-menu > li > a.menu-link > span:after {
  opacity: 0;
  transition: all 0.25s ease-out;
}
.effect-five #site-navigation-wrap .dropdown-menu > li > a.menu-link:hover > span:before, .effect-five #site-navigation-wrap .dropdown-menu > li > a.menu-link:hover > span:after {
  -ms-transform: scale(1);
  transform: scale(1);
}
.effect-five #site-navigation-wrap .dropdown-menu > li > a.menu-link:hover > span:after {
  top: -30%;
  opacity: 1;
}
.effect-five #site-navigation-wrap .dropdown-menu > li.sfHover > a.menu-link > span:before, .effect-five #site-navigation-wrap .dropdown-menu > li.sfHover > a.menu-link > span:after {
  -ms-transform: scale(1);
  transform: scale(1);
}
.effect-five #site-navigation-wrap .dropdown-menu > li.sfHover > a.menu-link > span:after {
  top: -30%;
  opacity: 1;
}

.effect-six #site-navigation-wrap .dropdown-menu > li > a.menu-link > span {
  position: relative;
}
.effect-six #site-navigation-wrap .dropdown-menu > li > a.menu-link > span:before, .effect-six #site-navigation-wrap .dropdown-menu > li > a.menu-link > span:after {
  position: absolute;
  top: 50%;
  left: 50%;
  width: 50px;
  height: 50px;
  border: 2px solid rgba(0, 0, 0, 0.1);
  border-radius: 50%;
  content: "";
  opacity: 0;
  transition: all 0.25s ease-out;
  -ms-transform: translateX(-50%) translateY(-50%) scale(0.2);
  transform: translateX(-50%) translateY(-50%) scale(0.2);
}
.effect-six #site-navigation-wrap .dropdown-menu > li > a.menu-link > span:after {
  width: 40px;
  height: 40px;
  border-width: 4px;
  -ms-transform: translateX(-50%) translateY(-50%) scale(0.8);
  transform: translateX(-50%) translateY(-50%) scale(0.8);
}
.effect-six #site-navigation-wrap .dropdown-menu > li > a.menu-link:hover > span:before, .effect-six #site-navigation-wrap .dropdown-menu > li > a.menu-link:hover > span:after {
  opacity: 1;
  -ms-transform: translateX(-50%) translateY(-50%) scale(1);
  transform: translateX(-50%) translateY(-50%) scale(1);
}
.effect-six #site-navigation-wrap .dropdown-menu > li.sfHover > a.menu-link > span:before, .effect-six #site-navigation-wrap .dropdown-menu > li.sfHover > a.menu-link > span:after {
  opacity: 1;
  -ms-transform: translateX(-50%) translateY(-50%) scale(1);
  transform: translateX(-50%) translateY(-50%) scale(1);
}

.effect-seven #site-navigation-wrap .dropdown-menu > li > a.menu-link > span {
  position: relative;
}
.effect-seven #site-navigation-wrap .dropdown-menu > li > a.menu-link > span:after {
  position: absolute;
  bottom: -80%;
  left: 50%;
  color: transparent;
  content: "•";
  text-shadow: 0 0 transparent;
  font-size: 1.2em;
  line-height: 1;
  transition: all 0.25s ease-out;
  -ms-transform: translateX(-50%);
  transform: translateX(-50%);
  pointer-events: none;
}
.effect-seven #site-navigation-wrap .dropdown-menu > li > a.menu-link:hover > span:after {
  color: #13aff0;
  text-shadow: 10px 0 #13aff0, -10px 0 #13aff0;
}
.effect-seven #site-navigation-wrap .dropdown-menu > li.sfHover > a.menu-link > span:after {
  color: #13aff0;
  text-shadow: 10px 0 #13aff0, -10px 0 #13aff0;
}

.effect-eight #site-navigation-wrap .dropdown-menu > li > a.menu-link > span {
  position: relative;
  padding: 0 8px;
}
.effect-eight #site-navigation-wrap .dropdown-menu > li > a.menu-link > span:before, .effect-eight #site-navigation-wrap .dropdown-menu > li > a.menu-link > span:after {
  position: absolute;
  width: 100%;
  top: 50%;
  left: 0;
  height: 2px;
  margin-top: -1px;
  background-color: rgba(0, 0, 0, 0.1);
  content: "";
  z-index: -1;
  transition: all 0.25s ease-out;
  pointer-events: none;
}
.effect-eight #site-navigation-wrap .dropdown-menu > li > a.menu-link > span:before {
  -ms-transform: translateY(-13px);
  transform: translateY(-13px);
}
.effect-eight #site-navigation-wrap .dropdown-menu > li > a.menu-link > span:after {
  -ms-transform: translateY(15px);
  transform: translateY(15px);
}
.effect-eight #site-navigation-wrap .dropdown-menu > li > a.menu-link:hover > span:before, .effect-eight #site-navigation-wrap .dropdown-menu > li > a.menu-link:hover > span:after {
  opacity: 0.8;
}
.effect-eight #site-navigation-wrap .dropdown-menu > li > a.menu-link:hover > span:before {
  -ms-transform: rotate(45deg);
  transform: rotate(45deg);
}
.effect-eight #site-navigation-wrap .dropdown-menu > li > a.menu-link:hover > span:after {
  -ms-transform: rotate(-45deg);
  transform: rotate(-45deg);
}
.effect-eight #site-navigation-wrap .dropdown-menu > li.sfHover > a.menu-link > span:before, .effect-eight #site-navigation-wrap .dropdown-menu > li.sfHover > a.menu-link > span:after {
  opacity: 0.8;
}
.effect-eight #site-navigation-wrap .dropdown-menu > li.sfHover > a.menu-link > span:before {
  -ms-transform: rotate(45deg);
  transform: rotate(45deg);
}
.effect-eight #site-navigation-wrap .dropdown-menu > li.sfHover > a.menu-link > span:after {
  -ms-transform: rotate(-45deg);
  transform: rotate(-45deg);
}

.effect-nine #site-navigation-wrap .dropdown-menu > li > a.menu-link > span {
  position: relative;
}
.effect-nine #site-navigation-wrap .dropdown-menu > li > a.menu-link > span:before, .effect-nine #site-navigation-wrap .dropdown-menu > li > a.menu-link > span:after {
  position: absolute;
  left: 0;
  width: 100%;
  height: 2px;
  background-color: #13aff0;
  content: "";
  opacity: 0;
  transition: all 0.25s ease-out;
  -ms-transform: translateY(-10px);
  transform: translateY(-10px);
}
.effect-nine #site-navigation-wrap .dropdown-menu > li > a.menu-link > span:before {
  top: 0;
  -ms-transform: translateY(-10px);
  transform: translateY(-10px);
}
.effect-nine #site-navigation-wrap .dropdown-menu > li > a.menu-link > span:after {
  bottom: 0;
  -ms-transform: translateY(10px);
  transform: translateY(10px);
}
.effect-nine #site-navigation-wrap .dropdown-menu > li > a.menu-link:hover > span:before, .effect-nine #site-navigation-wrap .dropdown-menu > li > a.menu-link:hover > span:after {
  opacity: 1;
}
.effect-nine #site-navigation-wrap .dropdown-menu > li > a.menu-link:hover > span:before {
  -ms-transform: translateY(-3px);
  transform: translateY(-3px);
}
.effect-nine #site-navigation-wrap .dropdown-menu > li > a.menu-link:hover > span:after {
  -ms-transform: translateY(5px);
  transform: translateY(5px);
}
.effect-nine #site-navigation-wrap .dropdown-menu > li.sfHover > a.menu-link > span:before, .effect-nine #site-navigation-wrap .dropdown-menu > li.sfHover > a.menu-link > span:after {
  opacity: 1;
}
.effect-nine #site-navigation-wrap .dropdown-menu > li.sfHover > a.menu-link > span:before {
  -ms-transform: translateY(-3px);
  transform: translateY(-3px);
}
.effect-nine #site-navigation-wrap .dropdown-menu > li.sfHover > a.menu-link > span:after {
  -ms-transform: translateY(5px);
  transform: translateY(5px);
}

.effect-ten #site-navigation-wrap .dropdown-menu > li > a.menu-link > span {
  padding: 8px;
  transition: box-shadow 0.25s ease-out;
}
.effect-ten #site-navigation-wrap .dropdown-menu > li > a.menu-link:hover > span {
  box-shadow: 0 0 10px 4px rgba(0, 0, 0, 0.1);
}
.effect-ten #site-navigation-wrap .dropdown-menu > li.sfHover > a.menu-link > span {
  box-shadow: 0 0 10px 4px rgba(0, 0, 0, 0.1);
}

/*------------------------------------*
	$MEGA MENU
*------------------------------------*/
.navigation .megamenu a .nav-arrow {
  display: none;
}
.navigation .megamenu > li > a.menu-link {
  font-size: 13px;
  font-weight: 600;
}
.navigation .megamenu li ul.sub-menu {
  border-top: 1px solid #f1f1f1;
}
.navigation .megamenu li a.menu-link {
  padding: 12px 20px;
}
.navigation .megamenu .sidebar-box {
  padding: 20px;
  margin-bottom: 0;
  line-height: 1.8;
  white-space: normal;
}

.navigation > ul > li > ul.megamenu.sub-menu > li {
  float: left;
  border-bottom: 0;
  border-left-width: 1px;
  border-style: solid;
  border-color: #f1f1f1;
}
.navigation > ul > li > ul.megamenu.sub-menu > li:first-child {
  border-left: none;
}

.navigation li.megamenu-li.hide-headings > .megamenu > li > a,
.navigation li.megamenu-li > .megamenu > li.hide-heading > a {
  display: none;
}

.navigation .megamenu .sub-menu {
  display: block !important;
  -moz-opacity: 1 !important;
  -webkit-opacity: 1 !important;
  opacity: 1 !important;
  min-width: 100%;
  position: static;
  background: transparent;
  box-shadow: none;
}

/**
 * Megamenu columns
 */
.navigation li.megamenu-li .megamenu.col-1 > li {
  width: 100%;
}
.navigation li.megamenu-li .megamenu.col-2 > li {
  width: 50%;
}
.navigation li.megamenu-li .megamenu.col-3 > li {
  width: 33.33333333%;
}
.navigation li.megamenu-li .megamenu.col-4 > li {
  width: 25%;
}
.navigation li.megamenu-li .megamenu.col-5 > li {
  width: 20%;
}
.navigation li.megamenu-li .megamenu.col-6 > li {
  width: 16.66666667%;
}

/**
 * Megamenu auto width
 */
@media only screen and (min-width: 959px) {
  .navigation li.megamenu-li.auto-mega .megamenu.col-1 {
    width: 320px;
  }
  .navigation li.megamenu-li.auto-mega .megamenu.col-2 {
    width: 440px;
  }
  .navigation li.megamenu-li.auto-mega .megamenu.col-3 {
    width: 660px;
  }
  .navigation li.megamenu-li.auto-mega .megamenu.col-4 {
    width: 780px;
  }
  .navigation li.megamenu-li.auto-mega .megamenu.col-5 {
    width: 980px;
  }
  .navigation li.megamenu-li.auto-mega .megamenu.col-6 {
    width: 1080px;
  }
}
/**
 * Elementor Template
 */
.navigation > ul > li > ul.megamenu.sub-menu > li .elementor {
  white-space: normal;
  line-height: initial;
}

/**
 * Latest Posts Categories
 */
.navigation li.mega-cat .megamenu {
  padding: 30px 20px;
}
.navigation li.mega-cat .mega-cat-title {
  position: relative;
  font-size: 14px;
  line-height: 1;
  font-weight: 400;
  background-color: #f8f8f8;
  color: #222;
  letter-spacing: 2px;
  margin: 0 -20px 30px;
  padding: 15px 35px;
  text-transform: uppercase;
}
.navigation li.mega-cat > ul > li {
  padding: 0 15px;
}
.navigation li.mega-cat ul li a {
  padding: 0;
}
.navigation li.mega-cat ul li a.mega-post-link {
  display: block;
  position: relative;
  background-color: #000;
}
.navigation li.mega-cat ul li a.mega-post-link img {
  display: block;
  width: 100%;
}
.navigation li.mega-cat ul li a.mega-post-link .overlay {
  position: absolute;
  bottom: 0;
  left: 0;
  right: 0;
  width: 100%;
  height: 100%;
  border-radius: 3px;
  background-color: rgba(0, 0, 0, 0.2);
  -moz-opacity: 0;
  -webkit-opacity: 0;
  opacity: 0;
  text-align: center;
  transition: all 0.3s ease;
}
.navigation li.mega-cat ul li a.mega-post-link:hover .overlay {
  -moz-opacity: 1;
  -webkit-opacity: 1;
  opacity: 1;
}
.navigation li.mega-cat ul li .mega-post-title {
  display: block;
  margin: 15px 0 8px;
  white-space: initial;
}
.navigation li.mega-cat ul li .mega-post-title a {
  color: #555;
  font-size: 14px;
  font-weight: 400;
  line-height: 1.3;
  letter-spacing: 0.6px;
  text-transform: none;
}
.navigation li.mega-cat ul li .mega-post-title a:hover {
  background-color: transparent;
  color: #333;
}
.navigation li.mega-cat ul li .mega-post-date {
  display: block;
  font-size: 10px;
  color: #bbb;
  text-transform: uppercase;
}
.navigation li.mega-cat ul li .mega-post-date i {
  font-size: 9px;
  padding-right: 5px;
}
.navigation li.mega-cat ul li .mega-post-date svg.owp-icon {
  width: 16px;
  height: 16px;
  margin-right: 0.7rem;
}

.navigation > ul > li.mega-cat > ul.megamenu.sub-menu > li.first {
  border-left: 0;
}

/*------------------------------------*
	Tablet & Small Desktop Widths
*------------------------------------*/
@media only screen and (min-width: 768px) and (max-width: 1280px) {
  /* megamenu */
  .navigation li.megamenu.auto-width.col-6 > .sub-menu {
    width: 980px;
  }
}
/*------------------------------------*
	$SEARCH ICON
*------------------------------------*/
#searchform-dropdown,
#icon-searchform-dropdown {
  position: absolute;
  right: 0;
  background-color: #fff;
  border-top: 3px solid #13aff0;
  top: 100%;
  padding: 15px;
  width: 260px;
  box-shadow: 0 2px 7px rgba(0, 0, 0, 0.1);
  visibility: hidden;
  -moz-opacity: 0;
  -webkit-opacity: 0;
  opacity: 0;
  transition: all 0.25s ease-in-out;
  z-index: 10000;
}
#searchform-dropdown input,
#icon-searchform-dropdown input {
  display: block;
  background-color: transparent;
  border-radius: 0;
  margin: 0;
}

.no-top-border #searchform-dropdown,
.no-top-border #icon-searchform-dropdown {
  border: none;
}

/* display search on click */
#searchform-dropdown.show,
#icon-searchform-dropdown.show {
  visibility: visible;
  -moz-opacity: 1;
  -webkit-opacity: 1;
  opacity: 1;
}

#icon-searchform-dropdown {
  width: 100%;
}

#site-header.header-replace #site-navigation .dropdown-menu {
  transition: opacity 0.25s ease-in-out;
}
#site-header.header-replace #site-navigation.hide .dropdown-menu {
  visibility: hidden;
  -moz-opacity: 0;
  -webkit-opacity: 0;
  opacity: 0;
}

#searchform-header-replace {
  position: absolute;
  top: 0;
  right: 0;
  height: 100%;
  width: 100%;
  min-width: 370px;
  visibility: hidden;
  -moz-opacity: 0;
  -webkit-opacity: 0;
  opacity: 0;
  transition: opacity 0.25s ease-in-out;
}
#searchform-header-replace form {
  height: 100%;
  width: 100%;
}
#searchform-header-replace input {
  height: 100%;
  width: 94%;
  font-size: 22px;
  background-color: transparent;
  color: #bbb;
  padding: 0;
  outline: 0;
  border: 0;
  margin: 0;
  border-radius: 0;
}

#searchform-header-replace-close {
  position: absolute;
  right: 8px;
  top: 50%;
  margin-top: -20px;
  height: 40px;
  line-height: 40px;
  font-size: 26px;
  color: #bbb;
  cursor: pointer;
  transition: all 0.3s ease;
}
#searchform-header-replace-close:hover {
  color: #222;
}

/* display search on click */
#searchform-header-replace.show {
  visibility: visible;
  -moz-opacity: 1;
  -webkit-opacity: 1;
  opacity: 1;
}

#searchform-overlay,
#icon-searchform-overlay {
  display: none;
  position: fixed;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  background-color: rgba(0, 0, 0, 0.9);
  z-index: 9999;
}
#searchform-overlay .container,
#icon-searchform-overlay .container {
  position: relative;
  width: 100%;
  height: 100%;
}
#searchform-overlay a.search-overlay-close,
#icon-searchform-overlay a.search-overlay-close {
  position: absolute;
  top: -50px;
  left: 50%;
  margin-left: -20px;
  width: 40px;
  height: 40px;
  background-color: rgba(255, 255, 255, 0.2);
  text-align: center;
  border-radius: 2px;
}
#searchform-overlay a.search-overlay-close:hover,
#icon-searchform-overlay a.search-overlay-close:hover {
  background-color: rgba(255, 255, 255, 0.3);
}
#searchform-overlay a.search-overlay-close span,
#icon-searchform-overlay a.search-overlay-close span {
  position: relative;
  display: inline-block;
  width: 24px;
  height: 24px;
}
#searchform-overlay a.search-overlay-close span:before, #searchform-overlay a.search-overlay-close span:after,
#icon-searchform-overlay a.search-overlay-close span:before,
#icon-searchform-overlay a.search-overlay-close span:after {
  content: "";
  position: absolute;
  top: 50%;
  left: 0;
  height: 2px;
  width: 100%;
  margin-top: 6px;
  background-color: #fff;
  border-radius: 5px;
}
#searchform-overlay a.search-overlay-close span:before,
#icon-searchform-overlay a.search-overlay-close span:before {
  -ms-transform: rotate(45deg);
  transform: rotate(45deg);
}
#searchform-overlay a.search-overlay-close span:after,
#icon-searchform-overlay a.search-overlay-close span:after {
  -ms-transform: rotate(-45deg);
  transform: rotate(-45deg);
}
#searchform-overlay form,
#icon-searchform-overlay form {
  position: absolute;
  top: 50%;
  left: 0;
  margin-top: -33px;
  width: 100%;
  text-align: center;
}
#searchform-overlay form input, #searchform-overlay form .search-text,
#icon-searchform-overlay form input,
#icon-searchform-overlay form .search-text {
  font-size: 22px;
  line-height: 1.3;
  padding: 18px 0;
  margin: 0;
  min-height: 50px;
  color: #fff;
  letter-spacing: 1px;
  text-transform: uppercase;
  text-align: center;
}
#searchform-overlay form input,
#icon-searchform-overlay form input {
  position: relative;
  border: 0;
  background-color: transparent;
  border-bottom: 1px solid #444;
  z-index: 2;
  transition: border-color 0.3s ease;
}
#searchform-overlay form input:hover,
#icon-searchform-overlay form input:hover {
  border-color: #777;
}
#searchform-overlay form input:focus,
#icon-searchform-overlay form input:focus {
  border-color: #fff;
}
#searchform-overlay form .search-text,
#icon-searchform-overlay form .search-text {
  display: block;
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  right: 0;
  cursor: text;
  -moz-opacity: 0.5;
  -webkit-opacity: 0.5;
  opacity: 0.5;
  z-index: 1;
}
#searchform-overlay form .search-text i,
#icon-searchform-overlay form .search-text i {
  display: inline-block;
  background-color: #fff;
  width: 3px;
  height: 3px;
  margin-left: 3px;
  animation: blink 1s linear infinite;
}
#searchform-overlay form .search-text i + i,
#icon-searchform-overlay form .search-text i + i {
  animation-delay: 0.2s;
}
#searchform-overlay form .search-text i + i + i,
#icon-searchform-overlay form .search-text i + i + i {
  animation-delay: 0.4s;
}
#searchform-overlay form.search-filled .search-text,
#icon-searchform-overlay form.search-filled .search-text {
  -moz-opacity: 0;
  -webkit-opacity: 0;
  opacity: 0;
  transition-duration: 150ms;
}

#searchform-overlay .container {
  max-width: 550px;
}

#icon-searchform-overlay form .search-text,
#icon-searchform-overlay form input {
  font-size: 16px;
}
#icon-searchform-overlay .search-overlay-close {
  line-height: inherit;
}

/*------------------------------------*
	All Devices under 960px
*------------------------------------*/
@media only screen and (max-width: 959px) {
  /* header > search overlay */
  #searchform-overlay {
    display: none !important;
  }
}
/*------------------------------------*
	$DROP DOWN MOBILE
*------------------------------------*/
#mobile-dropdown {
  display: none;
  position: absolute;
  top: 100%;
  left: 0;
  width: 100%;
  background-color: #fff;
  max-height: 400px;
  overflow-y: auto;
  box-shadow: 0 2px 6px rgba(0, 0, 0, 0.1);
}
#mobile-dropdown ul {
  margin: 0;
  list-style: none;
}
#mobile-dropdown ul li {
  border-bottom: 1px solid rgba(0, 0, 0, 0.035);
}
#mobile-dropdown ul li a {
  display: block;
  position: relative;
  padding: 12px 40px;
  text-align: left;
}
#mobile-dropdown ul li a:focus {
  outline: 1px dashed #e3e3e3;
}
#mobile-dropdown ul li a i,
#mobile-dropdown ul li a img {
  margin-right: 10px;
}
#mobile-dropdown ul li a i.after {
  margin-right: 0;
  margin-left: 10px;
}
#mobile-dropdown ul li a .dropdown-toggle {
  position: absolute;
  right: 0;
  top: 0;
  height: 100%;
  width: 60px;
  cursor: pointer;
  color: #555;
  padding-right: 40px;
  text-align: center;
  transition: all 0.3s ease;
}
#mobile-dropdown ul li a .dropdown-toggle:focus {
  outline: 1px dashed rgba(0, 0, 0, 0.4);
}
#mobile-dropdown ul li a .dropdown-toggle:before {
  content: "+";
  font-size: 20px;
  position: absolute;
  top: 50%;
  left: 50%;
  line-height: 30px;
  margin-top: -15px;
  margin-left: -15px;
}
#mobile-dropdown ul li.active > a > .dropdown-toggle:before {
  content: "-";
}
#mobile-dropdown ul li ul {
  display: none;
  border-top: 1px solid rgba(0, 0, 0, 0.035);
  margin-left: 0;
  background-color: rgba(0, 0, 0, 0.02);
}
#mobile-dropdown ul li.woo-menu-icon,
#mobile-dropdown ul li.search-toggle-li,
#mobile-dropdown ul li.side-panel-li,
#mobile-dropdown ul li a .nav-arrow,
#mobile-dropdown ul .sidebar-box,
#mobile-dropdown ul .widget {
  display: none;
}
#mobile-dropdown .oceanwp-social-menu {
  display: block !important;
  float: none;
  width: 100%;
  right: auto !important;
  left: auto !important;
  padding: 0 40px !important;
  margin: 10px 0 !important;
}
#mobile-dropdown .oceanwp-social-menu .social-menu-inner {
  height: auto;
}
#mobile-dropdown .oceanwp-social-menu li {
  display: inline-block;
  float: none;
  border: 0;
}
#mobile-dropdown .oceanwp-social-menu li a {
  display: block;
  padding: 12px 10px;
}
#mobile-dropdown #mobile-menu-search {
  display: block;
  padding: 20px 40px;
}
#mobile-dropdown #mobile-menu-search form {
  position: relative;
}
#mobile-dropdown #mobile-menu-search form input {
  padding: 6px 45px 6px 12px !important;
  margin-top: 0 !important;
  box-sizing: inherit;
}
#mobile-dropdown #mobile-menu-search form button {
  display: block;
  position: absolute;
  right: 10px;
  height: 30px;
  line-height: 30px;
  width: 30px;
  padding: 0;
  text-align: center;
  top: 50%;
  margin-top: -15px;
  background-color: transparent !important;
  color: #555;
  border: 0;
  transition: all 0.3s ease-in-out;
}
#mobile-dropdown #mobile-menu-search form button:hover {
  color: #222;
}
#mobile-dropdown .has-social #mobile-menu-search {
  padding-top: 0;
}

/*------------------------------------*
	$FULL SCREEN MOBILE
*------------------------------------*/
#mobile-fullscreen {
  display: none;
  position: fixed;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  background-color: rgba(0, 0, 0, 0.9);
  overflow-y: scroll;
  z-index: 100000;
}
#mobile-fullscreen #mobile-fullscreen-inner {
  display: table;
  width: 100%;
  height: 100%;
  padding: 0 40px;
}
#mobile-fullscreen a.close {
  position: absolute;
  top: 14px;
  right: 14px;
}
#mobile-fullscreen a.close .close-icon-wrap {
  display: inline-block;
  position: relative;
  width: 40px;
  height: 40px;
  line-height: 33px;
  transition: opacity 0.15s linear;
}
#mobile-fullscreen a.close .close-icon-wrap:hover {
  opacity: 0.7;
}
#mobile-fullscreen a.close .close-icon-inner,
#mobile-fullscreen a.close .close-icon-inner::after {
  display: inline-block;
  width: 40px;
  height: 3px;
  background-color: #fff;
  border-radius: 3px;
}
#mobile-fullscreen a.close .close-icon-inner {
  -ms-transform: rotate(45deg);
  transform: rotate(45deg);
}
#mobile-fullscreen a.close .close-icon-inner::after {
  content: "";
  display: block;
  -ms-transform: rotate(-90deg);
  transform: rotate(-90deg);
}
#mobile-fullscreen nav {
  display: table-cell;
  vertical-align: middle;
  padding: 50px 0;
  text-align: center;
}
#mobile-fullscreen ul {
  list-style: none;
  margin: 0;
}
#mobile-fullscreen ul li a {
  display: block;
  position: relative;
  color: #fff;
  letter-spacing: 1px;
  text-transform: uppercase;
  text-align: center;
}
#mobile-fullscreen ul li a:focus {
  outline: 1px dashed rgba(255, 255, 255, 0.6);
}
#mobile-fullscreen ul li a:hover {
  color: #929292;
}
#mobile-fullscreen ul li a i,
#mobile-fullscreen ul li a img {
  margin-right: 10px;
}
#mobile-fullscreen ul li a i.after {
  margin-right: 0;
  margin-left: 10px;
}
#mobile-fullscreen ul li .dropdown-toggle {
  display: inline-block;
  width: 26px;
  padding-left: 5px;
  text-align: center;
}
#mobile-fullscreen ul li .dropdown-toggle:before {
  font-family: "Font Awesome 5 Free";
  font-weight: 600;
  content: "+";
}
#mobile-fullscreen ul li .dropdown-toggle:focus {
  outline: 1px dashed rgba(255, 255, 255, 0.6);
}
#mobile-fullscreen ul li.open-sub > a > .dropdown-toggle:before {
  content: "-";
}
#mobile-fullscreen ul ul.sub-menu {
  display: none;
  list-style: none;
  margin: 0;
  padding: 0;
}
#mobile-fullscreen ul ul.sub-menu li a {
  font-size: 13px;
  padding: 3px 0;
}
#mobile-fullscreen ul > li {
  display: block;
}
#mobile-fullscreen ul > li > a {
  font-size: 18px;
  line-height: 1.2;
  padding: 12px 0;
}
#mobile-fullscreen ul .woo-menu-icon,
#mobile-fullscreen ul .search-toggle-li,
#mobile-fullscreen ul .side-panel-li,
#mobile-fullscreen ul .sidebar-box {
  display: none;
}
#mobile-fullscreen #mobile-search {
  max-width: 220px;
  margin: 10px auto 0;
}
#mobile-fullscreen #mobile-search form {
  position: relative;
}
#mobile-fullscreen #mobile-search input,
#mobile-fullscreen #mobile-search .search-text {
  font-size: 20px;
  padding: 4px 0;
  color: #fff;
  margin: 0;
  text-align: center;
  text-transform: uppercase;
}
#mobile-fullscreen #mobile-search input {
  position: relative;
  border: 0;
  background-color: transparent;
  border-bottom: 1px solid #666;
  border-radius: 0;
  z-index: 2;
}
#mobile-fullscreen #mobile-search input:hover, #mobile-fullscreen #mobile-search input:focus {
  border-color: #fff;
}
#mobile-fullscreen #mobile-search .search-text {
  display: block;
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  right: 0;
  cursor: text;
  -moz-opacity: 0.5;
  -webkit-opacity: 0.5;
  opacity: 0.5;
  z-index: 1;
}
#mobile-fullscreen #mobile-search .search-text i {
  display: inline-block;
  background-color: #fff;
  width: 3px;
  height: 3px;
  margin-left: 3px;
  animation: blink 1s linear infinite;
}
#mobile-fullscreen #mobile-search .search-text i + i {
  animation-delay: 0.2s;
}
#mobile-fullscreen #mobile-search .search-text i + i + i {
  animation-delay: 0.4s;
}
#mobile-fullscreen #mobile-search form.search-filled .search-text {
  -moz-opacity: 0;
  -webkit-opacity: 0;
  opacity: 0;
  transition-duration: 150ms;
}
#mobile-fullscreen .oceanwp-social-menu {
  display: block;
  float: none;
  margin-top: 30px;
  text-align: center;
  right: auto;
}
#mobile-fullscreen .oceanwp-social-menu .social-menu-inner {
  display: block;
  height: auto !important;
}
#mobile-fullscreen .oceanwp-social-menu ul li {
  float: none;
  display: inline-block;
}
#mobile-fullscreen .oceanwp-social-menu.simple-social ul li a {
  color: #fff;
  font-size: 24px;
  padding: 0 16px;
  margin: 0;
  background-color: transparent !important;
}
#mobile-fullscreen .oceanwp-social-menu.simple-social ul li a:hover {
  color: #929292;
}
#mobile-fullscreen .oceanwp-social-menu .colored ul li a,
#mobile-fullscreen .oceanwp-social-menu .minimal ul li a,
#mobile-fullscreen .oceanwp-social-menu .dark ul li a {
  padding: 0 4px;
}
#mobile-fullscreen .oceanwp-social-menu .colored ul li a span,
#mobile-fullscreen .oceanwp-social-menu .minimal ul li a span,
#mobile-fullscreen .oceanwp-social-menu .dark ul li a span {
  font-size: 16px;
  width: 60px;
  height: 60px;
  line-height: 60px;
}
@keyframes blink {
  0% {
    opacity: 1;
  }
  50% {
    opacity: 0;
  }
  100% {
    opacity: 1;
  }
}
/*------------------------------------*
	$PAGE HEADER
*------------------------------------*/
.page-header {
  position: relative;
  background-color: #f5f5f5;
  padding: 34px 0;
}
.page-header .container {
  position: relative;
}

.has-transparent-header .page-header {
  padding: 120px 0 36px 0;
}

body.home .page-header-inner {
  text-align: center;
}

.page-header-title {
  display: block;
  font-size: 24px;
  line-height: 1.4em;
  font-weight: 400;
  margin: 0;
  color: #333;
}

body.breadcrumbs-position-default .page-header-title {
  max-width: 70%;
}

.page-subheading {
  font-size: 15px;
  margin: 0;
}
.page-subheading p:last-child {
  margin: 0;
}

.centered-page-header .page-header-title,
.centered-minimal-page-header .page-header-title {
  max-width: 100% !important;
}

/**
 * Page Header Centered
 */
.centered-page-header {
  text-align: center;
}
.centered-page-header .page-header-title {
  font-size: 32px;
}
.centered-page-header .page-subheading {
  font-size: 18px;
  font-weight: 300;
}

/**
 * Page Header Minimal Centered
 */
.centered-minimal-page-header {
  background-color: #fff;
  border-bottom: 1px solid #f1f1f1;
  text-align: center;
}
.centered-minimal-page-header .page-header-title {
  font-size: 32px;
}
.centered-minimal-page-header .page-subheading {
  font-size: 18px;
  font-weight: 300;
}

/**
 * Page Header Solid Color
 */
.solid-color-page-header .page-header-title {
  color: #fff !important;
}

.solid-color-page-header .site-breadcrumbs,
.solid-color-page-header .site-breadcrumbs a {
  color: #fff !important;
}

.solid-color-page-header .page-subheading {
  color: #fff;
}

/**
 * Page Header Background Image
 */
.background-image-page-header {
  display: -ms-flexbox;
  display: flex;
  -ms-flex-align: center;
      align-items: center;
  width: 100%;
  background-color: #000;
  height: 400px;
  background-position: 50% 0;
  background-repeat: no-repeat;
  background-size: cover;
}
.background-image-page-header .page-header-inner {
  text-align: center;
}
.background-image-page-header .page-subheading {
  position: relative;
  color: #fff;
  font-size: 24px;
  font-weight: 300;
  z-index: 2;
}

.page-header.background-image-page-header .page-header-title {
  position: relative;
  color: #fff;
  font-size: 44px;
  font-weight: 400;
  max-width: 100%;
  z-index: 2;
}

.background-image-page-header-overlay {
  display: block;
  position: absolute;
  top: 0;
  left: 0;
  height: 100%;
  width: 100%;
  background-color: #000;
  z-index: 1;
  -moz-opacity: 0.5;
  -webkit-opacity: 0.5;
  opacity: 0.5;
}

/**
 * Breadcrumbs
 */
.site-breadcrumbs {
  position: absolute;
  right: 0;
  top: 50%;
  max-width: 50%;
  height: 32px;
  line-height: 32px;
  margin-top: -16px;
  font-size: 13px;
  color: #c6c6c6;
  font-weight: normal;
  white-space: nowrap;
  overflow: hidden;
}
.site-breadcrumbs ol {
  margin: 0;
  padding: 0;
  list-style: none;
}
.site-breadcrumbs ol li {
  display: inline-block;
}
.site-breadcrumbs ol li .breadcrumb-sep {
  margin: 0 6px;
}
.site-breadcrumbs.woocommerce-breadcrumbs .breadcrumb-sep {
  margin: 0 6px;
}
.site-breadcrumbs .icon-home.has-text,
.site-breadcrumbs .breadcrumb-home.has-icon {
  display: none;
}
.site-breadcrumbs .breadcrumb-title {
  margin-right: 5px;
}
.site-breadcrumbs .owp-icon {
  vertical-align: text-top;
}

.site-breadcrumbs.position-under-title,
.centered-page-header .site-breadcrumbs,
.centered-minimal-page-header .site-breadcrumbs {
  position: inherit;
  top: auto;
  right: auto;
  margin-top: 0;
  max-width: 100%;
}

.oceanwp-breadcrumb .site-breadcrumbs {
  position: relative;
  top: auto;
  left: auto;
  right: auto;
  max-width: 100%;
  margin-top: 0;
}

.background-image-page-header .site-breadcrumbs {
  display: block;
  position: inherit;
  max-width: 100%;
  margin-top: 20px;
  top: auto;
  right: auto;
  color: #fff;
  text-align: center;
  z-index: 2;
}
.background-image-page-header .site-breadcrumbs a {
  color: #fff;
}
.background-image-page-header .site-breadcrumbs a:hover {
  color: #ddd;
}

/* compatibility with SEOPress */
.site-breadcrumbs nav,
.site-breadcrumbs ol {
  margin: 0;
}

.elementor .site-breadcrumbs {
  position: relative;
  display: block;
  overflow: visible;
}

/*------------------------------------*
  All Devices under 960px
*------------------------------------*/
@media only screen and (max-width: 959px) {
  /* page title */
  body.has-breadcrumbs .page-header-title {
    max-width: 100%;
    width: 100%;
  }
}
/*------------------------------------*
  Tablet Portrait
*------------------------------------*/
@media only screen and (max-width: 959px) {
  /* page header */
  .site-breadcrumbs {
    position: inherit;
    top: auto;
    left: auto;
    right: auto;
    max-width: 100%;
    margin-top: 0;
  }
}
/*------------------------------------*
  Phone Portrait and Landscape
*------------------------------------*/
@media only screen and (max-width: 767px) {
  /* Remove fixed background to fix the IOS bug */
  .page-header {
    background-attachment: initial !important;
  }
  /* page header */
  .page-header-with-background .page-header-title {
    font-size: 36px;
  }
  .centered-page-header .page-header-title,
.centered-minimal-page-header .page-header-title,
.page-header.background-image-page-header .page-header-title {
    font-size: 24px;
  }
  .centered-page-header .page-subheading,
.centered-minimal-page-header .page-header-subheading,
.page-header.background-image-page-header .page-subheading {
    font-size: 14px;
  }
  .background-image-page-header {
    height: auto !important;
  }
  /* breadcrumbs */
  body.has-breadcrumbs .page-header-title {
    max-width: 100%;
    width: 100%;
  }
}
/*------------------------------------*
	$BLOG
*------------------------------------*/
#blog-entries {
  padding-bottom: 0;
}

.blog-entry.post {
  position: relative;
}
.blog-entry.post .thumbnail {
  position: relative;
}
.blog-entry.post .thumbnail a:not(.mejs-volume-slider) {
  display: inline-block;
  position: relative;
  width: 100%;
}
.blog-entry.post .thumbnail .overlay {
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  background-color: rgba(0, 0, 0, 0.2);
  -moz-opacity: 0;
  -webkit-opacity: 0;
  opacity: 0;
  text-align: center;
  transition: all 0.3s ease;
}
.blog-entry.post .thumbnail:hover .overlay {
  -moz-opacity: 1;
  -webkit-opacity: 1;
  opacity: 1;
}
.blog-entry.post .thumbnail img {
  width: 100%;
}
.blog-entry.post ul.meta {
  margin: 0 0 12px;
}
.blog-entry.post .blog-entry-header {
  margin-bottom: 20px;
}
.blog-entry.post .blog-entry-header .entry-title {
  font-size: 24px;
  margin: 0;
}
.blog-entry.post .blog-entry-header .entry-title a {
  font-weight: 600;
  letter-spacing: 0.6px;
}
.blog-entry.post .blog-entry-summary {
  margin-bottom: 20px;
}
.blog-entry.post .blog-entry-summary p:last-child {
  margin-bottom: 0;
}

.thumbnail-caption {
  font-size: 13px;
  margin-top: 0.5em;
  text-align: center;
}

.blog-entry.large-entry {
  border-bottom: 1px solid #f1f1f1;
  margin-bottom: 30px;
  padding-bottom: 30px;
}
.blog-entry.large-entry .thumbnail {
  margin-bottom: 20px;
}
.blog-entry.large-entry .blog-entry-readmore a {
  display: inline-block;
  font-size: 11px;
  line-height: 1;
  border: 1px solid #ddd;
  padding: 10px 16px;
  border-radius: 2px;
  text-transform: capitalize;
  letter-spacing: 1px;
}
.blog-entry.large-entry .blog-entry-readmore a:hover {
  color: #13aff0;
  border-color: #13aff0;
}
.blog-entry.large-entry .blog-entry-readmore a i {
  margin-left: 8px;
}
.blog-entry.large-entry .blog-entry-readmore a svg.owp-icon {
  margin-left: 0.7rem;
}

.has-blog-grid .blog-grid {
  display: -ms-flexbox;
  display: flex;
  -ms-flex-wrap: wrap;
      flex-wrap: wrap;
  margin: 0 auto;
  height: auto !important;
}

.blog-entry.grid-entry {
  -ms-flex-pack: start;
      justify-content: flex-start;
}
.blog-entry.grid-entry .blog-entry-inner {
  padding: 0 1.25rem 1.25rem;
  border: 1px solid #e9e9e9;
}
.blog-entry.grid-entry .thumbnail {
  margin: 0 -1.25rem;
}
.blog-entry.grid-entry .blog-entry-header {
  margin: 1rem 0 1rem;
}
.blog-entry.grid-entry .blog-entry-header .entry-title {
  font-size: 18px;
}
.blog-entry.grid-entry .blog-entry-summary {
  line-height: 1.6;
  margin-top: 0.625rem;
}
.blog-entry.grid-entry .blog-entry-readmore {
  margin-top: 1rem;
}
.blog-entry.grid-entry .blog-entry-readmore a {
  display: inline-block;
  font-size: 12px;
  line-height: 1.2;
  padding-bottom: 0.19rem;
  border-bottom: 1px solid;
  text-transform: capitalize;
}
.blog-entry.grid-entry .blog-entry-readmore a i {
  margin-left: 0.5rem;
}
.blog-entry.grid-entry .blog-entry-readmore a svg.owp-icon {
  margin-left: 0.7rem;
}

.blog-entry.thumbnail-entry {
  border-bottom: 1px solid #f1f1f1;
  margin-bottom: 30px;
  padding-bottom: 30px;
}
.blog-entry.thumbnail-entry .blog-entry-inner {
  display: -ms-flexbox;
  display: flex;
  -ms-flex-direction: row;
      flex-direction: row;
}
.blog-entry.thumbnail-entry .thumbnail,
.blog-entry.thumbnail-entry .blog-entry-content {
  display: -ms-flexbox;
  display: flex;
  -ms-flex-direction: column;
      flex-direction: column;
}
.blog-entry.thumbnail-entry .center .thumbnail,
.blog-entry.thumbnail-entry .center .blog-entry-content {
  -ms-flex-pack: center;
      justify-content: center;
}
.blog-entry.thumbnail-entry .bottom .thumbnail,
.blog-entry.thumbnail-entry .bottom .blog-entry-content {
  -ms-flex-pack: end;
      justify-content: flex-end;
}
.blog-entry.thumbnail-entry .thumbnail {
  width: 45%;
}
.blog-entry.thumbnail-entry .thumbnail a {
  position: relative;
}
.blog-entry.thumbnail-entry .thumbnail .link-entry {
  position: absolute;
  top: 0;
}
.blog-entry.thumbnail-entry .thumbnail .left-position .link-entry {
  right: 0;
}
.blog-entry.thumbnail-entry .thumbnail .right-position .link-entry {
  left: 0;
}
.blog-entry.thumbnail-entry .blog-entry-content {
  width: 55%;
}
.blog-entry.thumbnail-entry .blog-entry-content {
  padding: 6px 0;
}
.blog-entry.thumbnail-entry .left-position .blog-entry-content {
  padding-left: 3em;
}
.blog-entry.thumbnail-entry .right-position .blog-entry-content {
  padding-right: 3em;
}
.blog-entry.thumbnail-entry .blog-entry-category {
  display: block;
  font-size: 12px;
  font-weight: 600;
  letter-spacing: 0.6px;
  line-height: 1.2em;
  text-transform: uppercase;
  margin-bottom: 10px;
}
.blog-entry.thumbnail-entry .blog-entry-category a {
  color: #13aff0;
}
.blog-entry.thumbnail-entry .blog-entry-category a:hover {
  color: #333;
}
.blog-entry.thumbnail-entry .blog-entry-summary {
  margin-bottom: 15px;
}
.blog-entry.thumbnail-entry .blog-entry-bottom {
  display: block;
  border-top: 1px solid #e9e9e9;
  padding-top: 15px;
  font-size: 11px;
  font-weight: 600;
  letter-spacing: 0.6px;
  line-height: 1.2em;
  text-transform: uppercase;
}
.blog-entry.thumbnail-entry .blog-entry-comments,
.blog-entry.thumbnail-entry .blog-entry-comments a,
.blog-entry.thumbnail-entry .blog-entry-date {
  color: #ababab;
}
.blog-entry.thumbnail-entry .blog-entry-comments {
  float: left;
}
.blog-entry.thumbnail-entry .blog-entry-comments i {
  padding-right: 6px;
}
.blog-entry.thumbnail-entry .blog-entry-comments a:hover {
  color: #333;
}
.blog-entry.thumbnail-entry .blog-entry-comments svg.owp-icon {
  width: 17px;
  height: 17px;
  margin-right: 0.7rem;
}
.blog-entry.thumbnail-entry .blog-entry-date {
  float: right;
}
.blog-entry.thumbnail-entry.format-standard.no-featured-image .blog-entry-content {
  width: 100%;
}
.blog-entry.thumbnail-entry.format-standard.no-featured-image .left-position .blog-entry-content {
  padding-left: 0;
}
.blog-entry.thumbnail-entry.format-standard.no-featured-image .right-position .blog-entry-content {
  padding-right: 0;
}

/*------------------------------------*
	Phone Portrait and Landscape
*------------------------------------*/
@media only screen and (max-width: 767px) {
  .blog-entry.thumbnail-entry .blog-entry-inner {
    -ms-flex-direction: column;
        flex-direction: column;
  }
  .blog-entry.thumbnail-entry .thumbnail,
.blog-entry.thumbnail-entry .blog-entry-content {
    width: 100%;
  }
  .blog-entry.thumbnail-entry .blog-entry-content {
    margin-top: 15px;
    padding: 0 !important;
  }
}
ul.meta {
  display: -ms-flexbox;
  display: flex;
  -ms-flex-wrap: wrap;
      flex-wrap: wrap;
  -ms-flex-pack: start;
      justify-content: flex-start;
  color: #4a4a4a;
  font-size: 14px;
  line-height: 1.3;
  margin: 0 0 20px;
  padding: 0 0 10px;
  list-style: none;
}
ul.meta li {
  line-height: 1.5;
  -ms-flex-item-align: end;
      align-self: flex-end;
  -ms-flex-wrap: nowrap;
      flex-wrap: nowrap;
  padding-bottom: 5px;
}
ul.meta li:after {
  padding: 0 6px;
  font-weight: bold;
}
ul.meta li:last-child:after {
  display: none;
  padding: 0;
}
ul.meta li a {
  color: #4a4a4a;
}
ul.meta li a:hover {
  color: #13aff0;
}
ul.meta li i {
  padding-right: 6px;
  font-size: 17px;
}
ul.meta li .owp-icon {
  margin-right: 8px;
}
ul.meta li svg.owp-icon {
  width: 18px;
  height: 18px;
}
ul.meta li .owp-sep {
  padding: 0 5px;
}

ul.obem-default li:after {
  content: "-";
}

ul.obem-modern li:after {
  content: "|";
}

ul.obem-stylish li:after {
  content: "//";
}

ul.obem-none li:after {
  content: "";
  margin: 0 5px;
}

/*------------------------------------*
	Single Post Styling
*------------------------------------*/
.single-post ul.meta {
  font-size: 14.5px;
  border-bottom: 1px solid #f1f1f1;
  padding-bottom: 15px;
}
.single-post ul.meta li:after {
  padding: 0 8px;
}
.single-post ul.meta li i {
  padding-right: 9px;
}
.single-post ul.meta li .owp-icon {
  margin-right: 8px;
}
.single-post ul.meta li svg.owp-icon {
  width: 20px;
  height: 20px;
}

.single-post ul.ospm-default li:after {
  content: "-";
}

.single-post ul.ospm-modern li:after {
  content: "|";
}

.single-post ul.ospm-stylish li:after {
  content: "//";
}

.single-post ul.ospm-none li:after {
  content: "";
  margin: 0 10px;
}

/**
 *  Gallery Format
 */
.gallery-format {
  opacity: 0;
  visibility: hidden;
  height: 0;
}
.gallery-format img,
.gallery-format a.gallery-lightbox {
  display: block;
  position: relative;
  width: 100%;
  margin-bottom: 0;
}
.gallery-format .flickity-button {
  top: calc(100% - 18px);
  width: 30px;
  height: 36px;
  border-radius: 0;
  background-color: rgba(0, 0, 0, 0.6);
  display: -ms-flexbox;
  display: flex;
  -ms-flex-pack: center;
      justify-content: center;
  -ms-flex-align: center;
      align-items: center;
}
.gallery-format .flickity-button:hover {
  background-color: rgba(0, 0, 0, 0.8);
}
.gallery-format .flickity-button:disabled {
  pointer-events: unset;
}
.gallery-format .flickity-button.next {
  right: 0;
}
.gallery-format .flickity-button.previous {
  left: auto;
  right: 30px;
}
.gallery-format .flickity-button svg {
  fill: #fff;
  width: 12px;
  height: auto;
  position: static;
}

/**
 *  Video/audio format
 */
.wp-video {
  width: 100% !important;
}

/**
 * Link Format
 */
.link-entry {
  position: absolute;
  top: 20px;
  right: 20px;
}
.link-entry i {
  display: inline-block;
  width: 60px;
  height: 60px;
  font-size: 22px;
  line-height: 60px;
  background-color: #333;
  color: #fff;
  text-align: center;
  border-radius: 50%;
  transition: all 0.3s ease;
}

.thumbnail:hover i {
  background-color: #13aff0;
}

.link-post-svg-icon {
  width: 60px;
  height: 60px;
  border-radius: 50%;
  background-color: #333;
  text-align: center;
  padding-top: 18px;
}
.link-post-svg-icon .owp-icon {
  width: 22px;
  height: 22px;
}
.link-post-svg-icon .owp-icon use {
  stroke: #fff;
}

/**
 *  Quote format
 */
.post-quote-content,
.post-quote-author {
  position: relative;
  background-color: #13aff0;
  color: #fff;
  font-size: 20px;
  padding: 20px 30px;
  line-height: 1.6;
  z-index: 1;
}

.post-quote-icon {
  position: absolute;
  right: 20px;
  bottom: 10px;
  font-size: 48px;
  -moz-opacity: 0.2;
  -webkit-opacity: 0.2;
  opacity: 0.2;
  z-index: -1;
}
.post-quote-icon svg.owp-icon {
  width: 45px;
  height: 45px;
}

.post-quote-author {
  background-color: #0b7cac;
  font-size: 12px;
  font-weight: 600;
  padding: 10px 30px;
  margin-top: 1px;
  text-transform: uppercase;
  letter-spacing: 0.6px;
}

.single-post .post-quote-wrap {
  margin-bottom: 30px;
}

/**
 * Single Post
 */
.single .thumbnail {
  position: relative;
  margin-bottom: 20px;
}
.single .thumbnail img {
  width: 100%;
}
.single .entry-title {
  font-size: 34px;
  padding: 0 0 20px;
  margin: 0 0 15px;
  border-bottom: 1px solid #f1f1f1;
  letter-spacing: 0.6px;
}

.single-post.content-max-width #main #content-wrap {
  width: 100%;
  max-width: 100%;
}
.single-post.content-max-width .thumbnail,
.single-post.content-max-width .entry-header,
.single-post.content-max-width ul.meta,
.single-post.content-max-width .entry-content h1,
.single-post.content-max-width .entry-content h2,
.single-post.content-max-width .entry-content h3,
.single-post.content-max-width .entry-content h4,
.single-post.content-max-width .entry-content h5,
.single-post.content-max-width .entry-content h6,
.single-post.content-max-width .entry-content blockquote,
.single-post.content-max-width .entry-content p,
.single-post.content-max-width .post-tags,
.single-post.content-max-width .entry-share,
.single-post.content-max-width nav.post-navigation,
.single-post.content-max-width #author-bio,
.single-post.content-max-width #related-posts,
.single-post.content-max-width .comments-area {
  padding-left: 20px;
  padding-right: 20px;
}
.single-post.content-max-width .entry-header,
.single-post.content-max-width ul.meta,
.single-post.content-max-width .entry-content h1,
.single-post.content-max-width .entry-content h2,
.single-post.content-max-width .entry-content h3,
.single-post.content-max-width .entry-content h4,
.single-post.content-max-width .entry-content h5,
.single-post.content-max-width .entry-content h6,
.single-post.content-max-width .entry-content blockquote,
.single-post.content-max-width .entry-content p,
.single-post.content-max-width .wp-block-image,
.single-post.content-max-width .wp-block-buttons,
.single-post.content-max-width .wp-block-gallery,
.single-post.content-max-width .wp-block-video,
.single-post.content-max-width .wp-block-quote,
.single-post.content-max-width .wp-block-text-columns,
.single-post.content-max-width .wp-block-code,
.single-post.content-max-width .entry-content ul,
.single-post.content-max-width .entry-content ol,
.single-post.content-max-width .wp-block-cover-text,
.single-post.content-max-width .wp-block-cover,
.single-post.content-max-width .wp-block-columns,
.single-post.content-max-width .post-tags,
.single-post.content-max-width .comments-area {
  margin: 1.5em auto;
  max-width: 700px;
}
.single-post.content-max-width .wp-block-columns.alignfull h1,
.single-post.content-max-width .wp-block-columns.alignfull h2,
.single-post.content-max-width .wp-block-columns.alignfull h3,
.single-post.content-max-width .wp-block-columns.alignfull h4,
.single-post.content-max-width .wp-block-columns.alignfull h5,
.single-post.content-max-width .wp-block-columns.alignfull h6,
.single-post.content-max-width .wp-block-columns.alignfull blockquote,
.single-post.content-max-width .wp-block-columns.alignfull p,
.single-post.content-max-width .wp-block-columns.alignfull .wp-block-image,
.single-post.content-max-width .wp-block-columns.alignfull .wp-block-buttons,
.single-post.content-max-width .wp-block-columns.alignfull .wp-block-gallery,
.single-post.content-max-width .wp-block-columns.alignfull .wp-block-video,
.single-post.content-max-width .wp-block-columns.alignfull .wp-block-quote,
.single-post.content-max-width .wp-block-columns.alignfull .wp-block-text-columns,
.single-post.content-max-width .wp-block-columns.alignfull .wp-block-code,
.single-post.content-max-width .wp-block-columns.alignfull ul,
.single-post.content-max-width .wp-block-columns.alignfull ol,
.single-post.content-max-width .wp-block-columns.alignfull .wp-block-cover-text,
.single-post.content-max-width .wp-block-columns.alignfull .wp-block-cover,
.single-post.content-max-width .wp-block-columns.alignwide h1,
.single-post.content-max-width .wp-block-columns.alignwide h2,
.single-post.content-max-width .wp-block-columns.alignwide h3,
.single-post.content-max-width .wp-block-columns.alignwide h4,
.single-post.content-max-width .wp-block-columns.alignwide h5,
.single-post.content-max-width .wp-block-columns.alignwide h6,
.single-post.content-max-width .wp-block-columns.alignwide blockquote,
.single-post.content-max-width .wp-block-columns.alignwide p,
.single-post.content-max-width .wp-block-columns.alignwide .wp-block-image,
.single-post.content-max-width .wp-block-columns.alignwide .wp-block-buttons,
.single-post.content-max-width .wp-block-columns.alignwide .wp-block-gallery,
.single-post.content-max-width .wp-block-columns.alignwide .wp-block-video,
.single-post.content-max-width .wp-block-columns.alignwide .wp-block-quote,
.single-post.content-max-width .wp-block-columns.alignwide .wp-block-text-columns,
.single-post.content-max-width .wp-block-columns.alignwide .wp-block-code,
.single-post.content-max-width .wp-block-columns.alignwide ul,
.single-post.content-max-width .wp-block-columns.alignwide ol,
.single-post.content-max-width .wp-block-columns.alignwide .wp-block-cover-text,
.single-post.content-max-width .wp-block-columns.alignwide .wp-block-cover,
.single-post.content-max-width .elementor-section h1,
.single-post.content-max-width .elementor-section h2,
.single-post.content-max-width .elementor-section h3,
.single-post.content-max-width .elementor-section h4,
.single-post.content-max-width .elementor-section h5,
.single-post.content-max-width .elementor-section h6,
.single-post.content-max-width .elementor-section blockquote,
.single-post.content-max-width .elementor-section p,
.single-post.content-max-width .elementor-section .wp-block-image,
.single-post.content-max-width .elementor-section .wp-block-buttons,
.single-post.content-max-width .elementor-section .wp-block-gallery,
.single-post.content-max-width .elementor-section .wp-block-video,
.single-post.content-max-width .elementor-section .wp-block-quote,
.single-post.content-max-width .elementor-section .wp-block-text-columns,
.single-post.content-max-width .elementor-section .wp-block-code,
.single-post.content-max-width .elementor-section ul,
.single-post.content-max-width .elementor-section ol,
.single-post.content-max-width .elementor-section .wp-block-cover-text,
.single-post.content-max-width .elementor-section .wp-block-cover {
  max-width: 100%;
}
.single-post.content-max-width .entry-content ul,
.single-post.content-max-width .entry-content ol {
  padding-left: 40px;
  padding-right: 40px;
}
.single-post.content-max-width .thumbnail {
  margin-top: 0;
}
.single-post.content-max-width .entry-header {
  margin-bottom: 0;
  text-align: center;
}
.single-post.content-max-width ul.meta {
  display: -ms-flexbox;
  display: flex;
  -ms-flex-wrap: wrap;
      flex-wrap: wrap;
  -ms-flex-pack: center;
      justify-content: center;
  color: #4a4a4a;
  font-size: 14px;
  line-height: 1.3;
  margin-bottom: 20px;
  margin-top: 20px;
  padding: 0 0 10px;
  list-style: none;
}
.single-post.content-max-width .wp-block-quote p {
  padding: 0;
}
.single-post.content-max-width .entry-content blockquote p {
  max-width: 100%;
  margin: 0;
  padding: 0;
}
.single-post.content-max-width .thumbnail,
.single-post.content-max-width .wp-block-cover-text.alignwide,
.single-post.content-max-width .wp-block-image.alignwide,
.single-post.content-max-width .wp-block-gallery.alignwide,
.single-post.content-max-width .wp-block-text-columns.alignwide,
.single-post.content-max-width .entry-share,
.single-post.content-max-width nav.post-navigation,
.single-post.content-max-width #author-bio,
.single-post.content-max-width #related-posts {
  margin: 1.5em auto;
  max-width: 1100px;
}
.single-post.content-max-width .wp-block-cover-text.alignfull,
.single-post.content-max-width .wp-block-image.alignfull,
.single-post.content-max-width .wp-block-gallery.alignfull,
.single-post.content-max-width .wp-block-text-columns.alignfull {
  margin: 1.5em 0;
  max-width: 100%;
}
.single-post.content-max-width .wp-block-image.alignfull img {
  width: 100% !important;
}
.single-post.content-max-width .wp-block-image.alignleft,
.single-post.content-max-width .wp-block-image.alignright {
  max-width: 350px;
  margin-top: 0;
  margin-bottom: 0;
}
.single-post.content-max-width .wp-block-image.alignleft {
  margin-left: calc(50% - 350px);
  padding: 14px 36px 14px 0;
}
.single-post.content-max-width .wp-block-image.alignright {
  margin-right: calc(50% - 350px);
  padding: 14px 0 14px 36px;
}
.single-post.content-max-width figure img {
  margin: 0 auto;
}
.single-post.content-max-width .entry-content ul.alignfull,
.single-post.content-max-width .entry-content ol.alignfull {
  padding-left: 0;
  padding-right: 0;
}
.single-post.content-max-width .entry-content ul.alignwide,
.single-post.content-max-width .entry-content ol.alignwide {
  padding-left: 0;
  padding-right: 0;
}

.wp-block-cover-image,
.wp-block-image {
  margin-bottom: 20px;
}

.wp-block-quote.blocks-quote-style-2 {
  border: 0;
}

.wp-block-pullquote {
  border-left-width: 0;
  margin: 0;
}

.wp-block-separator {
  margin: 30px auto;
}
.wp-block-separator.is-style-wide:not(.size-full) {
  max-width: 700px;
}

.elementor-edit-area ul.elementor-editor-element-settings {
  padding: 0 !important;
  margin: 0 !important;
}

/*------------------------------------*
	Phone Landscape
*------------------------------------*/
@media only screen and (max-width: 480px) {
  .single-post.media-above-content .thumbnail {
    margin-bottom: 20px;
  }
  .single-post .entry-title {
    font-size: 26px;
  }
}
/**
 * Single Post Content
 */
.single .entry-content {
  margin-bottom: 20px;
}

.dropcap {
  float: left;
  color: #13aff0;
  font-size: 120px;
  line-height: 80px;
  margin-top: 6px;
  margin-right: 10px;
}

.entry-footer {
  display: inline-block;
  width: 100%;
}

/**
 * Single Post Tags
 */
.single .post-tags {
  font-size: 11px;
  font-weight: 600;
  margin: 30px 0 0;
  text-transform: uppercase;
}

/**
 * Single Post Next Prev
 */
.single nav.post-navigation {
  margin-top: 30px;
  padding-top: 30px;
  border-top: 1px solid #f1f1f1;
}
.single nav.post-navigation:after {
  content: "";
  display: block;
  visibility: hidden;
  clear: both;
  zoom: 1;
  height: 0;
}
.single nav.post-navigation .nav-links .title {
  display: block;
  color: #13aff0;
  line-height: 20px;
}
.single nav.post-navigation .nav-links a {
  display: block;
}
.single nav.post-navigation .nav-links i {
  font-size: 20px;
  line-height: 20px;
}
.single nav.post-navigation .nav-links .post-title {
  display: block;
  font-size: 16px;
  margin: 5px 0 0;
}
.single nav.post-navigation .nav-previous {
  float: left;
  width: 50%;
  text-align: left;
  border-right-width: 1px;
  border-style: solid;
  border-color: #f1f1f1;
  padding-right: 20px;
}
.single nav.post-navigation .nav-previous i,
.single nav.post-navigation .nav-previous .owp-icon {
  float: left;
  margin-right: 20px;
}
.single nav.post-navigation .nav-previous .owp-icon {
  margin-top: 4px;
}
.single nav.post-navigation .nav-next {
  float: right;
  width: 50%;
  text-align: right;
  padding-left: 20px;
}
.single nav.post-navigation .nav-next i,
.single nav.post-navigation .nav-next .owp-icon {
  float: right;
  margin-left: 20px;
}
.single nav.post-navigation .nav-next .owp-icon {
  margin-top: 4px;
}

/*------------------------------------*
	Phone Landscape
*------------------------------------*/
@media only screen and (max-width: 480px) {
  .single nav.post-navigation .nav-links .nav-previous,
.single nav.post-navigation .nav-links .nav-next {
    float: none;
    width: 100%;
    padding: 0;
  }
  .single nav.post-navigation .nav-links .nav-previous {
    border-right-width: 0;
    border-left-width: 0;
  }
}
/**
 * Single Post Author bio
 */
#author-bio {
  position: relative;
  margin-top: 30px;
  padding-top: 30px;
  border-top-width: 1px;
  border-style: solid;
  border-color: #f1f1f1;
}
#author-bio #author-bio-inner {
  display: -ms-flexbox;
  display: flex;
}
#author-bio .author-bio-avatar,
#author-bio .author-bio-avatar img {
  border-radius: 50%;
}
#author-bio .author-bio-avatar {
  min-width: 80px;
  margin-right: 30px;
}
#author-bio .author-bio-avatar img {
  width: 80px;
  height: 80px;
  border: 3px solid #e9e9e9;
}
#author-bio .author-bio-content {
  position: relative;
}
#author-bio .author-bio-title {
  display: inline-block;
  font-size: 18px;
  margin: 0 0 10px;
  text-transform: capitalize;
}
#author-bio .author-bio-description p:last-child {
  margin: 0;
}

.author #author-bio {
  margin: 0 0 30px;
  padding-bottom: 30px;
  border-bottom-width: 1px;
}

/*------------------------------------*
	Phone Landscape
*------------------------------------*/
@media only screen and (max-width: 480px) {
  #author-bio .author-bio-avatar {
    display: none;
  }
}
/**
 * Single Post Related posts
 */
#related-posts {
  margin-top: 30px;
  padding-top: 30px;
  border-top: 1px solid #f1f1f1;
}
#related-posts .title-wrap {
  display: block;
  color: #333;
  font-size: 20px;
  font-weight: 600;
  letter-spacing: 0.6px;
  margin-bottom: 18px;
}
#related-posts ul {
  padding: 0;
  list-style: none;
}
#related-posts .col {
  float: left;
  position: relative;
  min-height: 100px;
  margin: 0;
  text-align: center;
}
#related-posts .span_1_of_3 {
  width: 33.3333333333%;
}

.related-thumb {
  display: block;
  background-color: #222;
}
.related-thumb img {
  display: block;
  width: 100%;
  transition: opacity 0.3s;
}
.related-thumb:hover img {
  -moz-opacity: 0.7;
  -webkit-opacity: 0.7;
  opacity: 0.7;
}

.related-post-title {
  font-size: 16px;
  font-weight: 600;
  margin: 12px 12px 3px 12px;
}
.related-post-title a {
  display: block;
}

time.published {
  font-size: 12px;
}
time.published i {
  padding-right: 5px;
}
time.published svg.owp-icon {
  width: 17px;
  height: 17px;
  margin-right: 0.7rem;
}

/*------------------------------------*
	Phone Portrait and Landscape
*------------------------------------*/
@media only screen and (max-width: 767px) {
  #related-posts .col {
    float: none;
    width: 100%;
    margin-bottom: 30px;
  }
  #related-posts .col:last-child {
    margin-bottom: 0;
  }
}
/*------------------------------------*
	$SIDEBAR
*------------------------------------*/
.widget-area {
  font-size: 13px;
}

.sidebar-box {
  margin-bottom: 40px;
}
.sidebar-box ul {
  margin: 0;
  padding: 0;
  list-style: none;
}

.widget-title {
  display: block;
  line-height: 1;
  font-size: 13px;
  font-weight: 400;
  color: #333;
  border-width: 0 0 0 3px;
  border-style: solid;
  border-color: #13aff0;
  letter-spacing: 1px;
  padding-left: 15px;
  margin: 0 0 20px;
  text-transform: capitalize;
}

/**
 * Widgets > Borders
 */
.oceanwp-widget-recent-posts-li,
.widget_categories li,
.widget_recent_entries li,
.widget_archive li,
.widget_recent_comments li,
.widget-recent-posts-icons li,
.site-footer .widget_nav_menu li {
  padding: 6px 0;
  border-bottom: 1px solid #e9e9e9;
}
.oceanwp-widget-recent-posts-li:first-child,
.widget_categories li:first-child,
.widget_recent_entries li:first-child,
.widget_archive li:first-child,
.widget_recent_comments li:first-child,
.widget-recent-posts-icons li:first-child,
.site-footer .widget_nav_menu li:first-child {
  border-top: 1px solid #e9e9e9;
}

/*------------------------------------*
	Phone Portrait and Landscape
*------------------------------------*/
@media only screen and (max-width: 767px) {
  #main .widget_nav_menu li a:before {
    display: none;
  }
}
/*------------------------------------*
	$CUSTOM SELECTS
*------------------------------------*/
.hasCustomSelect {
  width: 100%;
  z-index: 2;
}

.theme-select {
  position: relative;
  border: 1px solid #ddd;
  color: #555;
  height: 34px;
  line-height: 32px;
  padding: 0 45px 0 15px;
  width: 100%;
  z-index: 1;
  overflow: hidden;
}
.theme-select:after {
  font-family: "Font Awesome 5 Free";
  content: "\f107";
  position: absolute;
  right: 0;
  top: 0;
  display: block;
  height: 32px;
  width: 32px;
  font-size: 11px;
  font-weight: 600;
  color: #929292;
  border-left: 1px solid #ddd;
  text-align: center;
}

/*------------------------------------*
	$PAGINATION
*------------------------------------*/
ul.page-numbers {
  display: inline-block;
  width: 100%;
  margin: 0;
  padding: 10px 0 0;
  list-style: none;
  text-align: right;
  clear: both;
}
ul.page-numbers li {
  display: inline-block;
}
ul.page-numbers li .owp-icon {
  vertical-align: inherit;
}

.page-links {
  text-align: center;
  margin: 15px 0;
}

.page-numbers a,
.page-numbers span:not(.elementor-screen-only),
.page-links span {
  position: relative;
  display: inline-block;
  min-width: 38px;
  min-width: 38px;
  line-height: 38px;
  margin: 0 8px 0 0;
  text-align: center;
  color: #555;
  border: 1px solid #e9e9e9;
  font-size: 18px;
  cursor: pointer;
  white-space: nowrap;
  border-radius: 2px;
  transition: all 0.3s ease;
  box-sizing: content-box;
}

.page-numbers a .owp-icon use {
  stroke: #555;
}

.page-numbers a span:not(.elementor-screen-only) {
  padding: 0;
}

.page-numbers a:hover,
.page-links a:hover span,
.page-numbers.current,
.page-numbers.current:hover,
.page-links > span {
  background-color: #f8f8f8;
  color: #333;
}

.page-numbers a:hover .owp-icon use {
  stroke: #555;
}

.elementor-pagination .page-numbers.current,
.elementor-pagination .page-numbers.current:hover {
  background-color: transparent;
}

.pagination-center .oceanwp-pagination ul.page-numbers,
.pagination-center .oceanwp-pagination .page-links,
.pagination-center .woocommerce-pagination ul.page-numbers,
.pagination-center .woocommerce-pagination .page-links {
  text-align: center;
}

.pagination-left .oceanwp-pagination ul.page-numbers,
.pagination-left .oceanwp-pagination .page-links,
.pagination-left .woocommerce-pagination ul.page-numbers,
.pagination-left .woocommerce-pagination .page-links {
  text-align: left;
}

/* next/prev */
.page-jump a {
  display: inline-block;
  font-size: 12px;
  line-height: 1.2;
  padding-bottom: 3px;
  border-bottom: 1px solid;
  text-transform: uppercase;
}

/* infinite scroll */
.scroller-status,
.infinite-scroll-last,
.infinite-scroll-error {
  display: none;
}

.scroller-status {
  margin-top: 20px;
  text-align: center;
  clear: both;
}
.scroller-status p {
  margin: 0;
}

.loader-ellips {
  font-size: 12px;
  position: relative;
  width: 3.5em;
  height: 1em;
  margin: 0 auto;
}

.loader-ellips__dot {
  display: block;
  width: 1em;
  height: 1em;
  border-radius: 0.5em;
  background-color: #333;
  position: absolute;
  animation-duration: 0.5s;
  animation-timing-function: ease;
  animation-iteration-count: infinite;
}
.loader-ellips__dot:nth-child(1), .loader-ellips__dot:nth-child(2) {
  left: 0;
}
.loader-ellips__dot:nth-child(3) {
  left: 1.3em;
}
.loader-ellips__dot:nth-child(4) {
  left: 2.6em;
}
.loader-ellips__dot:nth-child(1) {
  animation-name: reveal;
}
.loader-ellips__dot:nth-child(2), .loader-ellips__dot:nth-child(3) {
  animation-name: slide;
}
.loader-ellips__dot:nth-child(4) {
  animation-name: reveal;
  animation-direction: reverse;
}

@keyframes reveal {
  from {
    transform: scale(0.001);
  }
  to {
    transform: scale(1);
  }
}
@keyframes slide {
  to {
    transform: translateX(1.3em);
  }
}
.infinite-scroll-nav {
  display: none;
}

/*------------------------------------*
	$COMMENT
*------------------------------------*/
#respond {
  margin-bottom: 20px;
}
#respond form {
  display: inline-block;
  width: 100%;
}
#respond .comment-textarea,
#respond .comment-form-author,
#respond .comment-form-email,
#respond .comment-form-url {
  margin-bottom: 20px;
}
#respond .comment-form-author,
#respond .comment-form-email,
#respond .comment-form-url {
  float: left;
  width: 33.33%;
}
#respond .comment-form-author {
  padding-right: 10px;
}
#respond .comment-form-email {
  padding: 0 10px;
}
#respond .comment-form-url {
  padding-left: 10px;
}
#respond input[type=text] {
  width: 100%;
}
#respond #wp-comment-cookies-consent:focus {
  outline: 1px solid;
}
#respond .form-submit {
  float: right;
  margin-bottom: 0;
}

#comments {
  margin-top: 30px;
  padding-top: 30px;
  border-top: 1px solid #f1f1f1;
}
#comments ol {
  margin: 0;
  list-style: none;
}
#comments ol.children {
  margin-left: 30px;
}
#comments.empty-closed-comments {
  display: none;
}

.comment-body {
  display: -ms-flexbox;
  display: flex;
  margin-bottom: 30px;
  padding-bottom: 30px;
  border-bottom: 1px solid #f1f1f1;
}
.comment-body img.avatar {
  width: 80px;
  height: 80px;
  margin-right: 30px;
  border-radius: 50%;
}
.comment-body .comment-content {
  position: relative;
  width: 100%;
}

.comment-author {
  display: inline-block;
  width: 100%;
}
.comment-author .comment-link, .comment-author .comment-meta {
  font-weight: 600;
  margin: 5px 0 8px;
}
.comment-author .comment-link {
  float: left;
  font-size: 18px;
}
.comment-author .comment-meta {
  float: right;
  text-align: right;
  font-size: 10px;
  line-height: 2.5;
  text-transform: uppercase;
  letter-spacing: 0.1em;
}
.comment-author .comment-meta .comment-reply-link, .comment-author .comment-meta .comment-edit-link {
  margin-left: 15px;
}

.comment-author .comment-meta .comment-reply-link {
  color: #13aff0;
}

.comment-author .comment-meta .comment-reply-link:hover {
  color: #333;
}

#respond #cancel-comment-reply-link {
  font-size: 10px;
  color: #929292;
  float: right;
  border: 2px solid #f1f1f1;
  padding: 3px 10px;
  border-radius: 3px;
  text-transform: uppercase;
  letter-spacing: 0.1em;
}
#respond #cancel-comment-reply-link:hover {
  color: #13aff0;
  border-color: #13aff0;
}

span.required {
  position: relative;
  top: -4px;
  font-size: 10px;
  margin-left: 3px;
  color: #F00;
}

.comment-body p {
  margin: 0;
}

.no-comments {
  text-align: right;
}
.no-comments i {
  margin-right: 8px;
}

.comment-navigation {
  display: inline-block;
  width: 100%;
}
.comment-navigation .nav-links a {
  display: inline-block;
  font-size: 12px;
  line-height: 1.2;
  padding-bottom: 3px;
  border-bottom: 1px solid;
  text-transform: uppercase;
}
.comment-navigation .nav-links .nav-previous {
  float: left;
  margin-right: 1.5em;
}
.comment-navigation .nav-links .nav-previous i {
  margin-right: 5px;
}
.comment-navigation .nav-links .nav-next {
  float: right;
  margin-left: 1.5em;
}
.comment-navigation .nav-links .nav-next i {
  margin-left: 5px;
}

/*------------------------------------*
	Phone Portrait and Landscape
*------------------------------------*/
@media only screen and (max-width: 767px) {
  #comments ol.children {
    margin-left: 0;
    margin-right: 0;
  }
  #respond .comment-form-author,
#respond .comment-form-email,
#respond .comment-form-url {
    float: none;
    width: 100%;
    padding-right: 0;
    padding: 0;
    padding-left: 0;
  }
}
/*------------------------------------*
	Phone Landscape
*------------------------------------*/
@media only screen and (max-width: 480px) {
  .comment-body img {
    display: none;
  }
  .comment-author {
    margin-bottom: 16px;
  }
  .comment-author .comment-link,
.comment-author .comment-meta {
    float: none;
  }
}
/*------------------------------------*
	$SEARCH
*------------------------------------*/
.search-results article {
  position: relative;
  width: 100%;
  margin-bottom: 20px;
  padding-bottom: 20px;
  border-bottom: 1px solid #e9e9e9;
}
.search-results article .search-entry-inner {
  display: -ms-flexbox;
  display: flex;
  -ms-flex-align: center;
      align-items: center;
}
.search-results article .thumbnail {
  min-width: 120px;
  margin-right: 20px;
}
.search-results article .thumbnail img {
  border-radius: 5px;
  box-shadow: 0 0 5px rgba(0, 0, 0, 0.3);
}
.search-results article .search-entry-title {
  font-size: 24px;
  margin: 0 0 6px;
}
.search-results article .search-entry-summary p:last-child {
  margin-bottom: 0;
}
.search-results article .search-entry-readmore a {
  display: inline-block;
  font-size: 12px;
  font-weight: 600;
  line-height: 1;
  padding-bottom: 3px;
  border-bottom: 1px solid;
  text-transform: uppercase;
  letter-spacing: 0.6px;
}
.search-results article ul {
  list-style: none;
}

/*------------------------------------*
    Phone Landscape
*------------------------------------*/
@media only screen and (max-width: 480px) {
  .search-results article .thumbnail {
    display: none;
  }
}
/*------------------------------------*
	$FOOTER
*------------------------------------*/
.site-footer {
  position: relative;
}

/**
 * Footer widgets
 */
#footer-widgets {
  background-color: #222;
  padding: 30px 0;
  margin: 0;
}
#footer-widgets .footer-box {
  padding: 0 15px;
  margin: 0;
}
#footer-widgets .footer-box .footer-widget {
  margin-bottom: 20px;
}
#footer-widgets .footer-box .footer-widget:last-child {
  margin-bottom: 0;
}
#footer-widgets .footer-box .footer-widget ul {
  margin: 0;
  padding: 0;
  list-style: none;
}
#footer-widgets .footer-box .widget-title {
  color: #fff;
}
#footer-widgets .footer-box a {
  color: #fff;
}
#footer-widgets .footer-box a:hover {
  color: #13aff0;
}
#footer-widgets #wp-calendar caption,
#footer-widgets #wp-calendar th,
#footer-widgets #wp-calendar tbody,
#footer-widgets .contact-info-widget i,
#footer-widgets .contact-info-widget .owp-icon,
#footer-widgets .mailchimp-widget input[type=email],
#footer-widgets .posts-thumbnails-widget li,
#footer-widgets .social-widget li a {
  border-color: #555;
}
#footer-widgets .mailchimp-widget input[type=email]:focus {
  border-color: #13aff0;
}
#footer-widgets .tagcloud a {
  background-color: #222;
  border-color: #333;
}
#footer-widgets .tagcloud a:hover {
  background-color: #444;
  color: #fff;
  border-color: #555;
}

/**
 * Parallax footer
 */
.parallax-footer {
  position: fixed;
  bottom: 0;
  left: 0;
  right: 0;
  z-index: 0;
}

.has-parallax-footer #main {
  z-index: 1;
}

.has-parallax-footer:not(.boxed-layout) #main {
  box-shadow: 0 0 40px 0 rgba(0, 0, 0, 0.1);
}

.has-parallax-footer:not(.separate-layout) #main {
  background-color: #fff;
}

.has-parallax-footer.separate-layout #main {
  background-color: #f1f1f1;
}

.boxed-layout .parallax-footer {
  width: 1280px;
  left: auto;
  right: auto;
}

/*------------------------------------*
	All Devices under 960px
*------------------------------------*/
@media only screen and (max-width: 959px) {
  /* margin footer columns */
  #footer-widgets .col {
    margin-bottom: 30px;
  }
  /* Parallax footer */
  .has-parallax-footer #main {
    margin-bottom: 0 !important;
  }
  .parallax-footer {
    position: relative;
  }
}
/* Responsive columns */
@media only screen and (min-width: 481px) and (max-width: 768px) {
  #footer-widgets.tablet-1-col .footer-box {
    width: 100%;
  }
  #footer-widgets.tablet-2-col .footer-box {
    width: 50% !important;
  }
  #footer-widgets.tablet-2-col .footer-box:nth-child(3n) {
    clear: left;
  }
  #footer-widgets.tablet-3-col .footer-box {
    width: 33.33% !important;
    clear: none;
  }
  #footer-widgets.tablet-3-col .footer-box:nth-child(4n) {
    clear: left;
  }
  #footer-widgets.tablet-4-col .footer-box {
    width: 25% !important;
  }
  #footer-widgets.tablet-4-col .footer-box:nth-child(5n) {
    clear: left;
  }
}
@media only screen and (max-width: 480px) {
  #footer-widgets.mobile-1-col .footer-box {
    width: 100%;
  }
  #footer-widgets.mobile-2-col .footer-box {
    width: 50% !important;
  }
  #footer-widgets.mobile-2-col .footer-box:nth-child(3n) {
    clear: left;
  }
  #footer-widgets.mobile-3-col .footer-box {
    width: 33.33% !important;
    clear: none;
  }
  #footer-widgets.mobile-3-col .footer-box:nth-child(4n) {
    clear: left;
  }
  #footer-widgets.mobile-4-col .footer-box {
    width: 25% !important;
  }
  #footer-widgets.mobile-4-col .footer-box:nth-child(5n) {
    clear: left;
  }
}
/**
 * Footer bottom
 */
#footer-bottom {
  background-color: #1B1B1B;
  padding: 15px 0;
  font-size: 12px;
  line-height: 1;
  color: #fff;
}
#footer-bottom #footer-bottom-menu, #footer-bottom #copyright {
  width: 50%;
}
#footer-bottom #footer-bottom-menu {
  float: right;
  text-align: right;
  padding-left: 15px;
}
#footer-bottom #footer-bottom-menu ul {
  display: inline-block;
  margin: 0;
  list-style: none;
  margin: 0;
  padding: 0;
}
#footer-bottom #footer-bottom-menu li {
  float: left;
}
#footer-bottom #footer-bottom-menu li:after {
  content: "|";
  margin-left: 5px;
  margin-right: 5px;
}
#footer-bottom #footer-bottom-menu li:last-child:after {
  content: "";
  margin-left: 0;
  margin-right: 0;
}
#footer-bottom #footer-bottom-menu a {
  color: #fff;
}
#footer-bottom #footer-bottom-menu a:hover {
  color: #13aff0;
}
#footer-bottom.no-footer-nav #copyright {
  float: none;
  width: 100%;
  text-align: center;
  padding-left: 0 !important;
  padding-right: 0 !important;
}
#footer-bottom #copyright {
  float: left;
  text-align: left;
  padding-right: 15px;
}
#footer-bottom a {
  color: #fff;
}
#footer-bottom a:hover {
  color: #13aff0;
}

/*------------------------------------*
	All Devices under 960px
*------------------------------------*/
@media only screen and (max-width: 959px) {
  /* center footer bottom */
  #footer-bottom #copyright,
#footer-bottom #footer-bottom-menu {
    float: none;
    width: 100%;
    padding-right: 0;
    padding-left: 0;
    text-align: center;
  }
  #footer-bottom #footer-bottom-menu {
    margin-bottom: 15px;
  }
  #footer-bottom #footer-bottom-menu li {
    float: none;
    display: inline-block;
  }
}
/*------------------------------------*
	Phone Landscape
*------------------------------------*/
@media only screen and (max-width: 480px) {
  #footer-bottom #footer-bottom-menu li {
    margin-bottom: 8px;
  }
}
/**
 * Scroll top
 */
#scroll-top {
  display: none;
  opacity: 0;
  position: fixed;
  right: 20px;
  bottom: 20px;
  width: 40px;
  height: 40px;
  line-height: 40px;
  background-color: rgba(0, 0, 0, 0.4);
  color: #fff;
  font-size: 18px;
  cursor: pointer;
  border-radius: 2px;
  text-align: center;
  z-index: 100;
  box-sizing: content-box;
}
#scroll-top > span {
  line-height: inherit;
  vertical-align: top;
}
#scroll-top:hover {
  background-color: rgba(0, 0, 0, 0.8);
}
#scroll-top.scroll-top-left {
  left: 20px;
  right: auto;
}
#scroll-top .owp-icon {
  vertical-align: initial;
}
#scroll-top .owp-icon use {
  stroke: #fff;
}

/*------------------------------------*
	Phone Landscape
*------------------------------------*/
@media only screen and (max-width: 480px) {
  #scroll-top {
    right: 10px;
    bottom: 10px;
    width: 26px;
    height: 26px;
    line-height: 24px;
    font-size: 14px;
  }
}
/*------------------------------------*
	$404 PAGE
*------------------------------------*/
.error404-content {
  position: relative;
  margin: 0 auto;
  text-align: center;
}
.error404-content .error-title {
  font-size: 46px;
  margin: 0 0 25px;
}
.error404-content .error-text {
  font-size: 18px;
  font-weight: 300;
  margin-bottom: 35px;
}
.error404-content .searchform {
  max-width: 390px;
  margin: 0 auto;
}
.error404-content .error-btn {
  font-size: 13px;
  padding: 14px 26px;
  margin-top: 60px;
}
.error404-content .error-btn:hover {
  color: #fff;
}

/*------------------------------------*
    Phone Landscape
*------------------------------------*/
@media only screen and (max-width: 480px) {
  .error404-content .searchform {
    width: 100%;
  }
  .error404-content .error-btn {
    margin-top: 40px;
  }
}
/*------------------------------------*
	$GENERAL
*------------------------------------*/
/* Fix for the tabs under the header in the edit mode */
.fl-builder-edit #site-header,
.fl-builder-edit.has-transparent-header #site-header,
.elementor-editor-active #site-header {
  z-index: 1;
}

.fl-builder-edit #main,
.elementor-editor-active #main {
  z-index: inherit !important;
}

/* Fix the height automatically in the custom header style */
#site-header .elementor-section-wrap {
  height: auto !important;
}

/* Fix image alignment with caption issue */
.elementor-widget-image .elementor-image img {
  display: inline-block;
}

/* Fix carousel next/prev bug in Elementor */
.elementor-slick-slider .slick-prev,
.elementor-slick-slider .slick-next {
  height: auto;
}

/* Fix background hover color on the photoswipe buttons */
.pswp__button:hover {
  background-color: transparent;
}

/* Fix bug with MotoPress */
div.motopress-bootstrap-dropdown .dropdown-menu {
  display: block !important;
  position: static !important;
}

/* Fix problem with Geolocation addon of Caldera form in the Ocean Modal Window */
.pac-container {
  z-index: 100003;
}

/* Remove the Elementor section min height if the no-height class is added */
.no-height .elementor-column {
  min-height: 0;
}

/* WooCommerce issues with Elementor Pro */
body .elementor-element.elementor-wc-products ul.products li.product .onsale {
  padding: 8px 12px;
}

body .elementor-element.elementor-wc-products ul.products li.product.circle-sale .onsale {
  padding: 0;
}

@media only screen and (max-width: 959px) {
  .elementor-element.elementor-wc-products ul.products li.product {
    width: auto !important;
  }
}
/* Fix parallax footer issue in the Elementor editor */
.elementor-editor-active .parallax-footer {
  z-index: -1;
}

/* Fix checkbox issue in Elementor */
.elementor-field-type-acceptance .elementor-field-subgroup .elementor-field-option input[type=checkbox] {
  display: inline-block;
}

/*------------------------------------*
	$SIDR
*------------------------------------*/
#sidr-close,
.sidebar-mobile #mobile-nav {
  display: none;
}

#sidr {
  display: block;
  position: fixed;
  top: 0;
  height: 100%;
  z-index: 999999;
  width: 300px;
  max-width: 100%;
  padding-bottom: 30px;
  overflow-x: hidden;
  overflow-y: auto;
  font-size: 15px;
  background-color: #fff;
  color: #555;
  -webkit-touch-callout: none;
  -webkit-user-select: none;
      -ms-user-select: none;
          user-select: none;
  -webkit-overflow-scrolling: touch;
}
#sidr ul {
  margin: 0;
  list-style: none;
}

.sidr.right {
  left: auto;
  right: -300px;
}

.sidr.left {
  left: -300px;
  right: auto;
}

.sidr a {
  color: #555;
}

.sidr a:hover,
.sidr-class-dropdown-toggle:hover,
.sidr-class-menu-item-has-children.active > a,
.sidr-class-menu-item-has-children.active > a > .sidr-class-dropdown-toggle {
  color: #13aff0;
}

.sidr-class-clr:after {
  content: "";
  display: block;
  visibility: hidden;
  clear: both;
  zoom: 1;
  height: 0;
}

a.sidr-class-toggle-sidr-close {
  display: block;
  background-color: #f8f8f8;
  color: #333;
  font-size: 13px;
  font-weight: 600;
  line-height: 1;
  padding: 20px;
  letter-spacing: 0.6px;
  text-transform: uppercase;
}
a.sidr-class-toggle-sidr-close i {
  display: inline-block;
  padding-right: 8px;
  margin: 0;
  width: auto;
  height: auto;
  line-height: 1;
  vertical-align: bottom;
}
a.sidr-class-toggle-sidr-close .owp-icon {
  margin-right: 8px;
}

.sidr-class-dropdown-menu ul,
.sidr-class-fs-dropdown-menu ul {
  display: none;
  border-top: 1px solid rgba(0, 0, 0, 0.035);
  margin-left: 0;
  background-color: rgba(0, 0, 0, 0.02);
}
.sidr-class-dropdown-menu li,
.sidr-class-fs-dropdown-menu li {
  border-bottom: 1px solid rgba(0, 0, 0, 0.035);
}
.sidr-class-dropdown-menu.sidr-class-left-menu li:last-child,
.sidr-class-fs-dropdown-menu.sidr-class-left-menu li:last-child {
  border-bottom: none;
}
.sidr-class-dropdown-menu > li:first-child,
.sidr-class-fs-dropdown-menu > li:first-child {
  border-top: 1px solid rgba(0, 0, 0, 0.035);
}
.sidr-class-dropdown-menu li a,
.sidr-class-fs-dropdown-menu li a {
  padding: 12px 20px;
  display: block;
  position: relative;
}
.sidr-class-dropdown-menu li a:focus,
.sidr-class-fs-dropdown-menu li a:focus {
  outline: 1px dashed rgba(0, 0, 0, 0.3);
}
.sidr-class-dropdown-menu li a.sidr-class-sf-with-ul,
.sidr-class-fs-dropdown-menu li a.sidr-class-sf-with-ul {
  padding-right: 40px;
}
.sidr-class-dropdown-menu ul li:last-child,
.sidr-class-fs-dropdown-menu ul li:last-child {
  border: none;
}

.sidr-class-top-bar-menu > li:first-child {
  border-top: none;
}

.sidr-class-menu-item-has-children {
  position: relative;
}

.sidr-class-dropdown-menu li.sidr-class-menu-item-has-children > a {
  padding-right: 60px;
}

.sidr-class-dropdown-toggle {
  font-size: 11px;
  height: 100%;
  width: 60px;
  position: absolute;
  right: 0;
  top: 0;
  cursor: pointer;
  color: #555;
  text-align: right;
  padding-right: 20px;
  text-align: center;
  transition: all 0.3s ease;
}
.sidr-class-dropdown-toggle:focus {
  outline: 1px dashed rgba(0, 0, 0, 0.3);
}
.sidr-class-dropdown-toggle:before {
  font-family: "Font Awesome 5 Free";
  content: "+";
  font-size: 20px;
  position: absolute;
  top: 50%;
  left: 50%;
  width: 30px;
  height: 30px;
  line-height: 30px;
  margin-top: -15px;
  margin-left: -15px;
}

.sidr-class-dropdown-menu li.active > a > .sidr-class-dropdown-toggle:before {
  content: "-";
}
.sidr-class-dropdown-menu ul a:before {
  font-family: "Font Awesome 5 Free";
  content: "\f105";
  display: inline-block;
  margin: 0 10px;
  font-weight: 600;
}
.sidr-class-dropdown-menu ul ul a:before {
  margin-left: 20px;
}
.sidr-class-dropdown-menu ul ul ul a:before {
  margin-left: 40px;
}

.sidr-class-middle-site-logo,
.sidr #searchform-header-replace-close,
.sidr #sidr-id-searchform-overlay,
.sidr .sidr-class-nav-arrow,
.sidr-class-sidebar-box,
.sidr-class-mega-cat .sidr-class-dropdown-toggle,
.sidr-class-mega-cat .sidr-class-megamenu,
.sidr-class-elementor {
  display: none !important;
}

.sidr-class-dropdown-menu li.sidr-class-menu-item-has-children.sidr-class-mega-cat > a {
  padding-right: 20px;
}

/* Icons */
.sidr-class-dropdown-menu a i {
  font-size: inherit !important;
  vertical-align: initial !important;
  margin-right: 10px;
}
.sidr-class-dropdown-menu a i.after {
  margin-right: 0;
  margin-left: 10px;
}

/* WPML img */
.sidr-class-wpml-ls-flag {
  margin-right: 10px;
  vertical-align: baseline;
}

/* Overlay */
.oceanwp-sidr-overlay {
  position: fixed;
  top: 0;
  left: 0;
  height: 100%;
  width: 100%;
  background: rgba(0, 0, 0, 0.3);
  z-index: 99;
}

/* Search */
#mobile-menu-search,
.sidr-class-woo-cart-link,
.sidr-class-search-toggle-li,
#sidr-id-searchform-dropdown,
#sidr-id-searchform-header-replace {
  display: none;
}

.sidr-class-mobile-searchform {
  position: relative;
  margin: 30px 20px 0;
}
.sidr-class-mobile-searchform input {
  padding: 6px 45px 6px 12px !important;
  margin-top: 0 !important;
  box-sizing: inherit;
}
.sidr-class-mobile-searchform button {
  display: block;
  position: absolute;
  right: 10px;
  height: 30px;
  line-height: 30px;
  width: 30px;
  padding: 0;
  text-align: center;
  top: 50%;
  margin-top: -15px;
  background-color: transparent !important;
  color: #555;
  border: 0;
  transition: all 0.3s ease-in-out;
}
.sidr-class-mobile-searchform button:hover {
  color: #222;
}
.sidr-class-mobile-searchform button:focus {
  outline: 1px solid;
  color: #1a1a1a;
}

/* Social */
.sidr-class-social-menu-inner ul {
  display: table;
  width: 100%;
  text-align: center;
  table-layout: fixed;
}
.sidr-class-social-menu-inner ul li {
  display: table-cell;
}
.sidr-class-social-menu-inner ul li a {
  display: block;
  padding: 12px 10px;
}

.admin-bar #sidr,
.admin-bar .oceanwp-sidr-overlay {
  top: 32px;
  height: calc(100% - 32px);
}

@media screen and (max-width: 782px) {
  .admin-bar #sidr,
.admin-bar .oceanwp-sidr-overlay {
    top: 46px;
    height: calc(100% - 46px);
  }
}
/*------------------------------------*
	$PERFECT SCROLLBAR
*------------------------------------*/
/*
 * Container style
 */
.ps {
  overflow: hidden !important;
  overflow-anchor: none;
  -ms-overflow-style: none;
  touch-action: auto;
  -ms-touch-action: auto;
}

/*
 * Scrollbar rail styles
 */
.ps__rail-x {
  display: none;
  opacity: 0;
  transition: background-color 0.2s linear, opacity 0.2s linear;
  -webkit-transition: background-color 0.2s linear, opacity 0.2s linear;
  height: 15px;
  /* there must be 'bottom' or 'top' for ps__rail-x */
  bottom: 0px;
  /* please don't change 'position' */
  position: absolute;
}

.ps__rail-y {
  display: none;
  opacity: 0;
  transition: background-color 0.2s linear, opacity 0.2s linear;
  -webkit-transition: background-color 0.2s linear, opacity 0.2s linear;
  width: 15px;
  /* there must be 'right' or 'left' for ps__rail-y */
  right: 0;
  /* please don't change 'position' */
  position: absolute;
}

.ps--active-x > .ps__rail-x,
.ps--active-y > .ps__rail-y {
  display: block;
  background-color: transparent;
}

.ps:hover > .ps__rail-x,
.ps:hover > .ps__rail-y,
.ps--focus > .ps__rail-x,
.ps--focus > .ps__rail-y,
.ps--scrolling-x > .ps__rail-x,
.ps--scrolling-y > .ps__rail-y {
  opacity: 0.6;
}

.ps .ps__rail-x:hover,
.ps .ps__rail-y:hover,
.ps .ps__rail-x:focus,
.ps .ps__rail-y:focus,
.ps .ps__rail-x.ps--clicking,
.ps .ps__rail-y.ps--clicking {
  background-color: #eee;
  opacity: 0.9;
}

/*
 * Scrollbar thumb styles
 */
.ps__thumb-x {
  background-color: #aaa;
  border-radius: 6px;
  transition: background-color 0.2s linear, height 0.2s ease-in-out;
  -webkit-transition: background-color 0.2s linear, height 0.2s ease-in-out;
  height: 6px;
  /* there must be 'bottom' for ps__thumb-x */
  bottom: 2px;
  /* please don't change 'position' */
  position: absolute;
}

.ps__thumb-y {
  background-color: #aaa;
  border-radius: 6px;
  transition: background-color 0.2s linear, width 0.2s ease-in-out;
  -webkit-transition: background-color 0.2s linear, width 0.2s ease-in-out;
  width: 6px;
  /* there must be 'right' for ps__thumb-y */
  right: 2px;
  /* please don't change 'position' */
  position: absolute;
}

.ps__rail-x:hover > .ps__thumb-x,
.ps__rail-x:focus > .ps__thumb-x,
.ps__rail-x.ps--clicking .ps__thumb-x {
  background-color: #999;
  height: 11px;
}

.ps__rail-y:hover > .ps__thumb-y,
.ps__rail-y:focus > .ps__thumb-y,
.ps__rail-y.ps--clicking .ps__thumb-y {
  background-color: #999;
  width: 11px;
}

/* MS supports */
@supports (-ms-overflow-style: none) {
  .ps {
    overflow: auto !important;
  }
}
@media screen and (-ms-high-contrast: active), (-ms-high-contrast: none) {
  .ps {
    overflow: auto !important;
  }
}
/*------------------------------------*
	$FLICKITY
*------------------------------------*/
/*! Flickity v2.2.2
https://flickity.metafizzy.co
---------------------------------------------- */
.flickity-enabled {
  position: relative;
}

.flickity-enabled:focus {
  outline: none;
}

.flickity-viewport {
  overflow: hidden;
  position: relative;
  height: 100%;
}

.flickity-slider {
  position: absolute;
  width: 100%;
  height: 100%;
}

/* draggable */
.flickity-enabled.is-draggable {
  -webkit-tap-highlight-color: transparent;
  -webkit-user-select: none;
  -ms-user-select: none;
  user-select: none;
}

.flickity-enabled.is-draggable .flickity-viewport {
  cursor: move;
  cursor: grab;
}

.flickity-enabled.is-draggable .flickity-viewport.is-pointer-down {
  cursor: grabbing;
}

/* ---- flickity-button ---- */
.flickity-button {
  position: absolute;
  background: hsla(0deg, 0%, 100%, 0.75);
  border: none;
  color: #333;
}

.flickity-button:hover {
  background: white;
  cursor: pointer;
}

.flickity-button:focus {
  outline: none;
  box-shadow: 0 0 0 5px #19F;
}

.flickity-button:active {
  opacity: 0.6;
}

.flickity-button:disabled {
  opacity: 0.3;
  cursor: auto;
  /* prevent disabled button from capturing pointer up event. #716 */
  pointer-events: none;
}

.flickity-button-icon {
  fill: currentColor;
}

/* ---- previous/next buttons ---- */
.flickity-prev-next-button {
  top: 50%;
  width: 44px;
  height: 44px;
  border-radius: 50%;
  /* vertically center */
  -ms-transform: translateY(-50%);
      transform: translateY(-50%);
}

.flickity-prev-next-button.previous {
  left: 10px;
}

.flickity-prev-next-button.next {
  right: 10px;
}

/* right to left */
.flickity-rtl .flickity-prev-next-button.previous {
  left: auto;
  right: 10px;
}

.flickity-rtl .flickity-prev-next-button.next {
  right: auto;
  left: 10px;
}

.flickity-prev-next-button .flickity-button-icon {
  position: absolute;
  left: 20%;
  top: 20%;
  width: 60%;
  height: 60%;
}

/* ---- page dots ---- */
.flickity-page-dots {
  position: absolute;
  width: 100%;
  bottom: -25px;
  padding: 0;
  margin: 0;
  list-style: none;
  text-align: center;
  line-height: 1;
}

.flickity-rtl .flickity-page-dots {
  direction: rtl;
}

.flickity-page-dots .dot {
  display: inline-block;
  width: 10px;
  height: 10px;
  margin: 0 8px;
  background: #333;
  border-radius: 50%;
  opacity: 0.25;
  cursor: pointer;
}

.flickity-page-dots .dot.is-selected {
  opacity: 1;
}

/*------------------------------------*
	$MAGNIFIC POPUP
*------------------------------------*/
/* Magnific Popup CSS */
.mfp-bg {
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  z-index: 1042;
  overflow: hidden;
  position: fixed;
  background: #0b0b0b;
  opacity: 0.8;
}

.mfp-wrap {
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  z-index: 1043;
  position: fixed;
  outline: none !important;
  -webkit-backface-visibility: hidden;
}

.mfp-container {
  text-align: center;
  position: absolute;
  width: 100%;
  height: 100%;
  left: 0;
  top: 0;
  padding: 0 8px;
  box-sizing: border-box;
}

.mfp-container:before {
  content: "";
  display: inline-block;
  height: 100%;
  vertical-align: middle;
}

.mfp-align-top .mfp-container:before {
  display: none;
}

.mfp-content {
  position: relative;
  display: inline-block;
  vertical-align: middle;
  margin: 0 auto;
  text-align: left;
  z-index: 1045;
}

.mfp-inline-holder .mfp-content,
.mfp-ajax-holder .mfp-content {
  width: 100%;
  cursor: auto;
}

.mfp-ajax-cur {
  cursor: progress;
}

.mfp-zoom-out-cur,
.mfp-zoom-out-cur .mfp-image-holder .mfp-close {
  cursor: zoom-out;
}

.mfp-zoom {
  cursor: pointer;
  cursor: zoom-in;
}

.mfp-auto-cursor .mfp-content {
  cursor: auto;
}

.mfp-close,
.mfp-arrow,
.mfp-preloader,
.mfp-counter {
  -webkit-user-select: none;
  -ms-user-select: none;
      user-select: none;
}

.mfp-loading.mfp-figure {
  display: none;
}

.mfp-hide {
  display: none !important;
}

.mfp-preloader {
  color: #ccc;
  position: absolute;
  top: 50%;
  width: auto;
  text-align: center;
  margin-top: -0.8em;
  left: 8px;
  right: 8px;
  z-index: 1044;
}

.mfp-preloader a {
  color: #ccc;
}

.mfp-preloader a:hover {
  color: #fff;
}

.mfp-s-ready .mfp-preloader {
  display: none;
}

.mfp-s-error .mfp-content {
  display: none;
}

button.mfp-close,
button.mfp-arrow {
  overflow: visible;
  cursor: pointer;
  background: transparent;
  border: 0;
  -webkit-appearance: none;
  display: block;
  outline: none;
  padding: 0;
  z-index: 1046;
  box-shadow: none;
  -ms-touch-action: manipulation;
      touch-action: manipulation;
}

button::-moz-focus-inner {
  padding: 0;
  border: 0;
}

.mfp-close {
  width: 44px;
  height: 44px;
  line-height: 44px;
  position: absolute;
  right: 0;
  top: 0;
  text-decoration: none;
  text-align: center;
  opacity: 0.65;
  padding: 0 0 18px 10px;
  color: #fff;
  font-style: normal;
  font-size: 28px;
  font-family: Arial, Baskerville, monospace;
}

.mfp-close:hover,
.mfp-close:focus {
  opacity: 1;
}

.mfp-close:active {
  top: 1px;
}

.mfp-close-btn-in .mfp-close {
  color: #333;
}

.mfp-image-holder .mfp-close,
.mfp-iframe-holder .mfp-close {
  color: #fff;
  right: -6px;
  text-align: right;
  padding-right: 6px;
  width: 100%;
}

.mfp-counter {
  position: absolute;
  top: 0;
  right: 0;
  color: #ccc;
  font-size: 12px;
  line-height: 18px;
  white-space: nowrap;
}

.mfp-arrow {
  position: absolute;
  opacity: 0.65;
  margin: 0;
  top: 50%;
  margin-top: -55px;
  padding: 0;
  width: 90px;
  height: 110px;
  -webkit-tap-highlight-color: transparent;
}

.mfp-arrow:active {
  margin-top: -54px;
}

.mfp-arrow:hover,
.mfp-arrow:focus {
  opacity: 1;
}

.mfp-arrow:before,
.mfp-arrow:after {
  content: "";
  display: block;
  width: 0;
  height: 0;
  position: absolute;
  left: 0;
  top: 0;
  margin-top: 35px;
  margin-left: 35px;
  border: medium inset transparent;
}

.mfp-arrow:after {
  border-top-width: 13px;
  border-bottom-width: 13px;
  top: 8px;
}

.mfp-arrow:before {
  border-top-width: 21px;
  border-bottom-width: 21px;
  opacity: 0.7;
}

.mfp-arrow-left {
  left: 0;
}

.mfp-arrow-left:after {
  border-right: 17px solid #fff;
  margin-left: 31px;
}

.mfp-arrow-left:before {
  margin-left: 25px;
  border-right: 27px solid #3f3f3f;
}

.mfp-arrow-right {
  right: 0;
}

.mfp-arrow-right:after {
  border-left: 17px solid #fff;
  margin-left: 39px;
}

.mfp-arrow-right:before {
  border-left: 27px solid #3f3f3f;
}

.mfp-iframe-holder {
  padding-top: 40px;
  padding-bottom: 40px;
}

.mfp-iframe-holder .mfp-content {
  line-height: 0;
  width: 100%;
  max-width: 900px;
}

.mfp-iframe-holder .mfp-close {
  top: -40px;
}

.mfp-iframe-scaler {
  width: 100%;
  height: 0;
  overflow: hidden;
  padding-top: 56.25%;
}

.mfp-iframe-scaler iframe {
  position: absolute;
  display: block;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  box-shadow: 0 0 8px rgba(0, 0, 0, 0.6);
  background: #000;
}

/* Main image in popup */
img.mfp-img {
  width: auto;
  max-width: 100%;
  height: auto;
  display: block;
  line-height: 0;
  box-sizing: border-box;
  padding: 40px 0 40px;
  margin: 0 auto;
}

/* The shadow behind the image */
.mfp-figure {
  line-height: 0;
}

.mfp-figure:after {
  content: "";
  position: absolute;
  left: 0;
  top: 40px;
  bottom: 40px;
  display: block;
  right: 0;
  width: auto;
  height: auto;
  z-index: -1;
  box-shadow: 0 0 8px rgba(0, 0, 0, 0.6);
  background: #444;
}

.mfp-figure small {
  color: #bdbdbd;
  display: block;
  font-size: 12px;
  line-height: 14px;
}

.mfp-figure figure {
  margin: 0;
}

.mfp-bottom-bar {
  margin-top: -36px;
  position: absolute;
  top: 100%;
  left: 0;
  width: 100%;
  cursor: auto;
}

.mfp-title {
  text-align: left;
  line-height: 18px;
  color: #f3f3f3;
  word-wrap: break-word;
  padding-right: 36px;
}

.mfp-image-holder .mfp-content {
  max-width: 100%;
}

.mfp-gallery .mfp-image-holder .mfp-figure {
  cursor: pointer;
}

@media screen and (max-width: 800px) and (orientation: landscape), screen and (max-height: 300px) {
  /**
     * Remove all paddings around the image on small screen
     */
  .mfp-img-mobile .mfp-image-holder {
    padding-left: 0;
    padding-right: 0;
  }
  .mfp-img-mobile img.mfp-img {
    padding: 0;
  }
  .mfp-img-mobile .mfp-figure:after {
    top: 0;
    bottom: 0;
  }
  .mfp-img-mobile .mfp-figure small {
    display: inline;
    margin-left: 5px;
  }
  .mfp-img-mobile .mfp-bottom-bar {
    background: rgba(0, 0, 0, 0.6);
    bottom: 0;
    margin: 0;
    top: auto;
    padding: 3px 5px;
    position: fixed;
    box-sizing: border-box;
  }
  .mfp-img-mobile .mfp-bottom-bar:empty {
    padding: 0;
  }
  .mfp-img-mobile .mfp-counter {
    right: 5px;
    top: 3px;
  }
  .mfp-img-mobile .mfp-close {
    top: 0;
    right: 0;
    width: 35px;
    height: 35px;
    line-height: 35px;
    background: rgba(0, 0, 0, 0.6);
    position: fixed;
    text-align: center;
    padding: 0;
  }
}
@media all and (max-width: 900px) {
  .mfp-arrow {
    -ms-transform: scale(0.75);
        transform: scale(0.75);
  }
  .mfp-arrow-left {
    -ms-transform-origin: 0;
        transform-origin: 0;
  }
  .mfp-arrow-right {
    -ms-transform-origin: 100%;
        transform-origin: 100%;
  }
  .mfp-container {
    padding-left: 6px;
    padding-right: 6px;
  }
}
/* overlay at start */
.mfp-fade.mfp-bg {
  opacity: 0;
  transition: all 0.15s ease-out;
}

/* overlay animate in */
.mfp-fade.mfp-bg.mfp-ready {
  opacity: 0.8;
}

/* overlay animate out */
.mfp-fade.mfp-bg.mfp-removing {
  opacity: 0;
}

/* content at start */
.mfp-fade.mfp-wrap .mfp-content {
  opacity: 0;
  transition: all 0.15s ease-out;
}

/* content animate it */
.mfp-fade.mfp-wrap.mfp-ready .mfp-content {
  opacity: 1;
}

/* content animate out */
.mfp-fade.mfp-wrap.mfp-removing .mfp-content {
  opacity: 0;
}

.mfp-with-zoom .mfp-container,
.mfp-with-zoom.mfp-bg {
  opacity: 0;
  -webkit-backface-visibility: hidden;
  /* ideally, transition speed should match zoom duration */
  transition: all 0.3s ease-out;
}

.mfp-with-zoom.mfp-ready .mfp-container {
  opacity: 1;
}

.mfp-with-zoom.mfp-ready.mfp-bg {
  opacity: 0.8;
}

.mfp-with-zoom.mfp-removing .mfp-container,
.mfp-with-zoom.mfp-removing.mfp-bg {
  opacity: 0;
}

/*------------------------------------*
	$RESPONSIVE
*------------------------------------*/
/*------------------------------------*
	All Devices under 960px
*------------------------------------*/
@media only screen and (max-width: 959px) {
  /* default breakpoint */
  body.default-breakpoint #site-logo.has-responsive-logo .custom-logo-link {
    display: none;
  }
  body.default-breakpoint #site-logo.has-responsive-logo .responsive-logo-link {
    display: block;
  }
  body.default-breakpoint .is-sticky #site-logo.has-responsive-logo .sticky-logo-link {
    display: block;
  }
  body.default-breakpoint .is-sticky #site-logo.has-sticky-logo .responsive-logo-link {
    display: none;
  }
  body.default-breakpoint #site-header.center-header #site-logo {
    display: block;
  }
  body.default-breakpoint #top-bar-nav,
body.default-breakpoint #site-navigation-wrap,
body.default-breakpoint .oceanwp-social-menu,
body.default-breakpoint .after-header-content {
    display: none;
  }
  body.default-breakpoint .center-logo #site-logo {
    float: none;
    position: absolute;
    left: 50%;
    padding: 0;
    -ms-transform: translateX(-50%);
        transform: translateX(-50%);
  }
  body.default-breakpoint .oceanwp-mobile-menu-icon {
    display: -ms-inline-flexbox;
    display: inline-flex;
  }
  body.default-breakpoint #top-bar.has-no-content #top-bar-social {
    text-align: center;
  }
  body.default-breakpoint #top-bar.has-no-content #top-bar-social.top-bar-left, body.default-breakpoint #top-bar.has-no-content #top-bar-social.top-bar-right {
    position: inherit;
    left: auto;
    right: auto;
    float: none;
    height: auto;
    line-height: 1.5em;
    margin-top: 0;
  }
  body.default-breakpoint #top-bar.has-no-content #top-bar-social li {
    float: none;
    display: inline-block;
  }
  body.default-breakpoint.vertical-header-style #outer-wrap {
    margin: 0 !important;
  }
  body.default-breakpoint #site-header.vertical-header {
    position: relative;
    width: 100%;
    left: 0 !important;
    right: 0 !important;
  }
  body.default-breakpoint #site-header.vertical-header .has-template > #site-logo {
    display: block;
  }
  body.default-breakpoint #site-header.vertical-header #site-header-inner {
    display: -ms-flexbox;
    display: flex;
    -ms-flex-align: center;
        align-items: center;
    padding: 0;
    max-width: 90%;
  }
  body.default-breakpoint #site-header.vertical-header #site-header-inner > *:not(.oceanwp-mobile-menu-icon) {
    display: none;
  }
  body.default-breakpoint #site-header.vertical-header #site-header-inner > * {
    padding: 0 !important;
  }
  body.default-breakpoint #site-header.vertical-header #site-header-inner #site-logo {
    display: block;
    margin: 0;
    width: 50%;
    text-align: left;
  }
  body.default-breakpoint #site-header.vertical-header #site-header-inner .oceanwp-mobile-menu-icon {
    width: 50%;
    text-align: right;
  }
  body.default-breakpoint #site-header.vertical-header .vertical-toggle {
    display: none;
  }
  body.default-breakpoint .is-sticky #site-header.vertical-header {
    position: fixed;
    height: auto;
  }
  body.default-breakpoint.vh-closed .vertical-toggle {
    display: none;
  }
  body.default-breakpoint .owp-cart-overlay {
    display: none !important;
  }
}
/*------------------------------------*
	Phone Portrait and Landscape
*------------------------------------*/
@media only screen and (max-width: 767px) {
  .hide-tablet-mobile {
    display: none !important;
  }
}
/*------------------------------------*
	Phone Landscape
*------------------------------------*/
@media only screen and (max-width: 480px) {
  .hide-mobile {
    display: none !important;
  }
}
/*------------------------------------*
	Visibility
*------------------------------------*/
@media only screen and (min-width: 481px) and (max-width: 767px) {
  .hide-tablet {
    display: none !important;
  }
}